<?php

use ch\monitoring\Application;

use org\adfinis\framework\datamapper\IdentityMap;
$idmContext = IdentityMap::getContext();


$dayTable = array(
	'sunday',
	'monday',
	'tuesday',
	'wednesday',
	'thursday',
	'friday',
	'saturday'
);

try {
	// DISTINCT because of the Timeframes join
	$query = sprintf("
			SELECT DISTINCT
				`Alert`.*,
				`Customer`.`name`            AS `customerName`,
				`Host`.`hostname`            AS `hostName`,
				`Host`.`IPv4`                AS `hostAddress`,
				`Service`.`name`             AS `serviceName`,
				`HostServiceInstance`.`name` AS `instanceName`,
				`Command`.`name`             AS `commandName`
			FROM
				`Alert`
			JOIN `Customer` ON (
				`Customer`.`id` = `Alert`.`customerId`
			)
			JOIN `Host` ON (
				`Host`.`id` = `Alert`.`hostId`
			)
			LEFT JOIN `HostServiceInstance` ON (
				`HostServiceInstance`.`id` = `Alert`.`serviceInstanceId`
			)
			LEFT JOIN `HostService` ON (
				`HostService`.`id` = `HostServiceInstance`.`hostServiceId`
			)
			LEFT JOIN `Service` ON (
				`Service`.`id` = `HostService`.`serviceId`
			)
			JOIN `Command` ON (
				`Command`.`id` = `Alert`.`commandId`
			)
			JOIN `SLA` ON (
				`SLA`.`id` = `HostServiceInstance`.`slaId`
				OR (
					`HostServiceInstance`.`slaId` IS NULL
					AND (
						`SLA`.`id` = `Host`.`slaId`
						OR (
							`Host`.`slaId` IS NULL
							AND
							`SLA`.`id` = `Customer`.`slaId`
						)
					)
				)
			)

			JOIN `Timeframe` ON (
				`Timeframe`.`slaId` = `SLA`.`id`
				AND
				`Timeframe`.`%s` = TRUE
				AND (
					(
						`Timeframe`.`timeFrom` <= `Timeframe`.`timeTo`
						AND
						TIME_FORMAT(NOW(), '%%H:%%i') BETWEEN
							TIME_FORMAT(`Timeframe`.`timeFrom`, '%%H:%%i')
							AND
							TIME_FORMAT(`Timeframe`.`timeTo`, '%%H:%%i')
					)
					OR (
						TIME_FORMAT(`Timeframe`.`timeFrom`, '%%H:%%i') > TIME_FORMAT(`Timeframe`.`timeTo`, '%%H:%%i')
						AND (
							TIME_FORMAT(NOW(), '%%H:%%i') > TIME_FORMAT(`Timeframe`.`timeFrom`, '%%H:%%i')
							OR
							TIME_FORMAT(NOW(), '%%H:%%i') < TIME_FORMAT(`Timeframe`.`timeTo`, '%%H:%%i')
						)
					)
				)
			)
			WHERE
				`Alert`.`slaId` IS NULL
				AND
				`Alert`.`acknowledged` = FALSE
		",
		$dayTable[date("w")]
	);
	$statement = Application::getDbInstance()->prepare($query);
	$statement->execute();
	$alerts = $statement->fetchAll(PDO::FETCH_ASSOC);

	foreach ($alerts as $alert) {
		$output = sprintf(
			"%s\n%s",
			'Incident happened outside of any SLA!',
			$alert['output']
		);

		if (empty($alert['serviceName'])) {
			$name = $alert['hostName'];
		}
		else {
			$name = empty($alert['instanceName'])
				? $alert['serviceName']
				: sprintf("%s__%s", $alert['serviceName'], $alert['instanceName']);
		}

		$now = new \Zend_Date();
		Application::getDbInstance()->insert(
			'NagiosLog',
			array(
				'objectType'    => $alert['serviceName'] ? 'SERVICE' : 'HOST',
				'stateType'     => 'HARD',
				'state'         => $alert['state'],
				'name'          => $name,
				'hostname'      => $alert['hostName'],
				'checkCommand'  => $alert['commandName'],
				'address'       => $alert['hostAddress'],
				'output'        => $output,
				'perfdata'      => '',
				'duration'      => '',
				'datetime'      => $now->get(Zend_Date::ISO_8601),
				'problemId'     => $alert['problemId'],
				'lastProblemId' => $alert['lastProblemId'],
				'attempt'       => 1
			)
		);

		Application::getDbInstance()->update(
			'Alert',
			array(
				'acknowledged'              => true,
				'acknowledgedBy'            => null,
				'acknowledgedAutomatically' => true,
				'comment'                   => "Created a new alert because this one was out of SLA"
			),
			sprintf("`id` = %d", $alert['id'])
		);

		Application::getDbInstance()->insert(
			'AlertLog',
			array(
				'typeId'  => 5,
				'userId'  => null,
				'alertId' => $alert['id']
			)
		);
	}
}
catch (PDOException $e) {
	die($e->getMessage());
}
