<?php

use ch\monitoring\datamapper\AlertMapper;
use ch\monitoring\Application;

use org\adfinis\framework\datamapper\IdentityMap;
$idmContext = IdentityMap::getContext();

$openAlerts = AlertMapper::getInstance()->getAll(
	null,
	true,
	null,
	null,
	null,
	null,
	null,
	false,
	null
);

Application::getDBInstance()->beginTransaction();

// For each open alert, verify whether the issue is open in Icinga, too
foreach ($openAlerts as $alert) {
	$host = $alert->getHost();
	$reason = "Recovery by Icinga detected, but not reported to SyMonitoring: Host {$host->hostname} disabled";

	if (!$host->isEnabled) {
		$alert->recover($reason);
		continue;
	}

	if ($alert->serviceInstanceId === null) {
		$query = "
			SELECT
				`icinga_hoststatus`.`current_state`
			FROM
				`icinga_hoststatus`
			JOIN `icinga_hosts` ON (
				`icinga_hosts`.`host_object_id` = `icinga_hoststatus`.`host_object_id`
				AND
				`icinga_hosts`.`display_name` = ?
			)
		";

		$parameters = array(
			$host->hostname
		);
        $reason = "Recovery by Icinga detected, but not reported to SyMonitoring: State for host {$host->hostname}: %s";
	}
	else {
        $serviceInstanceName = $alert->getHostServiceInstance()->getObjectName();
		$query = "
			SELECT
				`icinga_servicestatus`.`current_state`
			FROM
				`icinga_servicestatus`
			JOIN `icinga_hosts` ON (
				`icinga_hosts`.`alias` = ?
			)
			JOIN `icinga_services` ON (
				`icinga_services`.`service_object_id` = `icinga_servicestatus`.`service_object_id`
				AND
				`icinga_services`.`display_name` = ?
				AND
				`icinga_services`.`host_object_id` = `icinga_hosts`.`host_object_id`
			)
		";

		$parameters = array(
			$host->hostname,
            $serviceInstanceName
		);
        $reason = "Recovery by Icinga detected, but not reported to SyMonitoring: State for {$host->hostname} -- {$serviceInstanceName}: %s";
	}

	$state = Application::getDbInstance('icingaIdo')->fetchOne(
		$query,
		$parameters
	);

	if (!is_null($state) && "$state" === "0") { /* not sure if it comes in as string or int. but make sure it's not NULL */
		$alert->recover(sprintf($reason, $state));
	}
}

Application::getDBInstance()->commit();
