<?php

use ch\monitoring\Application;
use ch\monitoring\datamapper;
use ch\monitoring\util;
use org\adfinis\framework\utils;

use org\adfinis\framework\datamapper\IdentityMap;
$idmContext = IdentityMap::getContext();

$today    = new \Zend_Date();
$tomorrow = new \Zend_Date();
$tomorrow->add(1, \Zend_Date::DAY);

$membersToday = datamapper\CustomerTeamMapper::getInstance()->getAll(
	$today,
	null,
	null
);

$today = array();
foreach($membersToday as $member) {
	$today[$member->customerId][$member->userId] = true;
}

$membersTomorrow = datamapper\CustomerTeamMapper::getInstance()->getAll(
	$tomorrow,
	null,
	null
);

$topic    = "Emergency team announcement";
$template = "Tomorrow you are scheduled in the emergency team for the customer %s with priority %d.";


foreach ($membersTomorrow as $member) {
	if ($today[$member->customerId][$member->userId] === true) {
		$message = sprintf(
			"SyMonitoring: emergencyNotification: Not informing user %s as he was in the emergency team before",
			$member->getUser()->fullName
		);
		syslog(LOG_INFO, $message);
		continue;
	}

	$text = sprintf(
		tr($template),
		$member->getCustomer()->name,
		$member->priority + 1
	);

	if ($member->getUser()->email !== null) {
		utils\MailHelper::sendMail(
			array(
				array(
					'firstName' => '',
					'lastName'  => $member->getUser()->fullName,
					'address'   => $member->getUser()->email
				)
			),
			tr($topic),
			$text,
			'',
			true
		);
		$message = sprintf(
			"SyMonitoring: emergencyNotification: Informed user %s by email %s",
			$member->getUser()->fullName,
			$member->getUser()->email
		);
		syslog(LOG_INFO, $message);
	}

	if ($member->getUser()->phone !== null) {
		$sms = new util\phpASPSMS();
		$sms->Recipients  = $member->getUser()->phone;
		$sms->MessageText = $text;
		$sms->SendTextSMS();
		$message = sprintf(
			"SyMonitoring: emergencyNotification: Informed user %s by SMS %s",
			$member->getUser()->fullName,
			$member->getUser()->phone
		);
		syslog(LOG_INFO, $message);
	}
}
