<?php

use ch\monitoring\Application;

use org\adfinis\framework\datamapper\IdentityMap;
$idmContext = IdentityMap::getContext();

$selectDayStatement = Application::getDbInstance()->prepare("
	SELECT
		SUM(`CheckResult`.`available`) as `sumAvailable`,
		COUNT(`CheckResult`.`available`) as `countAvailable`,
		`Host`.`customerId`,
		`CheckResult`.`hostId`,
		`CheckResult`.`serviceInstanceId`
	FROM
		`CheckResult`
	JOIN `Host` ON (
		`Host`.`id` = `CheckResult`.`hostId`
	)
	WHERE
		DATE(`CheckResult`.`timestamp`) = :timestamp
	GROUP BY
		`CheckResult`.`hostId`,
		`CheckResult`.`serviceInstanceId`
");

$deleteDayStatement = Application::getDbInstance()->prepare("
	DELETE FROM
		`CheckResult`
	WHERE
		DATE(`timestamp`) = :date
");

$insertFactStatement = Application::getDbInstance()->prepare("
	INSERT INTO
		`BI_FactAvailability`
	SET
		`dateId`      = :dateId,
		`hostId`      = :hostId,
		`available`   = :available,
		`unavailable` = :unavailable
");

$selectDimensionHostStatement = Application::getDbInstance()->prepare("
	SELECT
		`id`
	FROM
		`BI_DimensionHost`
	WHERE
		`hostId` = :hostId
		AND
		`serviceInstanceId` = :serviceInstanceId
");

$selectDimensionHostNullStatement = Application::getDbInstance()->prepare("
	SELECT
		`id`
	FROM
		`BI_DimensionHost`
	WHERE
		`hostId` = :hostId
		AND
		`serviceInstanceId` IS NULL
");

$insertDimensionHostStatement = Application::getDbInstance()->prepare("
	INSERT INTO
		`BI_DimensionHost`
	SET
		`customerId`        = :customerId,
		`hostId`            = :hostId,
		`serviceInstanceId` = :serviceInstanceId
");

$selectDimensionDateStatement = Application::getDbInstance()->prepare("
	SELECT
		`id`
	FROM
		`BI_DimensionDate`
	WHERE
		`date` = :date
");

$insertDimensionDateStatement = Application::getDbInstance()->prepare("
	INSERT INTO
		`BI_DimensionDate`
	SET
		`date`       = :date,
		`dayOfWeek`  = :dayOfWeek,
		`dayOfMonth` = :dayOfMonth,
		`dayOfYear`  = :dayOfYear,
		`month`      = :month,
		`year`       = :year,
		`quarter`    = :quarter,
		`week`       = :week
");

$dates = Application::getDbInstance()->fetchCol("
	SELECT DISTINCT
		DATE(`timestamp`) as `date`
	FROM
		`CheckResult`
	WHERE
		`timestamp` < DATE(NOW())
");

foreach ($dates as $date) {
	echo sprintf("Starting to process events from %s\n", $date);
	Application::getDbInstance()->beginTransaction();
	$dateObject = new Zend_Date($date, \Zend_Date::ISO_8601);

	try {
		$selectDayStatement->execute(array('timestamp' => $date));
	}
	catch (\Exception $e) {
		error_log(sprintf("There was an exception when selecting days %s", $e->getMessage()));
		continue;
	}
	$checkResults = $selectDayStatement->fetchAll();
	foreach ($checkResults as $checkResult) {
		if ($checkResult['serviceInstanceId'] === null) {
			$hostStatement = $selectDimensionHostNullStatement;
			$dimensionHostParameters = array(
				'hostId'    => $checkResult['hostId']
			);
		}
		else {
			$hostStatement = $selectDimensionHostStatement;
			$dimensionHostParameters = array(
				'hostId'            => $checkResult['hostId'],
				'serviceInstanceId' => $checkResult['serviceInstanceId']
			);
		}

		try {
			$hostStatement->execute($dimensionHostParameters);
		}
		catch (\Exception $e) {
			error_log(sprintf("There was an exception when getting dimension host params %s", $e->getMessage()));
		}

		$hostId = $hostStatement->fetchColumn();

		if (empty($hostId)) {
			try {
				$insertDimensionHostStatement->execute(array(
					'customerId'        => $checkResult['customerId'],
					'hostId'            => $checkResult['hostId'],
					'serviceInstanceId' => $checkResult['serviceInstanceId']
				));
			}
			catch (\Exception $e) {
				error_log(sprintf("There was an exception inserting dimension host %s", $e->getMessage()));
			}

			$hostId = Application::getDbInstance()->lastInsertId();
		}

		try {
			$selectDimensionDateStatement->execute(array(
				'date' => $date
			));
		}
		catch (\Exception $e) {
			error_log(sprintf("There was an exception getting dimension dates %s", $e->getMessage()));
		}

		$dateId = $selectDimensionDateStatement->fetchColumn();

		if (empty($dateId)) {
			try {
				$insertDimensionDateStatement->execute(array(
					'date'       => $date,
					'dayOfWeek'  => $dateObject->get(Zend_Date::WEEKDAY_8601),
					'dayOfMonth' => $dateObject->get(Zend_Date::DAY_SHORT),
					'dayOfYear'  => $dateObject->get(Zend_Date::DAY_OF_YEAR),
					'month'      => $dateObject->get(Zend_Date::MONTH_SHORT),
					'year'       => $dateObject->get(Zend_Date::YEAR_8601),
					'quarter'    => ceil($dateObject->get(Zend_Date::MONTH_SHORT) / 3),
					'week'       => $dateObject->get(Zend_Date::WEEK)
				));
			}
			catch (\Exception $e) {
				error_log(sprintf("There was an exception inserting dimension dates %s", $e->getMessage()));
			}


			$dateId = Application::getDbInstance()->lastInsertId();
		}

		try {
			$insertFactStatement->execute(array(
				'hostId' => $hostId,
				'dateId' => $dateId,
				'available' => $checkResult['sumAvailable'],
				'unavailable' => $checkResult['countAvailable'] - $checkResult['sumAvailable']
			));
		}
		catch (\Exception $e) {
			error_log(sprintf("There was an exception inserting fact %s", $e->getMessage()));
		}
	}
	try {
		$deleteDayStatement->execute(array(
			'date' => $date
		));
		echo sprintf("Finished processing events from %s\n", $date);
	}
	catch (\Exception $e) {
		error_log(sprintf("There was an exception deleting day %s: %s", $date, $e->getMessage()));
	}
	Application::getDbInstance()->commit();
}
