<?php

use ch\monitoring\Application;
use ch\monitoring\datamapper;

use org\adfinis\framework\datamapper\IdentityMap;
$idmContext = IdentityMap::getContext();

if (count($argv) != 2) {
	print (
		sprintf(
			tr('Usage: %s %s'),
			$argv[0],
			tr('filename')
		)
	);
	exit -1;
}

$filename = $argv[1];
$fh = fopen($filename, 'r');

if ($fh === FALSE) {
	throw new RuntimeException(
		sprintf(
			tr('Could not open file: %s'),
			$filename
		)
	);
}

while (($line = fgets($fh)) !== FALSE) {
	preg_match('/^\w+::(?P<objectType>[^\t]*)\t+\w+::(?P<timestamp>[^\t]*)\t+\w+::(?P<hostname>[^\t]*)\t+\w+::((?P<servicename>[^\t]*)\t+\w+::){0,1}(?P<perfdata>[^\t]*)\t+\w+::(?P<command>[^\t]*)\t+\w+::(?P<stateId>[^\t]*)\t+\w+::(?P<stateType>[^\t]*)$/', $line, $values);

	if ($values['objectType'] == "HOSTPERFDATA") {
		// UNREACHABLE is neither available nor unavailable
		if ($values['stateId'] == 2) {
			exit;
		}

		$host              = datamapper\HostMapper::getInstance()->getByName($values['hostname'])->allowRead();
		$hostId            = $host->id;
		$serviceInstanceId = null;
		$available         = $values['stateId'] == 1 ? 0 : 1; // Id 1 is DOWN
	}
	else {
		// UNKNOWN is neither available nor unavailable
		if ($values['stateId'] == 3) {
			exit;
		}

		$host   = datamapper\HostMapper::getInstance()->getByName($values['hostname'])->allowRead();
		$hostId = $host->id;

		$serviceparts      = explode("__", $values['servicename'], 2);
		$service           = datamapper\ServiceMapper::getInstance()->getByName($serviceparts[0])->allowRead();

		$instanceName      = count($serviceparts) == 2 ? $serviceparts[1] : null;
		$serviceInstance   = datamapper\HostServiceInstanceMapper::getInstance()->getByName($instanceName, $hostId, $service->id)->allowRead();
		$serviceInstanceId = $serviceInstance->id;

		$available = $values['stateId'] == 2 ? 0 : 1; // Id 2 is CRITICAL. This also counts WARNING as available.
	}

	$datetime = new Zend_Date($values['timestamp']);

	$parameters = array(
		'timestamp'         => $datetime->get(Zend_Date::ISO_8601),
		'hostId'            => $hostId,
		'serviceInstanceId' => $serviceInstanceId,
		'available'         => $available
	);

	$query = '
		INSERT INTO
			`CheckResult`
		SET
			`timestamp`         = :timestamp,
			`hostId`            = :hostId,
			`serviceInstanceId` = :serviceInstanceId,
			`available`         = :available
	';

	$statement = Application::getDbInstance()->prepare($query);
	$statement->execute($parameters);
}
