<?php

use org\adfinis\framework as af;
use ch\monitoring\Application;
use org\adfinis\framework\datamapper\IdentityMap;
$idmContext = IdentityMap::getContext();

if (!$argv[1]) {
	die("Specify xml file location!\n");
}

if (!file_exists($argv[1])) {
	die("{$argv[1]} not found!\n");
}

//$zabbixYesSymonNo = array();
//$zabbixNoSymonYes = array();
//parseHosts($argv[1], 'verifyHost');
//showHosts();

$checks = array();
$triggers = array();
//parseChecks($argv[1], 'collectChecks');
parseTriggers($argv[1], 'collectTriggers');
//showChecks();
showTriggers();

/**
 * Parses the zabbix export and executes the callback
 * function for each event
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @throws        XMLParserException
 * @param         string   $logfile
 * @param         callable $fun
 * @returns       void
 */
function parseHosts($log, $fun) {
	$parser  = af\xml\Parser::create();
	$host = null;

	$parser->caseFolding = false;

	$parser->on('start element', function($self, $name, $attr) use (&$host) {
		if ($self->level === 2 && $name == "host") {
			$host = new StdClass;
			$host->name = $attr['name'];
		}
	});

	$parser->on('end element', function($self, $name) use (&$host) {
		if ($self->level === 2 && $name == "host") {
			$self->emit('element done', $host);
			$host = null;
		}
	});

	$parser->on('character data', function($self, $data) use (&$host) {
		if ($self->level === 3 && $self->currentElement == "status") {
			$host->status = $data;
		}
	});

	$parser->on('element done', function($self, $host) use (&$fun) {
		call_user_func($fun, $host);
	});

	$buffsize = 8192;

	$parser->parseFile($log, $buffsize);
}

/**
 * Verifies the existance or nonexistance of a host
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @param         StdClass $event
 * @returns       void
 */
function verifyHost($host) {
	global $zabbixNoSymonYes;
	global $zabbixYesSymonNo;

	$result = Application::getDbInstance()->prepare("
		SELECT
			`id`
		FROM
			`smng_hosts`
		WHERE
			`hostname` = :hostname
	");
	$result->execute(array('hostname' => $host->name));
	$smngHost = $result->fetch();

	if ($host->status == 1 && !empty($smngHost)) {
/*		echo sprintf(
			"Host '%s' is disabled in Zabbix but available in SyMonitoring!\n",
			$host->name
		);*/

		$zabbixNoSymonYes[] = $host;
	}

	if ($host->status == 0 && empty($smngHost)) {
/*		echo sprintf(
			"Host '%s' is enabled in Zabbix but unavailable in SyMonitoring!\n",
			$host->name
		);*/
		$zabbixYesSymonNo[] = $host;
	}
}

/**
 * List hosts
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @returns       void
 */
function showHosts() {
	global $zabbixNoSymonYes;
	global $zabbixYesSymonNo;

	echo "Hosts not monitored in Zabbix but available in SyMonitoring:\n---\n";
	foreach ($zabbixNoSymonYes as $host) {
		echo sprintf(
			"%s\n",
			$host->name
		);
	}

	echo "\n\nHosts monitored in Zabbix but not available in SyMonitoring:\n---\n";
	foreach ($zabbixYesSymonNo as $host) {
		echo sprintf(
			"%s\n",
			$host->name
		);
	}
}

/**
 * Parses the zabbix export and executes the callback
 * function for each event
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @throws        XMLParserException
 * @param         string   $logfile
 * @param         callable $fun
 * @returns       void
 */
function parseChecks($log, $fun) {
	$parser  = af\xml\Parser::create();
	$check = null;

	$parser->caseFolding = false;

	$parser->on('start element', function($self, $name, $attr) use (&$check) {
		if ($self->level === 4 && $name == "item") {
			$check = new StdClass;
			$check->name = $attr['key'];
			$check->attributes = array();
		}
	});

	$parser->on('end element', function($self, $name) use (&$check) {
		if ($self->level === 4 && $name == "item") {
			$self->emit('element done', $check);
			$check = null;
		}
	});

	$parser->on('character data', function($self, $data) use (&$check) {
		if ($self->level !== 5) {
			return;
		}

		$check->attributes[$self->currentElement] = $data;
	});

	$parser->on('element done', function($self, $check) use (&$fun) {
		call_user_func($fun, $check);
	});

	$buffsize = 8192;

	$parser->parseFile($log, $buffsize);
}

/**
 * Collect all checks
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @throws
 * @param         type $param_name
 * @returns       void
 */
function collectChecks($check) {
	global $checks;

	$checks[$check->name] = $check->attributes;
}

/**
 * Shows all collected checks
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @returns       void
 */
function showChecks() {
	global $checks;
	$unique = array();

	foreach ($checks as $name => $attributes) {
		echo sprintf(
			"%s\t%s\t%s\n",
			$name,
			$attributes['description'],
			$attributes['snmp_oid']
		);

		$name = preg_replace('/(.*)\[.*\]/', "$1", $name);
		$unique[$name] = $attributes;
	}

	echo "\n\nUnique:\n";

	foreach ($unique as $name => $attributes) {
		echo sprintf(
			"%s\t%s\t%s\n",
			$name,
			$attributes['description'],
			$attributes['snmp_oid']
		);
	}
}

/**
 * Parses the zabbix export and executes the callback
 * function for each event
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @throws        XMLParserException
 * @param         string   $logfile
 * @param         callable $fun
 * @returns       void
 */
function parseTriggers($log, $fun) {
	$parser  = af\xml\Parser::create();
	$trigger = null;

	$parser->caseFolding = false;

	$parser->on('start element', function($self, $name, $attr) use (&$trigger) {
		if ($self->level === 4 && $name == "trigger") {
			$trigger = new StdClass;
			$trigger->attributes = array();
		}
	});

	$parser->on('end element', function($self, $name) use (&$trigger) {
		if ($self->level === 4 && $name == "trigger") {
			$self->emit('element done', $trigger);
			$trigger = null;
		}
	});

	$parser->on('character data', function($self, $data) use (&$trigger) {
		if ($self->level !== 5) {
			return;
		}

		$trigger->attributes[$self->currentElement] = $data;
	});

	$parser->on('element done', function($self, $trigger) use (&$fun) {
		call_user_func($fun, $trigger);
	});

	$buffsize = 8192;

	$parser->parseFile($log, $buffsize);
}

/**
 * Collect all triggers
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @throws
 * @param         type $param_name
 * @returns       void
 */
function collectTriggers($trigger) {
	global $triggers;

	$triggers[] = $trigger->attributes;
}

/**
 * Shows all collected triggers
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @returns       void
 */
function showTriggers() {
	global $triggers;

	foreach ($triggers as $attributes) {
		echo sprintf(
			"%s\t%s\n",
			$attributes['expression'],
			$attributes['priority']
		);
	}
}
