<?php

namespace ch\monitoring\acl;

/**
 * Interface for acl operations
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
interface ACL {

	/**
	 * Returns a list of customers a user got a certain permission on
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         string $permissionName
	 * @returns       array
	 */
	public function getCustomersWithPermission($permissionName);

	/**
	 * Verifies whether a user has a certain permission for any customer
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         string $permissionName
	 * @returns       bool
	 */
	public function hasPermission($permissionName);

	/**
	 * Enforce hasPermission()
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         string $permissionName
	 * @throws        Exception
	 * @returns       void
	 */
	public function enforcePermission($permissionName);

	/**
	 * Verifies whether a user has a certain permission for a certain customer
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         string $permissionName
	 * @param         int $customerId
	 * @returns       bool
	 */
	public function hasPermissionForCustomer($permissionName, $customerId);

	/**
	 * Enforce hasPermissionForCustomer()
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         string $permissionName
	 * @param         int $customerId
	 * @throws        Exception
	 * @returns       void
	 */
	public function enforcePermissionForCustomer($permissionName, $customerId);

	/**
	 * Verifies whether a user has a certain permission for the whole system
	 * 
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @param         string $permissionName
	 * @returns       bool
	 */
	public function hasPermissionForWholeSystem($permissionName);

	/**
	 * Enforce a permission for the whole system
	 * 
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @param         string $permissionName
	 * @returns       void
	 */
	public function enforcePermissionForWholeSystem($permissionName);

	/**
	 * Returns a cached version of the root customer
	 * 
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       \org\adfinis\framework\model\Entity
	 */
	public function getRootCustomer();

	/**
	 * Returns a cached version of the PK from the root customer
	 * 
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       int
	 */
	public function getRootCustomerIdentifier();
}
