<?php

namespace ch\monitoring\controller;

use org\adfinis\framework\request;
use org\adfinis\framework\exceptions\UserException;
use org\adfinis\framework\utils\PasswordGenerator;
use org\adfinis\framework\config\ConfManager;
use ch\monitoring\Application;
use ch\monitoring\datamapper;
use ch\monitoring\model;
use ch\monitoring\util;

/**
 * Handle alert template page requests
 *
 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class AlertTemplateController extends ProtectedController {

	/**
	 * Handles GET requests
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function handleGET() {
		$this->setHeaderTitle(tr("Alert Template"));
		$this->parameters['templates'] = datamapper\AlertTemplateMapper::getInstance()->getAll();

		$this->tpl->assign('template', 'alerttemplates/alerttemplates.tpl');
		$this->tpl->assign('templateSubmenu', 'submenu.tpl');
		$this->outputPage('index.tpl');
	}

	/**
	 * Handles AJAX requests
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function handleAJAX() {
		header('Content-Type: application/json; charset=utf-8');

		$this->callActionHandler();

		$this->tpl->assign('template', 'alerttemplates/alerttemplatesAjax.tpl');
		$this->outputAjaxPage('ajax.tpl');
	}

	/**
	 * Edit an AlertTemplate
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @throws        UserException
	 * @returns       void
	 */
	protected function editAction() {
		$id = $this->request->getInt('id', request\REQUEST_GET);

		if (empty($id)) {
			throw new UserException(
				tr("Id is missing")
			);
		}

		$template   = datamapper\AlertTemplateMapper::getInstance()->getByID($id);
		$slaActions = util\IteratorUtil::getKeyValueArray(
			datamapper\SLAActionMapper::getInstance()->getAll()
		);

		$this->parameters['template'] = $template;
		$this->parameters['template'] = $template;
		$this->select['slaActions'] = $slaActions;
	}

	/**
	 * Add a template
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function addFormAction() {
		$template = new model\AlertTemplate();
		$slaActions = util\IteratorUtil::getKeyValueArray(
			datamapper\SLAActionMapper::getInstance()->getAll()
		);

		$this->parameters['template']   = $template;
		$this->select['slaActions'] = $slaActions;
	}

	/**
	 * Save a AlertTemplate
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @throws        UserException
	 * @returns       void
	 */
	protected function saveAction() {
		$id = $this->request->getInt('id');

		if (empty($id)) {
			throw new UserException(
				tr("AlertTemplate id is missing")
			);
		}

		$template = datamapper\AlertTemplateMapper::getInstance()->getByID($id);
		$this->saveTemplate($template);
		$this->parameters['template'] = $template;
	}

	/**
	 * Add an AlertTemplate
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function addAction() {
		$template = new model\AlertTemplate();
		$this->saveTemplate($template);
	}

	/**
	 * Add or save an AlertTemplate
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @param         model\AlertTemplate $template The AlertTemplate model to be saved
	 * @returns       void
	 */
	private function saveTemplate($template) {
		$template->name                = $this->request->getString('name');
		$template->description         = $this->request->getString('description');
		$template->content             = $this->request->getString('content');
		$template->slaActionId         = $this->request->getString('slaActionId');
		$template->save();
		
		$this->parameters['templates'][] = $template;
	}

	/**
	 * Delete a AlertTemplate
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @throws        UserException
	 * @returns       void
	 */
	protected function deleteAction() {
		$id = $this->request->getInt('id');

		if (empty($id)) {
			throw new UserException(tr('AlertTemplate id is missing'));
		}

		$template = datamapper\AlertTemplateMapper::getInstance()->getByID($id);
		$template->delete();
	}



	/**
	 * Returns the help page of the template markup language
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function helpAction() {}
}
