<?php

namespace ch\monitoring\controller;

use org\adfinis\framework\request;
use org\adfinis\framework\config\ConfManager;
use org\adfinis\framework\exceptions\UserException;
use ch\monitoring\datamapper;
use ch\monitoring\model;
use ch\monitoring\Application;
use ch\monitoring\util;

/**
 * Handle application page requests
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class ApplicationController extends ProtectedController {

	/**
	 * Handles GET requests
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function handleGET() {
		header('Content-Type: text/html; charset=utf-8');

		$this->session->user->enforcePermission(
			model\Permission::HOSTS_READ
		);

		$this->setHeaderTitle(tr("Applications"));
		$this->addLinkWithSourcePath('vis/dist/vis.min.css');

		$rpcClient = Application::getRPCClientInstance(
			ConfManager::getVar('sm','RPC', 'lcAppName'),
			ConfManager::getVar('sm','RPC', 'lcQueues')
		);
		$resultId = $rpcClient->putRequest('get_application_list', array());
		$data = $rpcClient->getResult($resultId);
		if (isset($data->exception)) {
			throw new UserException($data->exception->message, $data->exception->code);
		}
		$applications = array();
		if (isset($data->applications)) {
			foreach ($data->applications as $application) {
				$applications[$application->id] = $application->name;
			}
		}
		$this->select['applications'] = $applications;

		$this->tpl->assign('template', 'hosts/applications.tpl');
		$this->tpl->assign('templateSubmenu', 'submenu.tpl');

		$this->outputPage('index.tpl');
	}

	/**
	 * Handles AJAX requests
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function handleAJAX() {
		header('Content-Type: application/json; charset=utf-8');

		$this->callActionHandler();

		$this->tpl->assign('template', 'hosts/applicationsAjax.tpl');
		$this->outputAjaxPage('ajax.tpl');
	}

	/**
	 * Get details for an application
	 *
	 * @author        Denis Simonet
	 * @returns       void
	 */
	protected function getApplicationAction() {
		$id = $this->request->getInt('id', request\REQUEST_GET);
		$rpcClient = Application::getRPCClientInstance(
			ConfManager::getVar('sm','RPC', 'lcAppName'),
			ConfManager::getVar('sm','RPC', 'lcQueues')
		);
		$data = array(
			'application_id' => $id
		);
		$resultId = $rpcClient->putRequest('get_application', $data);
		$application = $rpcClient->getResult($resultId);
		if (isset($application->exception)) {
			throw new UserException($application->exception->message, $application->exception->code);
		}
		$this->parameters['application'] = json_encode($application);
	}
}
