<?php

namespace ch\monitoring\controller;

use org\adfinis\framework\request;
use ch\monitoring\datamapper;
use ch\monitoring\model;
use ch\monitoring\util;

/**
 * Handle alert page requests
 *
 * @author        Stefan Heinemann <stefan.heinemann@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class AuditLogController extends ProtectedController {

	/**
	 * Handle GET request
	 *
	 * @author        Stefan Heinemann <stefan.heinemann@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function handleGET() {
		$this->session->user->enforcePermission(
			model\Permission::AUDIT_LOG_READ
		);

		$this->setHeaderTitle(tr("Audit Log"));

		$dateTo = new \Zend_Date();
		$dateFrom = clone $dateTo;
		$dateFrom->sub(1, \Zend_Date::DAY);
		$dateFrom->set("00:00:00", \Zend_Date::TIMES);

		$logEntries = datamapper\AuditLogMapper::getInstance()->getAll();

		$this->parameters['dateFrom']   = $dateFrom;
		$this->parameters['dateTo']     = $dateTo;
		$this->parameters['logEntries'] = $logEntries;

		$this->tpl->assign('template', 'logs/auditLog.tpl');

		$this->select['users'] = datamapper\AuditLogMapper::getInstance()->getUsers();
		$this->select['entities'] = datamapper\AuditLogMapper::getInstance()->getEntities();
		$this->select['names'] = datamapper\AuditLogMapper::getInstance()->getEntityNames(null);

		header('Content-Type: text/html; charset=utf-8');
		$this->outputPage('index.tpl');
	}

	public function handleAjax() {

		$this->callActionHandler();

		$this->tpl->assign('template', 'logs/auditLogAjax.tpl');
		$this->outputAjaxPage('ajax.tpl');
	}

	protected function viewAuditLogAction() {

		$id = $this->request->getInt('auditLogID', request\REQUEST_GET);
		$this->parameters['entry'] = datamapper\AuditLogMapper::getInstance()->getById($id);
		$this->parameters['subAuditLogs'] = array(
				'logEntries' => $this->parameters['entry']->getSubAuditLogs()
		);
	}

	/**
	 * Get names for an entity
	 *
	 * @author        Jonas Metzener <jonas.metzener@adfinis-sygroup.ch>
	 * @returns       array
	 */
	protected function getEntityNamesAction() {
		$entity = $this->request->getString('entity', request\REQUEST_GET);

		if($entity == 'all' || empty($entity)) {
			$entity = null;
		}

		$this->select['names'] = datamapper\AuditLogMapper::getInstance()->getEntityNames($entity);
	}

	/**
	 * Shows audit log according to filter criteria
	 *
	 * @author        Jonas Metzener <jonas.metzener@adfinis-sygroup.ch>
	 * @returns       void
	 */

	protected function showAuditLogAction() {
		$dateFrom   = new \Zend_Date(
			$this->request->getString('dateFrom'),
			\Zend_Date::ISO_8601
		);
		$dateTo     = new \Zend_Date(
			$this->request->getString('dateTo'),
			\Zend_Date::ISO_8601
		);
		// add 24h hours, or else it'll be $dateTo 00:00
		$dateTo->add('24', \Zend_Date::HOUR);

		$timeFrom   = $this->getTime($this->request->getString('timeFrom'));
		$timeTo     = $this->getTime($this->request->getString('timeTo'));

		$entity     = $this->request->getString('entity');
		$name       = $this->request->getString('name');
		$user       = $this->request->getString('user');
		$operation  = $this->request->getString('operation');

		$auditEntries = datamapper\AuditLogMapper::GetInstance()->getAll(
			$dateFrom,
			$dateTo,
			$timeFrom,
			$timeTo,
			$entity,
			$name,
			$user,
			$operation
		);

		$this->parameters['logEntries'] = $auditEntries;
	}

	/**
	 * Check the time and return it
	 *
	 * @author        Stefan Heinemann <stefan.heinemann@adfinis-sygroup.ch>
	 * @param         string $time The Time
	 * @returns       string
	 */
	private function getTime($time) {
		if (!preg_match('/^(\d{1,2}):(\d{2})$/', $time, $matches)) {
			return null;
		}

		$hours   = $matches[1] > 23 ? 23 : $matches[1];
		$minutes = $matches[2] > 59 ? 59 : $matches[2];

		return sprintf("%02d:%02d", $hours, $minutes);
	}
}
