<?php

namespace ch\monitoring\controller;

use org\adfinis\framework\request;
use ch\monitoring\datamapper;
use ch\monitoring\model;

/**
 * Handle customer information page requests
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @todo by denis:   still needed?
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class CustomerInformationController extends ProtectedController {

	/**
	 * Handles GET requests
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function handleGET() {
		$this->setHeaderTitle(tr("Customer information"));

		$id = $this->request->getInt('id', request\REQUEST_GET);
		if (!empty($id)) {
			$this->parameters['customer'] = datamapper\CustomerMapper::getInstance()->getByID($id);
		}

		$this->addScriptFile('js/ajaxCustomers.js', self::SCRIPT_POSITION_TOP);
		$this->tpl->assign('template', 'customers/customersInformation.tpl');

		header('Content-Type: text/html; charset=utf-8');
		$this->outputPage('index.tpl');
	}

	/**
	 * Handles AJAX requests
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function handleAJAX() {
		header('Content-Type: application/json; charset=utf-8');

		switch ($this->action) {
			case 'saveInformation':
				$this->saveInformation();
				break;
			default:
				$this->assignAJAX();
		}

		$this->tpl->assign('template', 'customers/customersInformationAjax.tpl');
		$this->outputAjaxPage('ajax.tpl');
	}

	/**
	 * Verifies the user permissions
	 *
	 * Depends on the page, subpage and/or action
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       bool
	 */
	public function hasPermission() {
		$id = $this->request->getInt('id', request\REQUEST_GET);
		if (empty($id)) {
			$id = $this->request->getInt('id');
		}
		$customer = datamapper\CustomerMapper::getInstance()->getByID($id);

		$password = $this->request->getString('password', request\REQUEST_GET);
		if (empty($password)) {
			$password = $this->request->getString('password');
		}
		$this->parameters['password'] = $password;

		return !empty($id) && !empty($password) && $customer->verifyPassword($password);
	}

	/**
	 * Assigns variables for AJAX requests
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	private function assignAJAX() {
		$id = $this->request->getInt('id');
		$this->parameters['customer'] = datamapper\CustomerMapper::getInstance()->getByID($id);
	}

	/**
	 * Save customer information
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	private function saveInformation() {
		$customerInformation = new model\CustomerInformation();

		$customerInformation->id                = $this->request->getInt('id');
		$customerInformation->name              = $this->request->getString('name');
		$customerInformation->address           = $this->request->getString('address');
		$customerInformation->contactTechnical  = $this->request->getString('contact_technical');
		$customerInformation->contactCommercial = $this->request->getString('contact_commercial');
		$customerInformation->phoneRegular      = $this->request->getString('phone_regular');
		$customerInformation->phoneEmergency    = $this->request->getString('phone_emergency');
		$customerInformation->comment           = $this->request->getString('comment');
		$customerInformation->mayContact        = $this->request->keyExists('may_contact');

		$customerInformation->getMapper()->save($customerInformation);
		$this->parameters['customer'] = datamapper\CustomerMapper::getInstance()->getByID($customerInformation->id);
	}
}
