<?php

namespace ch\monitoring\controller;

use org\adfinis\framework\request;
use org\adfinis\framework\exceptions\UserException;
use ch\monitoring\util;
use ch\monitoring\datamapper;
use ch\monitoring\model;

/**
 * Handle Graph page requests
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class GraphController extends ProtectedController {

	/**
	 * Calls the parent constructor
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         org\adfinis\framework\request\RequestInterface $request
	 * @param         array $urlMatch
	 */
	public function __construct($request, $urlMatch) {
		parent::__construct($request, $urlMatch);
	}

	/**
	 * Handles GET requests
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * throws         UserException
	 * @returns       void
	 */
	public function handleGET() {
		$type       = $this->request->getString('type', request\REQUEST_GET);
		$customerId = $this->request->getInt('customerId', request\REQUEST_GET);
		$width      = $this->request->getInt('width', request\REQUEST_GET);
		$height     = $this->request->getInt('height', request\REQUEST_GET);

		if ($customerId == null) {
			throw new UserException(
				tr("Customer id is missing")
			);
		}

		$customer = datamapper\CustomerMapper::getInstance()->getByID($customerId);
		$customer->enforceReadPermission(
			model\Permission::ALERTS_READ
		);

		util\Graph::drawAlerts($type, $customerId, $width, $height);
	}
}
