<?php

namespace ch\monitoring\controller;

use org\adfinis\framework\request;
use org\adfinis\framework\config\ConfManager;
use org\adfinis\framework\exceptions\UserException;
use ch\monitoring\util;
use ch\monitoring\Application;
use ch\monitoring\datamapper;
use ch\monitoring\model;
use ch\monitoring\Version;

/**
 * Handle home page requests
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class HomeController extends ProtectedController {

	/**
	 * Calls the parent constructor
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         org\adfinis\framework\request\RequestInterface $request
	 * @param         array $urlMatch
	 */
	public function __construct($request, $urlMatch) {
		parent::__construct($request, $urlMatch);
	}

	/**
	 * Handles GET requests
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function handleGET() {
		header('Content-Type: text/html; charset=utf-8');
		$this->setHeaderTitle(tr("Home"));

		$permission = null;
		if ($this->session->user->hasPermission(model\Permission::ALERTS_READ)) {
			$permission = model\Permission::ALERTS_READ;
		}
		elseif ($this->session->user->hasPermission(model\Permission::HOSTS_READ)) {
			$permission = model\Permission::HOSTS_READ;
		}

		if (
			$this->session->user->hasIdentifier()
			&&
			$permission !== null
		) {
			$this->parameters['newAlerts'] = datamapper\AlertMapper::getInstance()->getAll(
				true,
				null,
				null,
				null,
				null,
				null,
				null,
				false,
				$permission
			);
			$rpcClient = Application::getRPCClientInstance(
				ConfManager::getVar('sm','RPC', 'lcAppName'),
				ConfManager::getVar('sm','RPC', 'lcQueues')
			);
			$type = 'get_version';
			$data = json_encode(array(
			));
			$resultId = $rpcClient->putRequest($type, $data);
			try {
				$data = $rpcClient->getResult($resultId);
				if (isset($data->exception)) {
					throw new UserException($data->exception);
				}
				$this->parameters['rpcServerVersion'] = $data->{'version'};
			}
			catch (\Exception $e) {
				$this->parameters['rpcServerVersion'] = tr('Unable to get RPC server version');
			}
		}

		$this->tpl->assign('template', 'main/home.tpl');
		$this->parameters['version'] = Version::getVersion();
		$this->outputPage('index.tpl');
	}
}
