<?php

namespace ch\monitoring\controller;

use org\adfinis\framework\request;
use org\adfinis\framework\exceptions\UserException;
use ch\monitoring\datamapper;
use ch\monitoring\model;
use ch\monitoring\Application;
use ch\monitoring\util;

/**
 * Handle hosttype page requests
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class HostTypeController extends ProtectedController {

	/**
	 * Handles GET requests
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function handleGET() {
		header('Content-Type: text/html; charset=utf-8');

		//$this->addScriptFile('js/ajaxForm.js', self::SCRIPT_POSITION_TOP);

		$this->session->user->enforcePermission(
			model\Permission::HOSTS_MASTER
		);

		$this->setHeaderTitle(tr("Host types"));
		$this->parameters['types'] = datamapper\HostTypeMapper::getInstance()->getAll();
		$this->tpl->assign('template', 'hosts/hostTypes.tpl');
		$this->tpl->assign('templateSubmenu', 'submenu.tpl');

		$this->outputPage('index.tpl');
	}

	/**
	 * Handles AJAX requests
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function handleAJAX() {
		header('Content-Type: application/json; charset=utf-8');
		
		$this->callActionHandler();

		$this->tpl->assign('template', 'hosts/hostTypesAjax.tpl');
		$this->outputAjaxPage('ajax.tpl');
	}

	/**
	 * Create a new hostType and load the form
	 *
	 * @author        Stefan Heinemann <stefan.heinemann@adfinis-sygroup.ch>
	 */
	protected function addFormAction() {
		$hostType = new model\HostType();
		$hostType->allowRead();
		$this->parameters['hostType'] = $hostType;
	}

	/**
	 * Load the hostType that is to edit and load the form
	 *
	 * @author        Stefan Heinemann <stefan.heinemann@adfinis-sygroup.ch>
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 */
	protected function editAction() {
		$id = $this->request->getInt('id', request\REQUEST_GET);

		$hostType = datamapper\HostTypeMapper::getInstance()->getByID($id);
		$hostType->enforceReadPermission(
			model\Permission::HOSTS_MASTER
		);

		$this->parameters['hostType'] = $hostType;
	}

	/**
	 * Add a new HostType
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function addAction() {
		$hostType = new model\HostType();
		$hostType->allowWrite(model\Permission::HOSTS_MASTER);

		$this->saveHostType($hostType);
	}

	/**
	 * After editing, save the HostType
	 *
	 * @author        Stefan Heinemann <stefan.heinemann@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function saveAction() {
		$id = $this->request->getInt('id', request\REQUEST_POST);
		$hostType = datamapper\HostTypeMapper::getInstance()->getByID($id);
		$hostType->enforceWritePermission(model\Permission::HOSTS_MASTER);

		$this->saveHostType($hostType);
	}
	
	/**
	 * Save a HostType
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         model\HostType $hostType
	 * @returns       void
	 */
	private function saveHostType($hostType) {
		$hostType->name  = $this->request->getString('name');
		$hostType->short = $this->request->getString('short');
		$hostType->save();

		$this->parameters['hostType'] = $hostType;
		$this->parameters['types'][] = $hostType;
	}

	/**
	 * Delete a HostType
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function deleteAction() {
		$id = $this->request->getInt('id');

		if (empty($id)) {
			throw new UserException(
				tr("HostType id is missing")
			);
		}

		$hostType = datamapper\HostTypeMapper::getInstance()->getByID($id);
		$hostType->enforceWritePermission(model\Permission::HOSTS_MASTER);
		$hostType->delete();
	}
}
