<?php

namespace ch\monitoring\controller;

use ch\monitoring\datamapper;
use ch\monitoring\util;
use ch\monitoring\model;
use ch\monitoring\Application;
use org\adfinis\framework\request;
use org\adfinis\framework\exceptions\UserException;

/**
 * Handle monitoring (icinga/nagios) page requests
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class MonitoringController extends ProtectedController {

	/**
	 * Handles GET requests
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function handleGET() {
		// No get implemented
	}

	/**
	 * Handles AJAX requests
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function handleAJAX() {
		header('Content-Type: application/json; charset=utf-8');

		$this->callActionHandler();
	}

	/**
	 * Check a host
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @throws        UserException
	 * @returns       void
	 */
	protected function hostCheckAction() {
		$hostId = $this->request->getInt('hostId');

		if (empty($hostId)) {
			throw new UserException(
				tr("Host id is missing")
			);
		}

		$host = datamapper\HostMapper::getInstance()->getByID($hostId);
		$host->enforceReadPermission(
			model\Permission::HOSTS_READ
		);

		$data = array(
			"SCHEDULE_FORCED_HOST_CHECK",
			$host->hostname,
			time()
		);

		util\Monitoring::sendCommand($data);

		$data = array(
			"SCHEDULE_FORCED_HOST_SVC_CHECKS",
			$host->hostname,
			time()
		);

		util\Monitoring::sendCommand($data);
	}
	
	/**
	 * Check a service
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @throws        UserException
	 * @returns       void
	 */
	protected function serviceCheckAction() {
		$instanceId = $this->request->getInt('instanceId');

		if (empty($instanceId)) {
			throw new UserException(
				tr("Service instance id is missing")
			);
		}

		$instance = datamapper\HostServiceInstanceMapper::getInstance()->getByID($instanceId);
		$instance->enforceReadPermission(
			model\Permission::HOSTS_READ
		);

		$data = array(
			"SCHEDULE_FORCED_SVC_CHECK",
			$instance->getHost()->hostname,
			$instance->getObjectName(),
			time()
		);

		util\Monitoring::sendCommand($data);
	}

	/**
	 * Restart monitoring
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function restartAction() {
		$this->session->user->enforcePermission(
			model\Permission::MONITORING_MASTER
		);

		$data = array(
			"RESTART_PROGRAM"
		);

		util\Monitoring::sendCommand($data);
	}

	/**
	 * Hide changes
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function hideChangesAction() {
		Application::unsetHostChanged();
	}
}
