<?php

namespace ch\monitoring\controller;

use org\adfinis\framework\request;
use org\adfinis\framework\exceptions\UserException;
use ch\monitoring\util;
use ch\monitoring\datamapper;
use ch\monitoring\model;

/**
 * Handle PNP4Nagios page requests
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class PNP4NagiosController extends ProtectedController {

	/**
	 * Handles GET requests
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * throws         UserException
	 * @returns       void
	 */
	public function handleGET() {
		$this->callActionHandler();
	}

	/**
	 * Outputs a graph for a host
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @throws        UserException
	 * @returns       void
	 */
	protected function getHostGraphAction() {
		$hostId   = $this->request->getInt('hostId', request\REQUEST_GET);
		$dateFrom = $this->request->getInt('dateFrom', request\REQUEST_GET);
		$dateTo   = $this->request->getInt('dateTo', request\REQUEST_GET);

		$now = new \Zend_Date();
		if ($dateTo > $now->get(\Zend_Date::TIMESTAMP)) {
			$dateTo = $now->get(\Zend_Date::TIMESTAMP);
		}

		if ($dateFrom > $dateTo) {
			throw new UserException(
				tr("Start date is more recent than end date or in the future")
			);
		}

		$host = datamapper\HostMapper::getInstance()->getByID(
			$hostId
		);

		$host->enforceReadPermission(
			model\Permission::REPORTS
		);

		try {
			$graph = $host->getGraph($dateFrom, $dateTo);

			header(
				sprintf("Content-Type: %s", $graph->getHeader('Content-Type'))
			);

			echo $graph->getBody();
		}
		catch (\RuntimeException $e) {
			util\PNP4Nagios::drawErrorImage(
				sprintf(
					"No data available for host %s",
					$host->hostname
				)
			);
		}
	}

	/**
	 * Outputs a graph for a service
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @throws        UserException
	 * @returns       void
	 */
	protected function getServiceGraphAction() {
		$hostServiceInstanceId = $this->request->getInt('hostServiceInstanceId', request\REQUEST_GET);
		$dateFrom              = $this->request->getInt('dateFrom', request\REQUEST_GET);
		$dateTo                = $this->request->getInt('dateTo', request\REQUEST_GET);

		$now = new \Zend_Date();
		if ($dateTo > $now->get(\Zend_Date::TIMESTAMP)) {
			$dateTo = $now->get(\Zend_Date::TIMESTAMP);
		}

		if ($dateFrom > $dateTo) {
			throw new UserException(
				tr("Start date is more recent than end date or in the future")
			);
		}

		$hostServiceInstance = datamapper\HostServiceInstanceMapper::getInstance()->getByID(
			$hostServiceInstanceId
		);

		$hostServiceInstance->enforceReadPermission(
			model\Permission::REPORTS
		);

		try {
			$graph = $hostServiceInstance->getGraph($dateFrom, $dateTo);

			header(
				sprintf("Content-Type: %s", $graph->getHeader('Content-Type'))
			);

			echo $graph->getBody();
		}
		catch (\RuntimeException $e) {
			util\PNP4Nagios::drawErrorImage(
				sprintf(
					"No data available for service %s (%s)",
					$hostServiceInstance->getHostService()->getService()->name,
					$hostServiceInstance->name
				)
			);
		}

		exit;
	}
}
