<?php

namespace ch\monitoring\controller;

use org\adfinis\framework\exceptions\ForbiddenException;
use org\adfinis\framework\utils\URLHelper;

/**
 * Abstract class that you can use as a base to implement object-oriented controller classes
 *
 * The protected version includes a hasPermission() method which is called and checked to be true.
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       BSD 3-Clause
 **/
abstract class ProtectedController extends BaseController {

	/**
	 * Calls the parent constructor
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         org\adfinis\framework\request\RequestInterface $request
	 * @param         array $urlMatch
	 */
	public function __construct($request, $urlMatch) {
		parent::__construct($request, $urlMatch);
	}

	/**
	 * Handles the request
	 *
	 * Depending on request type, calls
	 * - handleGET(),
	 * - handlePOST(),
	 * - handleAJAX(),
	 * - handleExternal()
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @throws        ForbiddenException
	 * @returns       void
	 */
	public function handle() {
		if (!$this->hasPermission()) {
			throw new ForbiddenException(tr('Access denied'));
		}

		return parent::handle();
	}

	/**
	 * Verify whether the user is authorized to access the system
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       bool
	 */
	public function hasPermission() {
		return $this->session->user->hasIdentifier();
	}
}
