<?php

namespace ch\monitoring\controller;

use ch\monitoring\Application;
use org\adfinis\framework\request;
use org\adfinis\framework\exceptions\UserException;
use ch\monitoring\datamapper;
use ch\monitoring\model;
use ch\monitoring\util;
use org\adfinis\framework\config\ConfManager;

/**
 * Handle setting page requests
 *
 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class SettingController extends ProtectedController {

	/**
	 * Handles GET requests
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
     * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @return        void
	 */
	public function handleGET() {
		header('Content-Type: text/html; charset=utf-8');

		$this->session->user->enforcePermission(
			model\Permission::GLOBAL_SETTINGS
		);
		
		$this->parameters['erroremail'] = util\Setting::get('erroremail', '');
		$this->parameters['avoidalert'] = util\Setting::monitoringIsDisabled();


        $roles = array_filter(
            datamapper\RoleMapper::getInstance()->getAll()->toArray(),
            function($r) { return !$r->isGlobal(); }
        );
		$this->parameters['roles'] = util\IteratorUtil::getKeyValueArray($roles);
		$this->parameters['defaultRoleId'] = util\Setting::get('defaultRoleId', 0);

		$this->setHeaderTitle(tr("Settings"));
		$this->tpl->assign('template', 'setting.tpl');
		$this->tpl->assign('templateSubmenu', 'submenu.tpl');
		$this->outputPage('index.tpl');
	}

	/**
	 * Handles POST Requests
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
     * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @return        void
	 */
	public function handlePOST() {
		$user = $this->session->user;
		$user->enforcePermission(model\Permission::GLOBAL_SETTINGS);

		$defaultRoleId = $this->request->getInt('defaultRoleId');
        try {
		    $role = datamapper\RoleMapper::getInstance()->getById($defaultRoleId);
		    $role->allowRead();
            util\Setting::set('defaultRoleId', $defaultRoleId);
        }
        catch (\OutOfBoundsException $e) {
            $this->addErrorMessage(tr('Invalid role selected'));
        }
        

		$email = $this->request->getString('erroremail');

		$validator = new \Zend_Validate_EmailAddress();
		if (!$validator->isValid($email)) {
			$this->addErrorMessage(tr('Invalid e-mail address'));
		}
		else {
			util\Setting::set('erroremail', $email);
		}
		
		$date = new \Zend_Date();
		$date->add(2, \Zend_Date::HOUR);
		if ($this->request->keyExists('avoidalert')) {
			util\Setting::set('avoidalert_date', $date->get(\Zend_Date::ISO_8601));
		}
		else {
			util\Setting::set('avoidalert_date', '');
		}

		$this->parameters['avoidAlerting'] = util\Setting::monitoringIsDisabled();
		
		$this->handleGET();
	}

	/**
	 * Handles AJAX requests
	 *
	 * @returns       void
	 */
	public function handleAJAX() {
		header('Content-Type: application/json; charset=utf-8');

		$this->callActionHandler();

		$this->outputAjaxPage('ajax.tpl');
	}

	/**
	 * Returns the states of notifications as
	 * assignements to the ajax template.
	 *
	 * @returns       void
	 */
	protected function getNotificationStatesAction() {
		$this->parameters['hostChanged']           = Application::getRegistry()->get('hostChanged');
		$this->parameters['satelliteChanged']      = Application::getRegistry()->get('satelliteChanged');
		$this->parameters['allSatellitesChanged']  = Application::getRegistry()->get('allSatellitesChanged');
	}
}
