<?php

namespace ch\monitoring\controller;

use ch\monitoring\datamapper;
use ch\monitoring\model;

/**
 * Base Controller for the UserController
 *
 * @copyright Adfinis SyGroup AG 2012
 * @license   LGPLv3
 **/
abstract class UserBaseController extends ProtectedController
{
	/**
	 * Assignes the contact information to a given user
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 *
	 * @param         model\User $user
	 *
	 * @returns       void
	 */
	protected function assignUserContact($user) {
		$fieldKeyMapping = array(
			'email',
			'phone',
			'sms',
			'jabber',
			'mattermost'
		);

		foreach ($fieldKeyMapping as $field) {
			$value = $this->request->getString($field) ?: null;
			if ($user->isMutable($field)) {
				$user->$field = $value;
			}
		}
	}


	/**
	 * Assigns the alert settings to a given user
	 *
	 * @param         model\User $user
	 * @returns       void
	 */
	protected function assignUserAlertSettings($user) {
		datamapper\AlertNotificationExcludeMapper::getInstance()->clearByUserId($user->id);
		if($this->request->keyExists('alertTypeExclude')) {
			$customers = datamapper\CustomerMapper::getInstance()->getAll(
				model\Permission::ALERTS_READ
			);
			$alertTypes = datamapper\SLAActionMapper::getInstance()->getAll();
			$alertTypesToExclude = $this->request->getRaw('alertTypeExclude');

			foreach($customers as $customer) {
				foreach($alertTypes as $alertType) {
					if (isset($alertTypesToExclude[$alertType->id]) &&
						isset($alertTypesToExclude[$alertType->id][$customer->id])
					) {
						$alertExclude = new model\AlertNotificationExcludeUser();

						$alertExclude->userId = $user->id;
						$alertExclude->customerId = $customer->id;
						$alertExclude->slaActionId = $alertType->id;

						$alertExclude->save();
					}
				}
			}
		}
	}

	/**
	 * Assigns the alert template settings to a given user
	 *
	 * @param         model\User $user
	 *
	 * @returns       void
	 */
	protected function assignUserAlertTemplateSettings($user) {
		if ($this->request->keyExists('alertType')) {
			datamapper\AlertTemplateUserMapper::getInstance()->clearByUSerId($user->id);

			$alertTypes = datamapper\SLAActionMapper::getInstance()->getAll();
			$enabledAlertTypes = $this->request->getRaw('alertType');

			foreach ($alertTypes as $alertType) {
				if ($enabledAlertTypes[$alertType->id] > 0) {
					$alertTemplateUser = new model\AlertTemplateUser();
					$alertTemplateUser->userId = $user->id;
					$alertTemplateUser->templateId = $enabledAlertTypes[$alertType->id];
					$alertTemplateUser->slaActionId = $alertType->id;
					$alertTemplateUser->save();
				}
			}
		}
	}
}
