<?php

namespace ch\monitoring\datamapper;

use org\adfinis\framework\exceptions\UserException;
use org\adfinis\framework\datamapper\Mapper;
use org\adfinis\framework\datamapper\IdentityMap;
use org\adfinis\framework\db\sql;
use ch\monitoring\model;
use ch\monitoring\Application;
use ch\monitoring\db\SortingPolicyIterator;

/**
 * Datamapper for the AlertNotificationExclude model.
 *
 * @copyright     Adfinis SyGroup AG 2014
 * @license       LGPLv3
 **/
class AlertNotificationExcludeMapper extends Mapper {

	/**
	 * AlertNotificationExclude object to implement singleton
	 *
	 * @var            ch\monitoring\datamapper\AlertNotificationExclude $singleton
	 */
	private static $singleton;

	/**
	 * Class constructor
	 */
	public function __construct() {
		parent::__construct('ch\monitoring\model\AlertNotificationExclude');
	}

	/**
	 * Implements a singleton
	 *
	 * @returns       ch\hplus\datamapper\AlertNotificationExclude
	 */
	public static function getInstance() {
		if (!self::$singleton) {
			self::$singleton = new self();
		}

		return self::$singleton;
	}

	/**
	 * Returns a single AlertNotificationExclude object identified
	 * by the given SQL query.
	 *
	 * Runs the given query, initialises a AlertNotificationExclude
	 * object and returns it
	 *
	 * @throws        \OutOfBoundsException if the AlertTemplateUser cannot be found
	 * @param         string $query
	 * @param         array  $params
	 *
	 * @returns       ch\monitoring\model\AlertNotificationExclude
	 */
	protected function getByQuery($query, $params) {
		$statement = Application::getDbInstance()->prepare($query);
		$statement->execute($params);

		$data = $statement->fetch();

		if (!$data) {
			throw new \OutOfBoundsException(
				sprintf(
					'%s: %s',
					tr('Could not find AlertNotificationExclude with these parameters'),
					var_export($params, true)
				)
			);
		}

		$user = new model\AlertNotificationExcludeUser();
		$user->fillFromRowData($data);

		return $user;
	}

	/**
	 * Returns a DBIterator of 
	 * AlertNotificationExclude which can be
	 * found by a SQLCondition.
	 *
	 * @param         sql\WhereGroup $conditions optional
	 * @param         array $joins optional
	 * @param         array $paramaters optional
	 * @param         string $permissionName A permission to restrict users to
	 *
	 * @returns       org\adfinis\framework\db\DbIterator
	 */
	protected function getByCondition(
		sql\WhereGroup $conditions = null,
		Array $joins = array(),
		Array $parameters = array()
	) {
		if (is_null($conditions)) {
			$conditions = new sql\WhereGroup();
			$conditions->setOperand('AND');
		}

		$searchQuery = sprintf("
				SELECT DISTINCT
					`AlertNotification_Exclude_User`.`id`
				FROM
					`AlertNotification_Exclude_User`
				%s
				%s
			",
			implode("\n", $joins),
			$conditions
		);

		$selectQuery = "SELECT * FROM `AlertNotification_Exclude_User`";
		$list = SortingPolicyIterator::create(
			$searchQuery,
			$selectQuery,
			'ch\monitoring\model\AlertNotificationExclude',
			$parameters
		);

		$list->addOrderVariant('id.ASC',  '`User`.`id` ASC');
		$list->addOrderVariant('id.DESC', '`User`.`id` DESC');

		return $list;
	}

	/**
	 * Load a AlertNotificationExclude by id
	 *
	 * @param         int $id
	 *
	 * @returns       ch\monitoring\model\AlertNotificationExclude
	 */
	public function getByID($id) {
		$map = IdentityMap::getInstance(get_called_class());
		if (!$map->exists(array('id' => $id))) {
			$query = '
				SELECT
					*
				FROM
					`AlertNotification_Exclude_User`
				WHERE
					`id` = ?
				LIMIT
					1
			';

			$alertNotificationExcludeUser = $this->getByQuery(
				$query,
				array((int)$id)
			);

			$map->set($alertNotificationExcludeUser);
		}

		return $map->get(array('id' => $id));
	}

	/**
	 * Delete all AlertNotificationExclude by userId
	 *
	 * @param         int $userId
	 * @returns       ch\monitoring\model\AlertNotificationExclude
	 */
	public function clearByUserId($userId) {
		Application::getDbInstance()->delete(
			'AlertNotification_Exclude_User',
			sprintf('`userId` = %d', $userId)
		);
	}

	/**
	 * Returns the AlertNotificationExclude object
	 * that matches the param OR returns
	 * an unsaved preinitialized AlertNotificationExclude
	 *
	 * @param         int $userId
	 * @param         int $customerId
	 * @param         int $slaAction
	 *
	 * @returns       ch\symonitoring\model\AlertNotificationExclude
	 */
	public function getByNotificationType($userId, $customerId, $slaActionId) {
		try {
			$selectQuery = '
				SELECT
					*
				FROM
					`AlertNotification_Exclude_User`
				WHERE
					`AlertNotification_Exclude_User`.`userId` = ?
				AND
					`AlertNotification_Exclude_User`.`customerId` = ?
				AND
					`AlertNotification_Exclude_User`.`slaActionId` = ?
			';
			return $this->getByQuery($selectQuery, array(
				$userId,
				$customerId,
				$slaActionId
			));
		} catch(\Exception $e) {
			return null;
		}
	}

	/**
	 * Saves AlertNotificationExclude information
	 *
	 * If the AlertNotificationExclude object is new,
	 * it is INSERTed, otherwise UPDATEd.
	 *
	 * @param         \org\adfinis\framework\model\Entity $alertNotificationExcludeUser
	 * @returns       array
	 */
	public function save(\org\adfinis\framework\model\Entity $alertNotificationExcludeUser) {
		$fieldDataMapping = array(
			'id'                    => $alertNotificationExcludeUser->id,
			'userId'                => $alertNotificationExcludeUser->userId,
			'slaActionId'           => $alertNotificationExcludeUser->slaActionId,
			'customerId'            => $alertNotificationExcludeUser->customerId,
		);

		if ($alertNotificationExcludeUser->hasIdentifier()) {
			Application::getDbInstance()->update(
				'AlertNotification_Exclude_User',
				$fieldDataMapping,
				sprintf('id = %d', $alertNotificationExcludeUser->id)
			);
		}
		else {
			Application::getDbInstance()->insert(
				'AlertNotification_Exclude_User',
				$fieldDataMapping
			);
			$alertNotificationExcludeUser->id = Application::getDbInstance()->lastInsertId();
		}

		return $alertNotificationExcludeUser->getIdentifier();
	}

	/**
	 * Delete a AlertNotificationExclude
	 *
	 * @param         array $identifier
	 *
	 * @throws        UserException
	 * 
	 * @returns       void
	 */
	public function delete($identifier) {
		try {
			Application::getDbInstance()->beginTransaction();

			Application::getDbInstance()->delete(
				'AlertNotification_Exclude_User',
				sprintf('`id` = %d', $identifier['id'])
			);

			Application::getDbInstance()->commit();
		}
		catch (\Zend_Db_Statement_Exception $e) {
			if ($e->getCode() == 23000) {
				throw new UserException(
					tr("This AlertNotificationExclude cannot be deleted because of dependencies.")
				);
			}
			else {
				throw $e;
			}
		}

	}
}
