<?php

namespace ch\monitoring\datamapper;

use ch\monitoring\Application;
//use ch\monitoring\db\DataTableIterator;
use ch\monitoring\db\SortingPolicyIterator;
use ch\monitoring\model;
use ch\monitoring\util;
use org\adfinis\framework\config\ConfManager;
use org\adfinis\framework\datamapper\Mapper;
use org\adfinis\framework\db\sql;
use org\adfinis\framework\exceptions\UserException;
use ch\monitoring\view\datatable;

/**
 * Datamapper for the BREComponentApplication model.
 *
 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2015
 * @license       LGPLv3
 **/
class BREComponentApplicationMapper extends Mapper {

	/**
	 * Identity map for BREComponentApplication (by database ID)
	 *
	 * @var           array $identityById
	 */
	private static $identityById = array();

	/**
	 * BREComponentApplication object to implement singleton
	 *
	 * @var            BREComponentApplicationMapper $singleton
	 */
	private static $singleton;

	/**
	 * Class constructor
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 */
	public function __construct() {
		parent::__construct('ch\monitoring\model\BREComponentApplication');
	}

	/**
	 * Implements a singleton
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @returns       ch\hplus\datamapper\BREComponentApplicationMapper
	 */
	public static function getInstance() {
		if (!self::$singleton) {
			self::$singleton = new self();
		}

		return self::$singleton;
	}

	/**
	 * Load a BREComponentApplication by id
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         int $id
	 * @returns       ch\monitoring\model\BREComponentApplication
	 */
	public function getByID($id) {
		// TODO: use the API written by TobiasF
		return null;
	}

	/**
	 * Returns a single BREComponentApplication object identified by the given SQL query
	 *
	 * Runs the given query, initialises a BREComponentApplication object and returns it
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @throws        \OutOfBoundsException if the BREComponentApplication cannot be found
	 * @param         string $query
	 * @param         array  $params
	 * @returns       ch\monitoring\model\BREComponentApplication
	 */
	protected function getByQuery($query, $params) {
		$statement = Application::getDbInstance()->prepare($query);
		$statement->execute($params);

		$data = $statement->fetch();

		if (!$data) {
			throw new \OutOfBoundsException(
				sprintf(
					'%s: %s',
					tr('Could not find business rule engine services with these parameters'),
					var_export($params, true)
				)
			);
		}

		$breservice = new model\BREComponentApplication();
		$breservice->fillFromRowData($data);

		return $breservice;
	}

	/**
	 * Load all BREComponentApplications
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         int $customerId Optional. The Customer the BREComponentApplication shall belong to.
	 * @param         string $permissionName Defaults to
	 * @return        org\adfinis\framework\db\DbIterator
	 */
	public function getAll(
		$customerId = null,
		$permissionName = model\Permission::BREAPPLICATION_READ
	) {
		// TODO: use the API written by TobiasF
		return null;
	}

	/**
	 * Load business rule engine components
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         int $customerId Optional. The Customer the BREComponentApplication shall belong to.
	 * @param         string $permissionName Defaults to
	 * @return        org\adfinis\framework\db\DbIterator
	 */
	public function getComponents(
		$customerId = null,
		$permissionName = model\Permission::BREAPPLICATION_WRITE
	) {
		// TODO: use the API written by TobiasF
		// filter using applicationId (since it's the same for all the components of an app)
		return null;
	}

	/**
	 * Load all possible services
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         int $customerId Optional. The Customer the BREComponentApplication shall belong to.
	 * @param         string $permissionName Defaults to
	 * @return        org\adfinis\framework\db\DbIterator
	 */
	public function getComponentApplications(
		$customerId = null,
		$permissionName = model\Permission::BREAPPLICATION_WRITE
	) {
		// TODO: use the API written by TobiasF
		// filter using customerId
		return null;
	}

	/**
	 * Saves BREComponentApplication information
	 *
	 * If the BREComponentApplication object is new, it is INSERTed, otherwise UPDATEd.
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         \org\adfinis\framework\model\Entity $breservice
	 * @throws        UnexpectedValuException
	 * @returns       array
	 */
	public function save(\org\adfinis\framework\model\Entity $breapplication) {

		$rpcClient = Application::getRPCClientInstance(
			ConfManager::getVar('sm','RPC', 'lcAppName'),
			ConfManager::getVar('sm','RPC', 'lcQueues')
		);

		// TODO: set the right variable names
		$resultId = $rpcClient->putRequest(
			'symonitoring_bpe.add_application_to_component',
			array(
				"component_id" => $breapplication->componentId,
				"application_id"   => $breapplication->componentapplicationId
			)
		);

		$data = $rpcClient->getResult($resultId, 10); // 10 is the timeout

		if (isset($data->exception)) {
			throw new UserException($data->exception->message, $data->exception->code);
		}

		return $breapplication->getIdentifier();
	}

	/**
	 * Delete a BREComponentApplication
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         array $identifier
	 * @returns       void
	 */
	public function deleteComponentApplication($componentId, $applicationId) {
		$rpcClient = Application::getRPCClientInstance(
			ConfManager::getVar('sm','RPC', 'lcAppName'),
			ConfManager::getVar('sm','RPC', 'lcQueues')
		);

		$resultId = $rpcClient->putRequest(
			'symonitoring_bpe.remove_application_from_component',
			array(
				"component_id" => $componentId,
				"application_id" => $applicationId
			)
		);

		$data = $rpcClient->getResult($resultId, 10); // 10 is the timeout

		if (isset($data->exception)) {
			throw new UserException($data->exception->message, $data->exception->code);
		}
	}

	/**
	 * Delete a BREComponentApplication
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         array $identifier
	 * @returns       void
	 */
	public function delete($identifier) {
		// TODO: do something before deleting the service?
		// TODO: maybe use TobiasF API?
		Application::getDbInstance()->delete(
			'BREComponentApplication',
			sprintf('`id` = %d', $identifier['id'])
		);
	}
}
