<?php

namespace ch\monitoring\datamapper;

use ch\monitoring\Application;
//use ch\monitoring\db\DataTableIterator;
use ch\monitoring\db\SortingPolicyIterator;
use ch\monitoring\model;
use ch\monitoring\util;
use org\adfinis\framework\config\ConfManager;
use org\adfinis\framework\datamapper\Mapper;
use org\adfinis\framework\db\sql;
use org\adfinis\framework\exceptions\UserException;
use ch\monitoring\view\datatable;

/**
 * Datamapper for the BREHost model.
 *
 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2015
 * @license       LGPLv3
 **/
class BREHostMapper extends Mapper {

	/**
	 * Identity map for BREHost (by database ID)
	 *
	 * @var           array $identityById
	 */
	private static $identityById = array();

	/**
	 * BREHost object to implement singleton
	 *
	 * @var            BREHostMapper $singleton
	 */
	private static $singleton;

	/**
	 * Class constructor
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 */
	public function __construct() {
		parent::__construct('ch\monitoring\model\BREHost');
	}

	/**
	 * Implements a singleton
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @returns       ch\hplus\datamapper\BREHostMapper
	 */
	public static function getInstance() {
		if (!self::$singleton) {
			self::$singleton = new self();
		}

		return self::$singleton;
	}

	/**
	 * Load a BREHost by id
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         int $id
	 * @returns       ch\monitoring\model\BREHost
	 */
	public function getByID($id) {
		// TODO: use the API written by TobiasF
		return null;
	}

	/**
	 * Returns a single BREHost object identified by the given SQL query
	 *
	 * Runs the given query, initialises a BREHost object and returns it
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @throws        \OutOfBoundsException if the BREHost cannot be found
	 * @param         string $query
	 * @param         array  $params
	 * @returns       ch\monitoring\model\BREHost
	 */
	protected function getByQuery($query, $params) {
		$statement = Application::getDbInstance()->prepare($query);
		$statement->execute($params);

		$data = $statement->fetch();

		if (!$data) {
			throw new \OutOfBoundsException(
				sprintf(
					'%s: %s',
					tr('Could not find business rule engine hosts with these parameters'),
					var_export($params, true)
				)
			);
		}

		$brehost = new model\BREHost();
		$brehost->fillFromRowData($data);

		return $brehost;
	}

	/**
	 * Load all BREHosts
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         int $customerId Optional. The Customer the BREHost shall belong to.
	 * @param         string $permissionName Defaults to
	 * @return        org\adfinis\framework\db\DbIterator
	 */
	public function getAll(
		$customerId = null,
		$permissionName = model\Permission::BREAPPLICATION_READ
	) {
		// TODO: use the API written by TobiasF
		return null;
	}

	/**
	 * Load business rule engine components
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         int $customerId Optional. The Customer the BREHost shall belong to.
	 * @param         string $permissionName Defaults to
	 * @return        org\adfinis\framework\db\DbIterator
	 */
	public function getComponents(
		$customerId = null,
		$permissionName = model\Permission::BREAPPLICATION_WRITE
	) {
		// TODO: use the API written by TobiasF
		// filter using applicationId (since it's the same for all the components of an app)
		return null;
	}

	/**
	 * Load all possible hosts
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         int $customerId Optional. The Customer the BREHost shall belong to.
	 * @param         string $permissionName Defaults to
	 * @return        org\adfinis\framework\db\DbIterator
	 */
	public function getHosts(
		$customerId = null,
		$permissionName = model\Permission::BREAPPLICATION_WRITE
	) {
		// TODO: use the API written by TobiasF
		// filter using customerId
		return null;
	}

	/**
	 * Saves BREHost information
	 *
	 * If the BREHost object is new, it is INSERTed, otherwise UPDATEd.
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         \org\adfinis\framework\model\Entity $brehost
	 * @throws        UnexpectedValuException
	 * @returns       array
	 */
	public function save(\org\adfinis\framework\model\Entity $brehost) {

		$rpcClient = Application::getRPCClientInstance(
			ConfManager::getVar('sm','RPC', 'lcAppName'),
			ConfManager::getVar('sm','RPC', 'lcQueues')
		);

		// TODO: set the right variable names
		$resultId = $rpcClient->putRequest(
			'symonitoring_bpe.add_host_to_component',
			array(
				"component_id" => $brehost->componentId,
				"host_id"      => $brehost->hostId
			)
		);

		$data = $rpcClient->getResult($resultId, 10); // 10 is the timeout

		if (isset($data->exception)) {
			throw new UserException($data->exception->message, $data->exception->code);
		}

		return $brehost->getIdentifier();
	}

	/**
	 * Delete a BREHost for given component
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         array $identifier
	 * @returns       void
	 */
	public function deleteHost($componentId, $hostId) {
		$rpcClient = Application::getRPCClientInstance(
			ConfManager::getVar('sm','RPC', 'lcAppName'),
			ConfManager::getVar('sm','RPC', 'lcQueues')
		);

		$resultId = $rpcClient->putRequest(
			'symonitoring_bpe.remove_host_from_component',
			array(
				"component_id" => $componentId,
				"host_id" => $hostId
			)
		);

		$data = $rpcClient->getResult($resultId, 10); // 10 is the timeout

		if (isset($data->exception)) {
			throw new UserException($data->exception->message, $data->exception->code);
		}
	}

	/**
	 * Deletes a host.
	 * Currently not needed as everything gets handled over RPC.
	 *
	 * @param         array $identifier
	 */
	public function delete($identifier) {}
}
