<?php

namespace ch\monitoring\datamapper;

use ch\monitoring\Application;
//use ch\monitoring\db\DataTableIterator;
use ch\monitoring\db\SortingPolicyIterator;
use ch\monitoring\model;
use ch\monitoring\util;
use org\adfinis\framework\config\ConfManager;
use org\adfinis\framework\datamapper\Mapper;
use org\adfinis\framework\db\sql;
use org\adfinis\framework\exceptions\UserException;
use ch\monitoring\view\datatable;

/**
 * Datamapper for the BREService model.
 *
 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2015
 * @license       LGPLv3
 **/
class BREServiceMapper extends Mapper {

	/**
	 * Identity map for BREService (by database ID)
	 *
	 * @var           array $identityById
	 */
	private static $identityById = array();

	/**
	 * BREService object to implement singleton
	 *
	 * @var            BREServiceMapper $singleton
	 */
	private static $singleton;

	/**
	 * Class constructor
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 */
	public function __construct() {
		parent::__construct('ch\monitoring\model\BREService');
	}

	/**
	 * Implements a singleton
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @returns       ch\hplus\datamapper\BREServiceMapper
	 */
	public static function getInstance() {
		if (!self::$singleton) {
			self::$singleton = new self();
		}

		return self::$singleton;
	}

	/**
	 * Load a BREService by id
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         int $id
	 * @returns       ch\monitoring\model\BREService
	 */
	public function getByID($id) {
		// TODO: use the API written by TobiasF
		return null;
	}

	/**
	 * Returns a single BREService object identified by the given SQL query
	 *
	 * Runs the given query, initialises a BREService object and returns it
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @throws        \OutOfBoundsException if the BREService cannot be found
	 * @param         string $query
	 * @param         array  $params
	 * @returns       ch\monitoring\model\BREService
	 */
	protected function getByQuery($query, $params) {
		$statement = Application::getDbInstance()->prepare($query);
		$statement->execute($params);

		$data = $statement->fetch();

		if (!$data) {
			throw new \OutOfBoundsException(
				sprintf(
					'%s: %s',
					tr('Could not find business rule engine services with these parameters'),
					var_export($params, true)
				)
			);
		}

		$breservice = new model\BREService();
		$breservice->fillFromRowData($data);

		return $breservice;
	}

	/**
	 * Load all BREServices
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         int $customerId Optional. The Customer the BREService shall belong to.
	 * @param         string $permissionName Defaults to
	 * @return        org\adfinis\framework\db\DbIterator
	 */
	public function getAll(
		$customerId = null,
		$permissionName = model\Permission::BREAPPLICATION_READ
	) {
		// TODO: use the API written by TobiasF
		return null;
	}

	/**
	 * Load business rule engine components
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         int $customerId Optional. The Customer the BREService shall belong to.
	 * @param         string $permissionName Defaults to
	 * @return        org\adfinis\framework\db\DbIterator
	 */
	public function getComponents(
		$customerId = null,
		$permissionName = model\Permission::BREAPPLICATION_WRITE
	) {
		// TODO: use the API written by TobiasF
		// filter using applicationId (since it's the same for all the components of an app)
		return null;
	}

	/**
	 * Load all possible services
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         int $customerId Optional. The Customer the BREService shall belong to.
	 * @param         string $permissionName Defaults to
	 * @return        org\adfinis\framework\db\DbIterator
	 */
	public function getServices(
		$customerId = null,
		$permissionName = model\Permission::BREAPPLICATION_WRITE
	) {
		// TODO: use the API written by TobiasF
		// filter using customerId
		return null;
	}

	/**
	 * Saves BREService information
	 *
	 * If the BREService object is new, it is INSERTed, otherwise UPDATEd.
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         \org\adfinis\framework\model\Entity $breservice
	 * @throws        UnexpectedValuException
	 * @returns       array
	 */
	public function save(\org\adfinis\framework\model\Entity $breservice) {

		$rpcClient = Application::getRPCClientInstance(
			ConfManager::getVar('sm','RPC', 'lcAppName'),
			ConfManager::getVar('sm','RPC', 'lcQueues')
		);

		// TODO: set the right variable names
		$resultId = $rpcClient->putRequest(
			'symonitoring_bpe.add_service_to_component',
			array(
				"component_id" => $breservice->componentId,
				"service_id"   => $breservice->serviceId
			)
		);

		$result = $rpcClient->getResult($resultId, 10); // 10 is the timeout

		if (isset($result->exception)) {
			throw new UserException($result->exception);
		}

		return $breservice->getIdentifier();
	}

	/**
	 * Delete a BREService
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         array $identifier
	 * @returns       void
	 */
	public function deleteService($componentId, $serviceId) {
		$rpcClient = Application::getRPCClientInstance(
			ConfManager::getVar('sm','RPC', 'lcAppName'),
			ConfManager::getVar('sm','RPC', 'lcQueues')
		);

		$resultId = $rpcClient->putRequest(
			'symonitoring_bpe.remove_service_from_component',
			array(
				"component_id" => $componentId,
				"service_id" => $serviceId
			)
		);

		$result = $rpcClient->getResult($resultId, 10); // 10 is the timeout

		if (isset($result->exception)) {
			throw new UserException($result->exception);
		}
	}

	/**
	 * Delete
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @param         array $identifier
	 * @returns       void
	 */
	public function delete($identifier) {
		// this is ugly
	}
}
