<?php

namespace ch\monitoring\datamapper;

use org\adfinis\framework\datamapper\Mapper;
use org\adfinis\framework\datamapper\IdentityMap;
use ch\monitoring\Application;

/**
 * Datamapper for the HoldInform model.
 *
 */
class HoldInformMapper extends Mapper {

	/**
	 * HoldInformMapper object to implement singleton
	 *
	 * @var            ch\monitoring\datamapper\HoldInformMapper $singleton
	 */
	private static $singleton;

	/**
	 * Class constructor
	 */
	public function __construct() {
		parent::__construct('ch\monitoring\model\HoldInform');
	}

	/**
	 * Implements a singleton
	 *
	 * @returns       ch\monitoring\datamapper\HoldInformMapper
	 */
	public static function getInstance() {
		if (!self::$singleton) {
			self::$singleton = new self();
		}
		return self::$singleton;
	}

	/**
	 * Get HoldInform entry by its id
	 *
	 * @param         int $id
	 * @returns       ch\monitoring\model\HoldInform
	 */
	public function getByID($id) {
		$map = IdentityMap::getInstance(get_called_class());
		if (!$map->exists(array('id' => $id))) {
			$query = '
				SELECT
					*
				FROM
					`HoldInform`
				WHERE
					`id` = ?
				LIMIT
					1
			';

			$holdInform = $this->getByQuery($query, array($id));
			$map->set($holdInform);
		}

		return $map->get(array('id' => $id));
	}

	/**
	 * Saves HoldInform information
	 *
	 * If the HoldInform object is new, it is INSERTed, otherwise UPDATEd.
	 *
	 * @param         \org\adfinis\framework\model\Entity $holdInform
	 * @returns       array
	 */
	public function save(\org\adfinis\framework\model\Entity $holdInform) {
		$fieldDataMapping = array(
			'id'           => $holdInform->id,
			'nagioslogId'  => $holdInform->nagioslogId
		);

		if ($holdInform->hasIdentifier()) {
			Application::getDbInstance()->update(
				'HoldInform',
				$fieldDataMapping,
				sprintf('id = %d', $holdInform->id)
			);
		}
		else {
			Application::getDbInstance()->insert(
				'HoldInform',
				$fieldDataMapping
			);
			$holdInform->id = Application::getDbInstance()->lastInsertId();
		}

		return $holdInform->getIdentifier();
	}

	/**
	 * Delete a HoldInform entry
	 *
	 * @param         array $identifier
	 * @returns       void
	 */
	public function delete($identifier) {
		Application::getDBInstance()->beginTransaction();
		Application::getDBInstance()->delete(
			'HoldInform',
			sprintf('`id` = %d', $identifier['id'])
		);
		Application::getDBInstance()->commit();
		IdentityMap::getInstance(get_called_class())->clear();
	}

	/**
	 * Delete the HoldInform entries associated to a NagiosLog entry
	 *
	 * @param         int $nagiosLogID The identifier of the NagiosLog entry
	 * @returns       void
	 */
	public function deleteByNagiosLogID($nagiosLogID) {
		Application::getDBInstance()->beginTransaction();
		Application::getDBInstance()->delete(
			'HoldInform',
			sprintf('`nagioslogId` = %d', $nagiosLogID)
		);
		Application::getDBInstance()->commit();
	}
}
