<?php

namespace ch\monitoring\datamapper;

use org\adfinis\framework\datamapper\Mapper;
use org\adfinis\framework\datamapper\IdentityMap;
use ch\monitoring\Application;

/**
 * Datamapper for the Hold model.
 *
 */
class HoldMapper extends Mapper {

	/**
	 * HoldMapper object to implement singleton
	 *
	 * @var            ch\monitoring\datamapper\HoldMapper $singleton
	 */
	private static $singleton;

	/**
	 * Class constructor
	 */
	public function __construct() {
		parent::__construct('ch\monitoring\model\Hold');
	}

	/**
	 * Implements a singleton
	 *
	 * @returns       ch\monitoring\datamapper\HoldMapper
	 */
	public static function getInstance() {
		if (!self::$singleton) {
			self::$singleton = new self();
		}
		return self::$singleton;
	}

	/**
	 * Get Hold entry by its id
	 *
	 * @param         int $id
	 * @returns       ch\monitoring\model\Hold
	 */
	public function getByID($id) {
		$map = IdentityMap::getInstance(get_called_class());
		if (!$map->exists(array('id' => $id))) {
			$query = '
				SELECT
					*
				FROM
					`Hold`
				WHERE
					`id` = ?
				LIMIT
					1
			';

			$hold = $this->getByQuery($query, array($id));
			$map->set($hold);
		}

		return $map->get(array('id' => $id));
	}

	/**
	 * Saves Hold information
	 *
	 * If the Hold object is new, it is INSERTed, otherwise UPDATEd.
	 *
	 * @param         \org\adfinis\framework\model\Entity $hold
	 * @returns       array
	 */
	public function save(\org\adfinis\framework\model\Entity $hold) {
		$fieldDataMapping = array(
			'id'           => $hold->id,
			'nagioslogId'  => $hold->nagioslogId
		);

		if ($hold->hasIdentifier()) {
			Application::getDbInstance()->update(
				'Hold',
				$fieldDataMapping,
				sprintf('id = %d', $hold->id)
			);
		}
		else {
			Application::getDbInstance()->insert(
				'Hold',
				$fieldDataMapping
			);
			$hold->id = Application::getDbInstance()->lastInsertId();
		}

		return $hold->getIdentifier();
	}

	/**
	 * Delete a Hold entry
	 *
	 * @param         array $identifier
	 * @returns       void
	 */
	public function delete($identifier) {
		Application::getDBInstance()->beginTransaction();
		Application::getDBInstance()->delete(
			'Hold',
			sprintf('`id` = %d', $identifier['id'])
		);
		Application::getDBInstance()->commit();
		IdentityMap::getInstance(get_called_class())->clear();
	}

	/**
	 * Delete the hold entries associated to a NagiosLog entry
	 *
	 * @param         int $nagiosLogID The identifier of the NagiosLog entry
	 * @returns       void
	 */
	public function deleteByNagiosLogID($nagiosLogID) {
		Application::getDBInstance()->beginTransaction();
		Application::getDBInstance()->delete(
			'Hold',
			sprintf('`nagioslogId` = %d', $nagiosLogID)
		);
		Application::getDBInstance()->commit();
	}
}
