<?php

namespace ch\monitoring\datamapper;

use org\adfinis\framework\datamapper\Mapper;
use org\adfinis\framework\datamapper\IdentityMap;
use org\adfinis\framework\db\SortingIterator;
use ch\monitoring\model;
use ch\monitoring\Application;

/**
 * Datamapper for the NotificationType model.
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class NotificationTypeMapper extends Mapper {

	/**
	 * NotificationTypeMapper object to implement singleton
	 *
	 * @var            ch\monitoring\datamapper\NotificationTypeMapper $singleton
	 */
	private static $singleton;

	/**
	 * Class constructor
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 */
	public function __construct() {
		parent::__construct('ch\monitoring\model\NotificationType');
	}

	/**
	 * Implements a singleton
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\hplus\datamapper\NotificationTypeMapper
	 */
	public static function getInstance() {
		if (!self::$singleton) {
			self::$singleton = new self();
		}

		return self::$singleton;
	}

	/**
	 * Load a NotificationType by id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         int $id
	 * @returns       ch\monitoring\model\NotificationType
	 */
	public function getByID($id) {
		$map = IdentityMap::getInstance(get_called_class());
		if (!$map->exists(array('id' => $id))) {
			$query = '
				SELECT
					*
				FROM
					`NotificationType`
				WHERE
					`id` = ?
				LIMIT
					1
			';

			$notificationType = $this->getByQuery($query, array((int)$id));
			$map->set($notificationType);
		}

		return $map->get(array('id' => $id));
	}

	/** 
	 * Returns a single NotificationType object identified by the given SQL query
	 *   
	 * Runs the given query, initialises a NotificationType object and returns it
	 *   
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @throws        \OutOfBoundsException if the NotificationType cannot be found
	 * @param         string $query
	 * @param         array  $params
	 * @returns       ch\monitoring\model\NotificationType
	 */  
	protected function getByQuery($query, $params) {
		$statement = Application::getDbInstance()->prepare($query);
		$statement->execute($params);

		$data = $statement->fetch();

		if (!$data) {
			throw new \OutOfBoundsException(
				sprintf(
					'%s: %s',
					tr('Could not find notification type with these parameters'),
					var_export($params, true)
				)
			);
		}

		$notificationType = new model\NotificationType();
		$notificationType->fillFromRowData($data);

		return $notificationType;
	}

	/**
	 * Load all NotificationTypes
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       org\adfinis\framework\db\DbIterator
	 */
	public function getAll() {
		$searchQuery = "
			SELECT
				`NotificationType`.`id`
			FROM
				`NotificationType`
		";

		$selectQuery = "SELECT * FROM `NotificationType`";

		$notificationTypeList = SortingIterator::create(
			$searchQuery,
			$selectQuery,
			'ch\monitoring\model\NotificationType',
			array()
		);

		return $notificationTypeList;
	}

	/**
	 * Saves NotificationType information
	 *
	 * If the NotificationType object is new, it is INSERTed, otherwise UPDATEd.
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         \org\adfinis\framework\model\Entity $notificationType
	 * @returns       array
	 */
	public function save(\org\adfinis\framework\model\Entity $notificationType) {
		$fieldDataMapping = array(
			'id'          => $notificationType->id,
			'name'        => $notificationType->name,
			'description' => $notificationType->description
		);

		if ($notificationType->hasIdentifier()) {
			Application::getDbInstance()->update(
				'NotificationType',
				$fieldDataMapping,
				sprintf('id = %d', $notificationType->id)
			);
		}
		else {
			Application::getDbInstance()->insert(
				'NotificationType',
				$fieldDataMapping
			);
			$notificationType->id = Application::getDbInstance()->lastInsertId();
		}

		return $notificationType->getIdentifier();
	}

	/**
	 * Delete a NotificationType
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $identifier
	 * @returns       void
	 */
	public function delete($identifier) {
		Application::getDbInstance()->delete(
			'NotificationType',
			sprintf('`id` = %d', $identifier['id'])
		);
	}
}
