<?php

namespace ch\monitoring\model;

use ch\monitoring\datamapper;
use ch\monitoring\validate\AlertTagValidator;

/**
 * Model for a AlertTag
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class AlertTag extends Entity {

	/**
	 * All available tags (references the AlertTag table rows)
	 */
	const CUSTOMER_REPORT = 1;
	const KNOWLEDGE_BASE  = 2;

	/**
	 * Primary key.
	 *
	 * @var           int $id
	 */
	public $id;

	/**
	 * The tag name.
	 *
	 * @var           string $name
	 */
	public $name;

	/**
	 * Short description of the tag.
	 *
	 * @var           string $description
	 */
	public $description;

	/**
	 * Does the database record belong to this object?
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       bool
	 */
	public function doesRecordMatch($data) {
		return ($this->id === (int) $data['id']);
	}

	/**
	 * Returns the identifier of the current object
	 *
	 * The identifier is an associative array that contains all the information
	 * for identifying the current object.
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @returns       array
	 */
	public function getIdentifier() {
		return array('id' => $this->id);
	}

	/**
	 * This method fills the object from an associative array, usually a row
	 * from the database.
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       void
	 */
	public function fillFromRowData($data) {
		$this->id          = (int)$data['id'];
		$this->name        = $data['name'];
		$this->description = $data['description'];
	}

	/**
	 * Returns a validator for the current AlertTag object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\validate\AlertTagValidator
	 */
	public function getValidator() {
		return new AlertTagValidator($this);
	}

	/**
	 * Returns a data mapper for handling persistence of this object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\datamapper\AlertTagMapper
	 */
	public static function getMapper() {
		return datamapper\AlertTagMapper::getInstance();
	}
}
