<?php

namespace ch\monitoring\model;

use org\adfinis\framework\config\ConfManager;
use ch\monitoring\datamapper;
use ch\monitoring\policy;
use ch\monitoring\acl;
use ch\monitoring\validate;
use ch\monitoring\util;
use ch\monitoring\model\Permission;

/**
 * Model for an AlertTemplates
 *
 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class AlertTemplate extends Entity {
	/**
	 * Primary key.
	 *
	 * @var           int $id
	 */
	public $id;

	/**
	 * The template name.
	 *
	 * @var           string $name
	 */
	public $name;

	/**
	 * The description of this template
	 *
	 * @var           string $description
	 */
	public $description;

	/**
	 * The content that will be used for creating the alert
	 *
	 * @var           string $content
	 */
	public $content;

	/**
	 * The SLA action the alert template is referring
	 * to
	 * @var           int $slaActionId
	 */
	public $slaActionId;

	/**
	 * Does the database record belong to this object?
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       bool
	 */
	public function doesRecordMatch($data) {
		return ($this->id === (int) $data['id']);
	}

	/**
	 * Returns the identifier of the current object
	 *
	 * The identifier is an associative array that contains all the information
	 * for identifying the current object.
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @returns       array
	 */
	public function getIdentifier() {
		return array('id' => $this->id);
	}

	/**
	 * This method fills the object from an associative array, usually a row
	 * from the database.
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       void
	 */
	public function fillFromRowData($data) {
		$this->id              = (int)$data['id'];
		$this->name            = $data['name'];
		$this->description     = $data['description'];
		$this->content         = $data['content'];
		$this->slaActionId     = $data['slaActionId'];
	}

	/**
	 * Returns a validator for the current User object
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\validate\AlertTemplateValidator
	 */
	public function getValidator() {
		return new validate\AlertTemplateValidator($this);
	}

	/**
	 * Returns a data mapper for handling persistence of this object
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\datamapper\AlertTemplateMapper
	 */
	public static function getMapper() {
		return datamapper\AlertTemplateMapper::getInstance();
	}

	/**
	 * Returns the SLA action of this alert template
	 *
	 * @returns       ch\monitoring\model\SLAAction
	 */
	public function getSlaAction() {
		return datamapper\SLAActionMapper::getInstance()->getByID(
			$this->slaActionId
		);
	}
}
