<?php

namespace ch\monitoring\model;

use org\adfinis\framework\config\ConfManager;
use ch\monitoring\datamapper;
use ch\monitoring\policy;
use ch\monitoring\acl;
use ch\monitoring\validate;
use ch\monitoring\util;
use ch\monitoring\model\Permission;

/**
 * Model for a AlertTemplateUser
 *
 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class AlertTemplateUser extends Entity {
	/**
	 * Primary key.
	 *
	 * @var           int $id
	 */
	public $id;

	/**
	 * The identifier of the user.
	 *
	 * @var           int $userId
	 */
	public $userId;

	/**
	 * The identifier for the SLA action.
	 *
	 * @var           int $slaActionId
	 */
	public $slaActionId;

	/**
	 * The template that should be used for
	 * a notification
	 *
	 * @var           int $templateId
	 */
	public $templateId = null;
	
	
	/**
	 * Does the database record belong to this object?
	 *
	 * @param         array $data
	 * @returns       bool
	 */
	public function doesRecordMatch($data) {
		return ($this->id === (int) $data['id']);
	}

	/**
	 * Returns the identifier of the current object
	 *
	 * The identifier is an associative array that contains all the information
	 * for identifying the current object.
	 *
	 * @returns       array
	 */
	public function getIdentifier() {
		return array('id' => $this->id);
	}

	/**
	 * This method fills the object from an associative array, usually a row
	 * from the database.
	 *
	 * @param         array $data
	 * @returns       void
	 */
	public function fillFromRowData($data) {
		$this->id                   = (int)$data['id'];
		$this->userId               = $data['userId'];
		$this->slaActionId          = $data['slaActionId'];
		$this->templateId           = $data['templateId'];
	}

	/**
	 * Returns a validator for the current User object
	 *
	 * @returns       ch\monitoring\validate\UserValidator
	 */
	public function getValidator() {
		return new validate\AlertTemplateUserValidator($this);
	}

	/**
	 * Returns a data mapper for handling persistence of this object
	 *
	 * @returns       ch\monitoring\datamapper\AlertTemplateUserMapper
	 */
	public static function getMapper() {
		return datamapper\AlertTemplateUserMapper::getInstance();
	}
}
