<?php

namespace ch\monitoring\model;

/**
 * A base entity abstraction of the adfinis model
 *
 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2014
 * @license       LGPLv3
 **/
abstract class Entity extends \org\adfinis\framework\model\Entity {

	/**
	 * Get the class which represents the view of this model for given category
	 *
	 * If not overwritten a class name will be generated using model class name
	 *
	 * @param  [type] $category [description]
	 * @return [type]           [description]
	 */
	protected function getViewClass($category = null) {
		$category = isset($category) ? sprintf('%s\\', $category) : '';
		$class = sprintf(
			'\ch\monitoring\view\\%s%s',
			$category,
			join('', array_slice(explode('\\', get_class($this)), -1))
		);

		return $class;
	}

	/**
	 * Creates a new view of current model for given section
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @param         string $category
	 * @param         string $view     [optional]
	 * @throws        \RuntimeException
	 * @return        \ch\monitoring\view\View
	 */
	public function view($category, $view = null) {
		if (!$view) {
			$view = $this->getViewClass($category);
		}
		if (!is_subclass_of($view, '\ch\monitoring\view\View')) {
			throw new \RuntimeException(sprintf('"%s" is not a valid view class', $view));
		}

		return new $view($this);
	}
}
