<?php

namespace ch\monitoring\model;

use ch\monitoring\policy;

/**
 * An entity which is used to import icinga configuration files
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
abstract class EntityForImport extends EntityWithPolicy {

	/**
	 * Add an object name to be included
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         string $name
	 * @returns       void
	 */
	public function addInclude($name) {
		$this->getMapper()->addInclude($this->id, $name);
	}

	/**
	 * Fill from import
	 *
	 * This function differs from fillFromRowData in the detail that the model
	 * fields are not expected to exist in the $data array.
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       void
	 */
	public function fillFromImport($data) {
		foreach ($this->getKeys() as $key) {
			$this->$key = array_key_exists($key, $data)
				? $data[$key]
				: null;
		}
	}

	/**
	 * Return the fields to be used for the import
	 *
	 * @returns       array
	 */
	abstract protected function getKeys();
}
