<?php

namespace ch\monitoring\model;

use org\adfinis\framework\model;

/**
 * Model for a hold entry
 */
class Hold extends EntityWithPolicy {
	/**
	 * Primary key
	 *
	 * @var           int $id
	 */
	public $id;

	/**
	 * The corresponding nagios log entry
	 *
	 * @var           int $nagioslogId
	 */
	public $nagioslogId;

	/**
	 * Returns the identifier of the current object
	 *
	 * The identifier is an associative array that contains all the information
	 * for identifying the current object.
	 *
	 * @returns       array
	 */
	public function getIdentifier() {
		return array('id' => $this->id);
	}

	/**
	 * This method fills the object from an associative array, usually a row
	 * from the database.
	 *
	 * @param         array $data
	 * @returns       void
	 */
	public function fillFromRowData($data) {
		$this->id          = (int)$data['id'];
		$this->nagioslogId = (int)$data['nagioslogId'];
	}

	/**
	 * Returns a policy for the current object
	 *
	 * @returns       ch\monitoring\policy\HoldPolicy
	 */
	public function getPolicy() {
		return new policy\HoldPolicy($this);
	}

	/**
	 * Returns a validator for the current object
	 *
	 * @returns       ch\monitoring\validate\HoldValidator
	 */
	public function getValidator() {
		return new HoldValidator($this);
	}

	/**
	 * Returns a data mapper for handling persistence of this object
	 *
	 * @returns       ch\monitoring\datamapper\HoldMapper
	 */
	public static function getMapper() {
		return datamapper\HoldMapper::getInstance();
	}

	/**
	 * Returns the nagioslog object this Hold entry was created for
	 *
	 * @returns       ch\monitoring\model\NagiosLog
	 */
	public function getNagiosLog() {
		return datamapper\NagiosLogMapper::getInstance()->getByID(
			$this->nagioslogId
		)->allowRead();
	}
}
