<?php

namespace ch\monitoring\model;

use org\adfinis\framework\model;
use ch\monitoring\datamapper;
use ch\monitoring\policy;
use ch\monitoring\validate;
/**
 * Model for a Host OS architecture
 *
 * @author        Tobias Feller <tobias.feller@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class HostOSArchitecture extends EntityWithPolicy {

	/**
	 * Primary key.
	 *
	 * @var           int $id
	 */
	public $id;

	/**
	 * The architecture name.
	 *
	 * @var           string $name
	 */
	public $name;

	/**
	 * Does the database record belong to this object?
	 *
	 * @author        Tobias Feller <tobias.feller@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       bool
	 */
	public function doesRecordMatch($data) {
		return ($this->id === (int) $data['id']);
	}

	/**
	 * Returns the identifier of the current object
	 *
	 * The identifier is an associative array that contains all the information
	 * for identifying the current object.
	 *
	 * @author        Tobias Feller <tobias.feller@adfinis-sygroup.ch>
	 * @returns       array
	 */
	public function getIdentifier() {
		return array('id' => $this->id);
	}

	/**
	 * This method fills the object from an associative array, usually a row
	 * from the database.
	 *
	 * @author        Tobias Feller <tobias.feller@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       void
	 */
	public function fillFromRowData($data) {
		$this->id                   = (int)$data['id'];
		$this->name                 = $data['name'];
	}

	/**
	 * Returns a validator for the current HostOSArchitecture object
	 *
	 * @author        Tobias Feller <tobias.feller@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\validate\ArchitectureValidator
	 */
	public function getValidator() {
		$validator = new validate\ArchitectureValidator($this);
		return $validator;
	}

	/**
	 * Returns a data mapper for handling persistence of this object
	 *
	 * @author        Tobias Feller <tobias.feller@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\datamapper\HostOSArchitectureMapper
	 */
	public static function getMapper() {
		return datamapper\HostOSArchitectureMapper::getInstance();
	}

	/**
	 * Returns a policy for the current object
	 *
	 * @author        Tobias Feller <tobias.feller@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\policy\CustomerBoundPolicy
	 */
	public function getPolicy() {
		return new policy\CustomerBoundPolicy($this);
	}
}
