<?php

namespace ch\monitoring\model;

use org\adfinis\framework\model;
use ch\monitoring\datamapper;
use ch\monitoring\policy;
use ch\monitoring\validate\HostTypeValidator;

/**
 * Model for a Host type
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class HostType extends EntityWithPolicy {

	/**
	 * Primary key.
	 *
	 * @var           int $id
	 */
	public $id;

	/**
	 * The type name.
	 *
	 * @var           string $name
	 */
	public $name;

	/**
	 * Short name of this type
	 *
	 * @var           string $short
	 */
	public $short;

	/**
	 * Does the database record belong to this object?
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       bool
	 */
	public function doesRecordMatch($data) {
		return ($this->id === (int) $data['id']);
	}

	/**
	 * Returns the identifier of the current object
	 *
	 * The identifier is an associative array that contains all the information
	 * for identifying the current object.
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @returns       array
	 */
	public function getIdentifier() {
		return array('id' => $this->id);
	}

	/**
	 * This method fills the object from an associative array, usually a row
	 * from the database.
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       void
	 */
	public function fillFromRowData($data) {
		$this->id    = (int)$data['id'];
		$this->name  = $data['name'];
		$this->short = $data['short'];
	}

	/**
	 * Returns a policy for the current object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\policy\CustomerBoundPolicy
	 */
	public function getPolicy() {
		return new policy\CustomerBoundPolicy($this);
	}

	/**
	 * Returns a validator for the current HostType object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\validate\HostTypeValidator
	 */
	public function getValidator() {
		return new HostTypeValidator($this);
	}

	/**
	 * Returns a data mapper for handling persistence of this object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\datamapper\HostTypeMapper
	 */
	public static function getMapper() {
		return datamapper\HostTypeMapper::getInstance();
	}
}
