<?php

namespace ch\monitoring\model;

use org\adfinis\framework\model;
use ch\monitoring\datamapper;
use ch\monitoring\policy;
use ch\monitoring\validate\ImportFileValidator;
use ch\monitoring\util;

/**
 * Model for a file to be imported
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class ImportFile extends EntityWithPolicy {

	/**
	 * Primary key.
	 *
	 * @var           int $id
	 */
	public $id;

	/**
	 * The name
	 *
	 * @var           string $name
	 */
	public $name;

	/**
	 * The hosts count
	 *
	 * @var           int $hosts
	 */
	public $hosts;

	/**
	 * The services count
	 *
	 * @var           int $services
	 */
	public $services;

	/**
	 * The commands count
	 *
	 * @var           int $commands
	 */
	public $commands;

	/**
	 * The host groups count
	 *
	 * @var           int $hostgroups
	 */
	public $hostgroups;

	/**
	 * Does the database record belong to this object?
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       bool
	 */
	public function doesRecordMatch($data) {
		return ($this->id === (int) $data['id']);
	}

	/**
	 * Returns the identifier of the current object
	 *
	 * The identifier is an associative array that contains all the information
	 * for identifying the current object.
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @returns       array
	 */
	public function getIdentifier() {
		return array('id' => $this->id);
	}

	/**
	 * This method fills the object from an associative array, usually a row
	 * from the database.
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       void
	 */
	public function fillFromRowData($data) {
		$this->id         = (int)$data['id'];
		$this->name       = $data['name'];
		$this->hosts      = (int)$data['hosts'];
		$this->services   = (int)$data['services'];
		$this->commands   = (int)$data['commands'];
		$this->hostgroups = (int)$data['hostgroups'];
	}

	/**
	 * Returns a policy for the current object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\policy\CustomerBoundPolicy
	 */
	public function getPolicy() {
		return new policy\CustomerBoundPolicy($this);
	}

	/**
	 * Returns a validator for the current ImportFile object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\validate\ImportFileValidator
	 */
	public function getValidator() {
		return new ImportFileValidator($this);
	}

	/**
	 * Returns a data mapper for handling persistence of this object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\datamapper\ImportFileMapper
	 */
	public static function getMapper() {
		return datamapper\ImportFileMapper::getInstance();
	}
}
