<?php

namespace ch\monitoring\model;

use ch\monitoring\datamapper;
use ch\monitoring\policy;
use ch\monitoring\validate\MaintenanceChecklistAnswerValidator;

/**
 * Model for a MaintenanceChecklistQuestion
 *
 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class MaintenanceChecklistAnswer extends Entity {

	/**
	 * Primary key.
	 *
	 * @var           int $id
	 */
	public $id;

	/**
	 * Reference to the assigned host
	 *
	 * @var           int $ticketHostId
	 */
	public $ticketHostId;

	/**
	 * Reference to the assigned question
	 *
	 * @var           int $questionId
	 */
	public $questionId;

	/**
	 * Short comment of the question.
	 *
	 * @var           string $comment
	 */
	public $comment;

	/**
	 * Whether the answer was checked
	 *
	 * @var           string $comment
	 */
	public $isChecked = false;

	/**
	 * Does the database record belong to this object?
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       bool
	 */
	public function doesRecordMatch($data) {
		return ($this->id === (int) $data['id']);
	}

	/**
	 * Returns the identifier of the current object
	 *
	 * The identifier is an associative array that contains all the information
	 * for identifying the current object.
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       array
	 */
	public function getIdentifier() {
		return array('id' => $this->id);
	}

	/**
	 * This method fills the object from an associative array, usually a row
	 * from the database.
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       void
	 */
	public function fillFromRowData($data) {
		$this->id           = (int)$data['id'];
		$this->comment      = $data['comment'];
		$this->questionId   = $data['questionId'];
		$this->ticketHostId = $data['ticketHostId'];
		$this->isChecked    = (bool)$data['isChecked'];
		
	}

	/**
	 * Returns a validator for the current MaintenanceChecklistQuestion object
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\validate\MaintenanceChecklistAnswerValidator
	 */
	public function getValidator() {
		return new MaintenanceChecklistAnswerValidator($this);
	}

	/**
	 * Returns a data mapper for handling persistence of this object
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\datamapper\MaintenanceChecklistAnswerMapper
	 */
	public static function getMapper() {
		return datamapper\MaintenanceChecklistAnswerMapper::getInstance();
	}


	/**
	 * Returns the attached question
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\datamapper\MaintenanceChecklistAnswerMapper
	 */
	public function getQuestion() {
		return datamapper\MaintenanceChecklistQuestionMapper::getInstance()->getByID($this->questionId);
	}
}
