<?php

namespace ch\monitoring\model;

use ch\monitoring\datamapper;
use ch\monitoring\validate\MaintenanceCycleValidator;

/**
 * Model for a maintenance cycle
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class MaintenanceCycle extends Entity {

	/**
	 * Primary key.
	 *
	 * @var           int $id
	 */
	public $id;

	/**
	 * The state name.
	 *
	 * @var           string $name
	 */
	public $name;

	/**
	 * The interval
	 *
	 * Unit: Months
	 *
	 * @var           int $interval
	 */
	public $interval;

	/**
	 * Does the database record belong to this object?
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       bool
	 */
	public function doesRecordMatch($data) {
		return ($this->id === (int) $data['id']);
	}

	/**
	 * Returns the identifier of the current object
	 *
	 * The identifier is an associative array that contains all the information
	 * for identifying the current object.
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @returns       array
	 */
	public function getIdentifier() {
		return array('id' => $this->id);
	}

	/**
	 * This method fills the object from an associative array, usually a row
	 * from the database.
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       void
	 */
	public function fillFromRowData($data) {
		$this->id       = (int)$data['id'];
		$this->name     = $data['name'];
		$this->interval = (int)$data['interval'];
	}

	/**
	 * Returns a validator for the current MaintenanceCycle object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\validate\MaintenanceCycleValidator
	 */
	public function getValidator() {
		return new MaintenanceCycleValidator($this);
	}

	/**
	 * Returns a data mapper for handling persistence of this object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\datamapper\MaintenanceCycleMapper
	 */
	public static function getMapper() {
		return datamapper\MaintenanceCycleMapper::getInstance();
	}
}
