<?php

namespace ch\monitoring\model;

use ch\monitoring\datamapper;
use ch\monitoring\validate\MaintenanceStateValidator;

/**
 * Model for a maintenance state
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class MaintenanceState extends Entity {

	/**
	 * State 'New'
	 *
	 * @const         int STATE_NEW
	 */
	const STATE_NEW = 1;

	/**
	 * State 'In progress'
	 *
	 * @const         int STATE_IN_PROGRESS
	 */
	const STATE_IN_PROGRESS = 2;

	/**
	 * State 'Done'
	 *
	 * @const         int STATE_DONE
	 */
	const STATE_DONE = 3;

	/**
	 * Primary key.
	 *
	 * @var           int $id
	 */
	public $id;

	/**
	 * The state name.
	 *
	 * @var           string $name
	 */
	public $name;

	/**
	 * Does the database record belong to this object?
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       bool
	 */
	public function doesRecordMatch($data) {
		return ($this->id === (int) $data['id']);
	}

	/**
	 * Returns the identifier of the current object
	 *
	 * The identifier is an associative array that contains all the information
	 * for identifying the current object.
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @returns       array
	 */
	public function getIdentifier() {
		return array('id' => $this->id);
	}

	/**
	 * This method fills the object from an associative array, usually a row
	 * from the database.
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       void
	 */
	public function fillFromRowData($data) {
		$this->id   = (int)$data['id'];
		$this->name = $data['name'];
	}

	/**
	 * Returns a validator for the current MaintenanceState object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\validate\MaintenanceStateValidator
	 */
	public function getValidator() {
		return new MaintenanceStateValidator($this);
	}

	/**
	 * Returns a data mapper for handling persistence of this object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\datamapper\MaintenanceStateMapper
	 */
	public static function getMapper() {
		return datamapper\MaintenanceStateMapper::getInstance();
	}
}
