<?php

namespace ch\monitoring\model;

use ch\monitoring\datamapper;
use ch\monitoring\validate\NotificationTypeValidator;

/**
 * Model for a notification type
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class NotificationType extends Entity {

	/**
	 * The ID of the acknowledged type
	 *
	 * @const         int EMAIL
	 */
	const EMAIL = 1;

	/**
	 * The ID of the acknowledged type
	 *
	 * @const         int TEXT
	 */
	const TEXT = 2;

	/**
	 * The ID of the acknowledged type
	 *
	 * @const         int PHONE
	 */
	const PHONE = 3;

	/**
	 * The ID of the acknowledged type
	 *
	 * @const         int TIMEOUT
	 */
	const TIMEOUT = 4;

	/**
	 * The ID of the acknowledged type
	 *
	 * @const         int ACKNOWLEDGED
	 */
	const ACKNOWLEDGED = 5;

	/**
	 * The ID of the jabber type
	 *
	 * @const         int JABBER
	 */
	const JABBER = 6;

	/**
	 * @TODO Is this used or can it be removed?
	 * The ID of the sms type
	 *
	 * @const         int SMS
	 */
	const SMS = 7;

	/**
	 * The ID of the mattermost type
	 *
	 * @const         int MATTERMOST
	 */
	const MATTERMOST = 8;


	/**
	 * Primary key.
	 *
	 * @var           int $id
	 */
	public $id;

	/**
	 * The notification name.
	 *
	 * @var           string $name
	 */
	public $name;

	/**
	 * The notification description.
	 *
	 * @var           string $description
	 */
	public $description;

	/**
	 * The notification is multiple.
	 *
	 * @var           bool $description
	 */
	public $multiple = true;

	/**
	 * Does the database record belong to this object?
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       bool
	 */
	public function doesRecordMatch($data) {
		return ($this->id === (int) $data['id']);
	}

	/**
	 * Returns the identifier of the current object
	 *
	 * The identifier is an associative array that contains all the information
	 * for identifying the current object.
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @returns       array
	 */
	public function getIdentifier() {
		return array('id' => $this->id);
	}

	/**
	 * This method fills the object from an associative array, usually a row
	 * from the database.
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       void
	 */
	public function fillFromRowData($data) {
		$this->id          = (int)$data['id'];
		$this->name        = $data['name'];
		$this->description = $data['description'];
		$this->multiple    = $data['multiple'];
	}

	/**
	 * Returns a validator for the current NotificationType object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\validate\NotificationTypeValidator
	 */
	public function getValidator() {
		return new NotificationTypeValidator($this);
	}

	/**
	 * Returns a data mapper for handling persistence of this object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\datamapper\NotificationTypeMapper
	 */
	public static function getMapper() {
		return datamapper\NotificationTypeMapper::getInstance();
	}

	/**
	 * Indicates of the current NotificationType can have templates (not if they're available)
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       bool
	 */
	public function hasTemplate() {
		switch($this->id) {
			case self::EMAIL:
			case self::TEXT:
			case self::JABBER:
			case self::SMS:
			case self::MATTERMOST:
				return true;
		}

		return false;
	}
}
