<?php

namespace ch\monitoring\model;

use ch\monitoring\datamapper;
use ch\monitoring\validate\SettingValidator;

/**
 * A setting
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class Setting extends Entity {

	/**
	 * Primary key.
	 *
	 * @var           int $id
	 */
	public $key;

	/**
	 * The value.
	 *
	 * @var           string $value
	 */
	public $value;

	/**
	 * Does the database record belong to this object?
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       bool
	 */
	public function doesRecordMatch($data) {
		return ($this->key === $data['key']);
	}

	/**
	 * Returns the identifier of the current object
	 *
	 * The identifier is an associative array that contains all the information
	 * for identifying the current object.
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @returns       array
	 */
	public function getIdentifier() {
		return array('key' => $this->key);
	}

	/**
	 * This method fills the object from an associative array, usually a row
	 * from the database.
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $data
	 * @returns       void
	 */
	public function fillFromRowData($data) {
		$this->key   = $data['key'];
		$this->value = $data['value'];
	}

	/**
	 * Returns a validator for the current Setting object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\validate\SettingValidator
	 */
	public function getValidator() {
		return new SettingValidator($this);
	}

	/**
	 * Returns a data mapper for handling persistence of this object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       ch\monitoring\datamapper\SettingMapper
	 */
	public static function getMapper() {
		return datamapper\SettingMapper::getInstance();
	}
}
