<?php

namespace ch\monitoring\policy;

use ch\monitoring\Application;

/**
 * A CustomerBoundPolicy implementation for HostService objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2013
 * @license       LGPLv3
 **/
class HostServiceInstancePolicy extends CustomerBoundPolicy {

	/**
	 * This function returns the customer id the associated object belongs to
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       int
	 */
	protected function getCustomerIdentifiers() {
		$hostCustomerId = $this->model->getHostService()->getHost()->customerId;
		$serviceCustomerId = $this->model->getHostService()->getService()->customerId;
		if ($serviceCustomerId !== null) {
			return array($hostCustomerId, $serviceCustomerId);
		}
		return array($hostCustomerId);
	}

	/**
	 * Returns true if the user has access to this object
	 *
	 * @param         string $permissionName
	 * @returns       bool
	 */
	public function hasPermission($permissionName, $checkAll=false) {
		return parent::hasPermission($permissionName, true);
	}
}
