<?php

namespace ch\monitoring\util;

/**
 * Class for accessing the settings table
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class IteratorUtil {

	/**
	 * Object constuctor
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 */
	private function __construct(){
	}

	/**
	 * Returns an array containg all Keys from given iterator
	 */
	public static function getKeyArray($iterator, $keyAttribute = 'id') {
		$selectArray = array();
		foreach ($iterator as $model) {
			$selectArray[$model->{$keyAttribute}] = $model->{$keyAttribute};
		}
		return $selectArray;
	}

	/**
	 * Returns a key -> value array from DBIterator
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         org\adfinis\framework\db\DBIterator $iterator
	 * @param         string $keyAttribute Name of the model attribute to be used for the key.
	 * @param         string $valueAttribute Name of the model attribute to be used for the value.
	 * @returns       array
	 */
	public static function getKeyValueArray($iterator, $keyAttribute = 'id', $valueAttribute = 'name') {
		$selectArray = array();
		foreach ($iterator as $model) {
			$selectArray[$model->{$keyAttribute}] = $model->{$valueAttribute};
		}
		return $selectArray;
	}

	/**
	 * Similiar to getKeyValueArray except that not a single value but the whole object
	 * gets insert in the array 
	 * 
	 * 
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @param         org\adfinis\framework\db\DBIterator $iterator
	 * @param         string $keyAttribute Name of the model attribute to be used for the key.
	 *
	 * @todo          missing a third parameter - should be a function which is able to map the model
	 *                to the expected value (however this can be done by using array_map before calling
	 *                this function)
	 *
	 * @returns       array
	 */
	public static function getKeyObjectArray($iterator, $keyAttribute = 'id') {
		$selectArray = array();
		foreach($iterator as $model) {
			$selectArray[$model->{$keyAttribute}] = $model;
		}
		return $selectArray;
	}

	/**
	 * Returns a list of values joined by given separator.
	 */
	public static function getImplodedKeysString($iterator, $keyAttribute = 'id', $separator = ',') {
		$implodedValues = '';
		foreach ($iterator as $model) {
			$implodedValues .= $model->{$keyAttribute}.$separator;
		}
		if (strlen($implodedValues) > 0) {
			$implodedValues = substr($implodedValues, 0, -strlen($separator));
		}
		return $implodedValues;
	}
}
