<?php

namespace ch\monitoring\util;

use org\adfinis\framework\utils;
use ch\monitoring\Application;

/**
 * SyMonitoring specific implementation of mail helper class.
 *
 * This class derives from the mail helper class from adfinis
 * framework but handles exceptions locally in terms of writing
 * them simply to the PHP error log.
 *
 * This procedure is used as the class is needed within various
 * actions which respond to AJAX calls and therefore the standard
 * exception handling behaviour would result in breaking the whole
 * application flow.
 *
 * @copyright   Adfinis SyGroup AG 2014
 * @license     BSD 3-clause
 */
class MailHelper extends utils\MailHelper {
	public static function sendMail(
		array $recipients,
		$subject,
		$messagePlain = '',
		$messageHtml = '',
		$utf8 = false,
		$wordwrap = 75,
		array $attachment = array(),
		array $bcc = array(),
		$mailFromMail = null,
		$mailFromName = null
	) {

		try {
			parent::sendMail(
				$recipients,
				$subject,
				$messagePlain,
				$messageHtml,
				$utf8,
				$wordwrap,
				$attachment,
				$bcc
			);
		}
		catch (\Exception $e) {
			$errorMessage = sprintf(
				"%s\n%s",
				$e->getMessage(),
				$e->getTraceAsString()
			);
			error_log($errorMessage);
			Application::getLogInstance()->err($errorMessage);
		}
	}
}
