<?php

namespace ch\monitoring\util;

use org\adfinis\framework\config\ConfManager;

/**
 * Holds a nagios object
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2014
 * @license       LGPLv3
 **/
class NagiosObject {
	protected $type;
	protected $directives = array();
	protected $includes = array();

	/**
	 * Constructor
	 *
	 * @param         string $type The object type (host, services, ...)
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 */
	public function __construct($type) {
		$this->type = $type;
	}

	/**
	 * Add a directive
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         string $key The key to be added
	 * @param         string $value The value to be added
	 * @returns       void
	 */
	public function addDirective($key, $value) {
		$key = preg_replace('/^normal_check_interval$/', 'check_interval', $key);
		$key = preg_replace('/^retry_check_interval$/', 'retry_interval', $key);

		if ($key == 'use') {
			$this->includes[] = $value;
			return;
		}

		$this->directives[$key] = $value;
	}

	/**
	 * Returns all the directives of this object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       array
	 */
	public function getDirectives() {
		return $this->directives;
	}

	/**
	 * Returns all the includes of this object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       array
	 */
	public function getIncludes() {
		return $this->includes;
	}

	/**
	 * Returns the type of this object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       string
	 */
	public function getType() {
		return $this->type;
	}

	/**
	 * Returns wether a directive exists
	 *
	 * Optional long description
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         string $directiveName The directive name
	 * @returns       bool
	 */
	public function hasDirective($directiveName) {
		return array_key_exists($directiveName, $this->directives);
	}
}
