<?php

namespace ch\monitoring\util;
use org\adfinis\framework\config\ConfManager;

/**
 * This class is a wrapper for PNP4Nagios graphs
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class PNP4Nagios {

	/**
	 * Prevent object creation
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 */
	private function __construct() {
	}

	/**
	 * Prevent object cloning
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 */
	private function __clone() {
	}

	/**
	 * Shows a PNP4Nagios graph
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         string $hostname
	 * @param         string $servicename Set to null to get host graph
	 * @param         \Zend_Date $dateFrom
	 * @param         \Zend_Date $dateTo
	 * @returns       \Zend_Http_Response
	 */
	public static function getGraph(
		$hostname,
		$servicename,
		$dateFrom,
		$dateTo
	) {
		$client = new \Zend_Http_Client();

		$client->setUri(
			ConfManager::getVar('af', 'URLSSL', 'pnp4nagios')
		);

		$client->setAuth(
			ConfManager::getVar('sm', 'pnp4nagios', 'user'),
			ConfManager::getVar('sm', 'pnp4nagios', 'pass')
		);

		$client->setParameterGet(
			array(
				'host'   => $hostname,
				'srv'    => $servicename,
				'start'  => $dateFrom,
				'end'    => $dateTo,
				'view'   => 0,
				'source' => 0
			)
		);

		$response = $client->request(\Zend_Http_Client::GET);

		if ($response->getStatus() != 200) {
			throw new \RuntimeException(
				sprintf(
					tr("HTTP GET request failed: %d %s"),
					$response->getStatus(),
					$response->getMessage()
				)
			);
		}

		return $response;
	}

	/**
	 * Draws an error image
	 *
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         string $message
	 * @returns       void
	 */
	public function drawErrorImage($message, $fontSize = 3) {
		header ("Content-type: image/png");

		//Get the size of the message
		$width  = imagefontwidth($fontSize) * strlen($message);
		$height = imagefontheight($fontSize);

		$img = @imagecreatetruecolor($width, $height);

		if ($img === FALSE) {
			throw new \RuntimeError(
				tr("Could not create GD image stream")
			);
		}

		//Make it transparent
		imagesavealpha($img, true);
		$transparentColour = imagecolorallocatealpha($img, 0, 0, 0, 127);
		imagefill($img, 0, 0, $transparentColour);

		//Get the text color
		$textColor = imagecolorallocate($img, 0, 0, 0);

		//Draw the string
		imagestring($img, $fontSize, 0, 0, $message, $textColor);

		//Output the image
		imagepng($img);
		imagedestroy($img);
	}
}
