<?php

namespace ch\monitoring\util;

use ch\monitoring\model;
use ch\monitoring\datamapper;

/**
 * Class for accessing the settings table
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class Setting {

	/**
	 * Object constuctor
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 */
	private function __construct(){
	}

	/**
	 * Returns a setting value
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @throws        \OutOfBoundsException
	 * @param         string $key
	 * @param         string $defaultValue Optional
	 * @returns       string
	 */
	public static function get($key, $defaultValue = null) {
		try {
			return datamapper\SettingMapper::getInstance()->getByID($key)->value;
		}
		catch (\OutOfBoundsException $e) {
			if ($defaultValue !== null) {
				return $defaultValue;
			}

			throw($e);
		}
	}

	/**
	 * Stores a setting value
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @throws        \OutOfBoundsException
	 * @param         string $key
	 * @param         string $value
	 * @returns       void
	 */
	public static function set($key, $value) {
		try {
			$setting = datamapper\SettingMapper::getInstance()->getByID($key);
		}
		catch (\OutOfBoundsException $e) {
			$setting = new model\Setting();
			$setting->key = $key;
		}

		$setting->value = $value;
		$setting->save();
	}

	/**
	 * Returns whether the monitoring currently is disabled
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       bool
	 */
	public static function monitoringIsDisabled() {
		$avoidalert = self::get('avoidalert_date', '');

		if (empty($avoidalert)) {
			return false;
		}

		$now            = new \Zend_Date();
		$avoidalertDate = new \Zend_Date($avoidalert);

		return $now->isEarlier($avoidalertDate);
	}
}
