<?php

namespace ch\monitoring\util;

/**
 * Time utility class
 *
 * @author        Stefan Heinemann <sh@adfinis.com>
 * @copyright     adfinis GmbH 2012
 * @license       BSD 3-Clause
 **/
class TimeUtility {

	/**
	 * MySQL date format
	 *
	 * @const         string MYSQL_DATE
	 */
	const MYSQL_DATE = 'yyyy-MM-dd';

	/**
	 * MySQL datetime format
	 *
	 * @const         string MYSQL_DATETIME
	 */
	const MYSQL_DATETIME = 'yyyy-MM-dd HH:mm:ss';

	/**
	 * Convert the Zend-Date to insert it into the DB
	 *
	 * @author        Stefan Heinemann <sh@adfinis.com>
	 * @author        David Vogt <dv@adfinis.com>
	 * @param         Zend_Date|null $date
	 * @return        String
	 */
	public static function dateOrNull($date) {
		if ($date instanceof \Zend_Date) {
			return $date->get(\Zend_Date::ISO_8601);
		}

		return null;
	}

	/**
	 * Convert seconds to days, hours, minutes and seconds
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         int $seconds The seconds to be converted
	 * @return        array
	 */
	public static function secondsToDays($seconds) {
		return array(
			'seconds' => $seconds % 60,
			'minutes' => floor(($seconds % (60 * 60)) / 60),
			'hours'   => floor(($seconds % (60 * 60 * 24)) / (60 * 60)),
			'days'    => floor($seconds / 86400)
		);
	}

	/**
	 * Convert seconds to hours, minutes and seconds
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         int $seconds The seconds to be converted
	 * @return        array
	 */
	public static function secondsToHours($seconds) {
		return array(
			'seconds' => $seconds % 60,
			'minutes' => floor(($seconds % (60 * 60)) / 60),
			'hours'   => floor($seconds / (60 * 60)),
		);
	}
}
