<?php

namespace ch\monitoring\util;

use org\adfinis\framework\config\ConfManager;

/*
Copyright [2011] [tompkins@vadian.net]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/**
 * This class uses ASPSMS to send SMS
 *
 * This code was taken from the ASPSMS website, see copyright note above
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2013
 * @license       LGPLv3
 **/
class phpASPSMS {

	private $version;
	private $fields;
	private $UserKey;
	private $Password;
	private $ServiceUrl;
	public $Recipients;
	public $Originator;
	public $MessageText;
	public $DeferredDeliveryTime;
	public $FlashingSMS;
	public $TimeZone;
	public $URLBufferedMessageNotification;
	public $URLDeliveryNotification;
	public $URLNonDeliveryNotification;
	public $AffiliateId;

	/**
	 * Constructor, loads user/pw/serviceURL from ConfManager
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function __construct() {
		$this->Version              = "09.08.2011";
		$this->UserKey              = ConfManager::getVar('sm', 'ASPSMS', 'UserKey');
		$this->Password             = ConfManager::getVar('sm', 'ASPSMS', 'Password');
		$this->ServiceUrl           = ConfManager::getVar('sm', 'ASPSMS', 'ServiceUrl');
		$this->Recipients           = "";
		$this->Originator           = ConfManager::getVar('sm', 'ASPSMS', 'Originator');
		$this->MessageText          = "";
		$this->DeferredDeliveryTime = "";
		$this->FlashingSMS          = "";
		$this->TimeZone             = "";

		$this->URLBufferedMessageNotification = "";
		$this->URLDeliveryNotification        = "";
		$this->URLNonDeliveryNotification     = "";
		$this->AffiliateId                    = "";
	}

	/**
	 * Sends a sms request
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         string $Action The action to execute
	 * @returns       string Answer from the gateway
	 */
	public function ExecutePost($Action) {
		$fields_string = '';

		//url-ify the data for the POST
		foreach ($this->fields as $key => $value) {
			$fields_string .= $key . '=' . $value . '&';
		}
		rtrim($fields_string, '&');

		//open connection
		$ch = curl_init();

		//set the url, number of POST vars, POST data
		curl_setopt($ch, CURLOPT_URL, $this->ServiceUrl . $Action);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_POST, count($this->fields));
		curl_setopt($ch, CURLOPT_POSTFIELDS, $fields_string);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

		//execute post
		$result = curl_exec($ch);

		//close connection
		curl_close($ch);

		//parse results
		$doc = new \DOMDocument();
		$doc->loadXML($result);
		return $doc->firstChild->textContent;
	}

	/**
	 * Send an SMS with the available information
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       string Answer from the gateway
	 */
	public function SendTextSMS() {
		//set parameters
		$this->fields = array(
			'UserKey'                        => urlencode($this->UserKey),
			'Password'                       => urlencode($this->Password),
			'Recipients'                     => urlencode($this->Recipients),
			'Originator'                     => urlencode($this->Originator),
			'MessageText'                    => urlencode(utf8_encode($this->MessageText)),
			'DeferredDeliveryTime'           => urlencode($this->DeferredDeliveryTime),
			'FlashingSMS'                    => urlencode($this->FlashingSMS),
			'TimeZone'                       => urlencode($this->TimeZone),
			'URLBufferedMessageNotification' => urlencode($this->URLBufferedMessageNotification),
			'URLDeliveryNotification'        => urlencode($this->URLDeliveryNotification),
			'URLNonDeliveryNotification'     => urlencode($this->URLNonDeliveryNotification),
			'AffiliateId'                    => urlencode($this->AffiliateId)
		);

		return $this->ExecutePost("SendTextSMS");
	}
}
