<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;

/**
 * Validator for AlertComment objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class AlertCommentValidator extends ModelValidator {

	/**
	 * Validates the alert id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function alertIdValidator() {
		$this->referenceExists('alertId', datamapper\AlertMapper::getInstance());
	}

	/**
	 * Validates the user id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function userIdValidator() {
		$this->referenceExists('userId', datamapper\UserMapper::getInstance());
	}

	/**
	 * Validates the timestamp
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function timestampValidator() {
		// Nothing
	}

	/**
	 * Validates the comment
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function commentValidator() {
		$this->isNotEmpty('comment');
	}

	/**
	 * Validates the complete AlertComment object
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        David Vogt <david.vogt@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('alertId');
		$this->validateField('userId');
		$this->validateField('comment');
	}
}
