<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;

/**
 * Validator for AlertLog objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class AlertLogValidator extends ModelValidator {

	/**
	 * Validates the type id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function typeIdValidator() {
		$this->referenceExists('typeId', datamapper\NotificationTypeMapper::getInstance());
	}

	/**
	 * Validates the user id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function userIdValidator() {
		$this->referenceExists('userId', datamapper\UserMapper::getInstance());
	}

	/**
	 * Validates the alert id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function alertIdValidator() {
		$this->referenceExists('alertId', datamapper\AlertMapper::getInstance());
	}

	/**
	 * Validates the timestamp
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function timestampValidator() {
		// Nothing
	}

	/**
	 * Validates the hasFailed indicator
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function hasFailedValidator() {
		$this->isNotNull('hasFailed');
	}

	/**
	 * Validates the complete AlertLog object
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        David Vogt <david.vogt@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('typeId');
		$this->validateField('userId');
		$this->validateField('alertId');
		$this->validateField('hasFailed');
	}
}
