<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;
use ch\monitoring\model;

/**
 * Validator for AlertTemplateUser objects
 *
 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class AlertTemplateUserValidator extends ModelValidator {

	/**
	 * Validates the foreign key userId
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function userIdValidator() {
		$this->referenceExists('userId', datamapper\UserMapper::getInstance());
	}

	/**
	 * Validates the foreign key templateId
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function templateIdValidator() {
		if(!is_null($this->model->templateId)) {
			$this->referenceExists('templateId', datamapper\AlertTemplateMapper::getInstance());
		}
	}


	/**
	 * Validates the foreign key slaActionId
	 *
	 * @returns       void
	 */
	protected function slaActionIdValidator() {
		$this->referenceExists('slaActionId', datamapper\SLAActionMapper::getInstance());
	}

	/**
	 * Validates the complete AlertTemplateUser object
	 *
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('userId');
		$this->validateField('slaActionId');
		$this->validateField('templateId');
	}
}
