<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;

/**
 * Validator for AlertTemplate objects
 *
 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class AlertTemplateValidator extends ModelValidator {

	/**
	 * Validates the alert action id
	 *
	 * @returns       void
	 */
	protected function slaActionIdValidator() {
		$this->referenceExists(
			'slaActionId',
			datamapper\SLAActionMapper::getInstance()
		);
	}

	/**
	 * Validates the name
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function nameValidator() {
		$this->isNotEmpty('name');
		$this->nameIsFree('name');
	}

	/**
	 * Validates the description
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function descriptionValidator() {
		$this->isNotEmpty('description');
	}

	/**
	 * Validates the content
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function contentValidator() {
		$this->isNotEmpty('content');
	}

	/**
	 * Validates the complete Command object
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('name');
		$this->validateField('description');
		$this->validateField('content');
	}
}
