<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;

/**
 * Validator for Application objects
 *
 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2015
 * @license       LGPLv3
 **/
class BREApplicationValidator extends ModelValidator {

	/**
	 * Validates the customer id
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function customerIdValidator() {
		$this->referenceExists('customerId', datamapper\CustomerMapper::getInstance());
	}

	/**
	 * Validates the name of the application
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function nameValidator() {
		$this->isNotNull('name');
	}

	/**
	 * Validates the amount of minimal available components
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function minAvailableValidator() {
		$this->isGreaterThanOrEqualZero('minAvailable');
	}

	/**
	 * Validates the complete Application object
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('customerId');
		$this->validateField('name');
		$this->validateField('minAvailable');
	}
}
