<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;

/**
 * Validator for Component objects
 *
 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2015
 * @license       LGPLv3
 **/
class BREComponentValidator extends ModelValidator {

	/**
	 * Validates the name of the component
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function nameValidator() {
		$this->isNotNull('name');
	}

	/**
	 * Validates the amount of minimal available components
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function minAvailableValidator() {
		$this->isGreaterThanOrEqualZero('minAvailable');
	}

	/**
	 * Validates the application id
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function applicationIdValidator() {
		$this->referenceExists('applicationId', datamapper\BREApplicationMapper::getInstance());
	}

	/**
	 * Validates the parent id
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function parentIdValidator() {
		// TODO: parentId is not allow to be $this->id
		$this->referenceExists('parentId', datamapper\BREComponentMapper::getInstance());
	}

	/**
	 * Validates the complete Component object
	 *
	 * @author        Pablo Vergés <pablo.verges@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('name');
		$this->validateField('minAvailable');
		$this->validateField('applicationId');
		$this->validateField('parentId');
	}
}
