<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;

/**
 * Validator for Command objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class CommandValidator extends ModelValidator {

	/**
	 * Validates the name
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function nameValidator() {
		$this->isNotEmpty('name');
		$this->isNagiosString('name');
		$this->nameIsFree('name');
	}

	/**
	 * Validates the description
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function descriptionValidator() {
		$this->isNotEmpty('description');
	}

	/**
	 * Validates the commandline
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function commandlineValidator() {
		$this->isNotEmpty('commandline');
	}

	/**
	 * Validates the v6Capable flag
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function v6CapableValidator() {
		$this->isNotNull('v6Capable');
	}

	/**
	 * Validates the isDeleted flag
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function isDeletedValidator() {
		// Nothing
	}

	/**
	 * Validates the complete Command object
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        David Vogt <david.vogt@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('name');
		$this->validateField('description');
		$this->validateField('commandline');
		$this->validateField('v6Capable');
	}
}
