<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;

/**
 * Validator for Downtime objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class DowntimeValidator extends ModelValidator {

	/**
	 * Validates the host id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function hostIdValidator() {
		$this->referenceExists('hostId', datamapper\HostMapper::getInstance());
	}

	/**
	 * Validates the service instance id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function serviceInstanceIdValidator() {
		if ($this->model->serviceInstanceId !== null) {
			$this->referenceExists('serviceInstanceId', datamapper\HostServiceInstanceMapper::getInstance());
		}
	}

	/**
	 * Validates the datetimeFrom
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function datetimeFromValidator() {
		$this->isNotNull('datetimeFrom');
	}

	/**
	 * Validates the datetimeTo
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function datetimeToValidator() {
		//$this->isNotNull('datetimeTo');
	}

	/**
	 * Validates the rrule
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function rruleValidator() {
		//nothing
	}

	/**
	 * Validates the durationHours
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function durationHoursValidator() {
		//nothing
	}

	/**
	 * Validates the complete Downtime object
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        David Vogt <david.vogt@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('hostId');
		$this->validateField('serviceInstanceId');
		$this->validateField('datetimeFrom');
		$this->validateField('datetimeTo');
		$this->validateField('rrule');
		$this->validateField('durationHours');
	}
}
