<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;
use ch\monitoring\Application;
use ch\monitoring\model;

/**
 * Validator for Guideline objects
 *
 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class GuidelineValidator extends ModelValidator {

	/**
	 * Validates the user id
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function userIdValidator() {
		$this->referenceExists('userId', datamapper\UserMapper::getInstance());
	}

	/**
	 * Validates the name
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function nameValidator() {
		$this->isNotEmpty('name');
		$this->nameIsFree('name');
	}

	/**
	 * Validates the content
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function contentValidator() {
		$this->isNotEmpty('content');
	}

	/**
	 * Validates the description
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function descriptionValidator() {
		$this->isNotEmpty('description');
	}

	/**
	 * Validates the creation date and time
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function createdValidator() {
		$this->isNotNull('created');
	}


	/**
	 * Validates the updated datetime
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function updatedValidator() {
		$this->isNotNull('updated');
	}

	/**
	 * Validates the HostOSVersion ID.
	 *
	 * @author        Tobias Feller <tobias.feller@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function versionIdValidator() {
		$this->referenceExists(
			'versionId',
			datamapper\HostOSVersionMapper::getInstance()
		);
	}

	/**
	 * Validates the Command ID.
	 *
	 * @author        Tobias Feller <tobias.feller@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function commandIdValidator() {
		$this->referenceExists(
			'commandId',
			datamapper\CommandMapper::getInstance()
		);
	}
	/**
	 * Validates the complete Guideline object
	 *
	 * @author        Matthieu Riolo <matthieu.riolo@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		//$this->validateField('name');
		//$this->validateField('description');
		$this->validateField('content');
		$this->validateField('created');
		$this->validateField('updated');
		$this->validateField('userId');
		$this->validateField('versionId');
		$this->validateField('commandId');
	}
}
