<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;
use ch\monitoring\model;

/**
 * Validator for HostOS objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class HostOSValidator extends ModelValidator {

	/**
	 * Validates the name
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function nameValidator() {
		$this->isNotEmpty('name');
	}

	/**
	 * Validates the image
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function imageValidator() {
		$this->isNotEmpty('image');
	}

	/**
	 * Validates the architecture
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @author        Tobias Feller <tobias.feller@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function architectureValidator() {
		$this->referenceExists('architecture', datamapper\HostOSArchitectureMapper::getInstance());
	}

	/**
	 * Validates the complete HostOS object
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        David Vogt <david.vogt@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('name');
		$this->validateField('image');
	}
}
