<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;

/**
 * Validator for HostOSVersion objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class HostOSVersionValidator extends ModelValidator {

	/**
	 * Validates the os id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function osIdValidator() {
		$this->referenceExists('osId', datamapper\HostOSMapper::getInstance());
	}

	/**
	 * Validates the name
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function nameValidator() {
		$this->isNotEmpty('name');
	}

	/**
	 * Validates the short name
	 *
	 * @author        Tobias Feller <tobias.feller@adfinis-sygroup.ch>
	 * @return        void
	 */
	protected function shortNameValidator() {
		$this->isExtendedAlphaNumeric('shortName');
		$this->isNotEmpty('shortName');
		$this->shortNameIsFree();
	}

	/**
	 * Validates the architecture id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function architectureIdValidator() {
		$this->referenceExists(
			'architectureId',
			datamapper\HostOSArchitectureMapper::getInstance()
		);
	}

	/**
	 * Validates the complete HostOSVersion object
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        David Vogt <david.vogt@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('osId');
		$this->validateField('name');
		$this->validateField('architectureId');
		$this->validateField('shortName');
	}

	/**
	 * Verifies whether the shortname is free
	 *
	 * @author        Tobias Feller <tobias.feller@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function shortNameIsFree() {
		try {
			$entity = $this->model->getMapper()->getByShortName(
				$this->model->shortName,
				$this->model->osId
			)->allowRead();

			// Probably we found ourself :)
			if ($entity->doesRecordMatch($this->model->getIdentifier())) {
				return;
			}

			$this->setIsInvalid(
				'shortName',
				tr('The short name is already in use')
			);
		}
		catch (\OutOfBoundsException $e) {
			// Name is free so don't do anything
			return;
		}
	}
}
