<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;

/**
 * Validator for HostServiceArgument objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class HostServiceArgumentValidator extends ModelValidator {

	/**
	 * Validates the host service instance assignment id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function instanceIdValidator() {
		$this->referenceExists('instanceId', datamapper\HostServiceInstanceMapper::getInstance());
	}

	/**
	 * Validates the service argument id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function serviceArgumentIdValidator() {
		$this->referenceExists('serviceArgumentId', datamapper\ServiceArgumentMapper::getInstance());
	}

	/**
	 * Validates the assigned value
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function assignedValueValidator() {
		$this->isNotNull('assignedValue');
		$this->containsNot('assignedValue', "'");
	}

	/**
	 * Validates the complete HostServiceArgument object
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        David Vogt <david.vogt@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('instanceId');
		$this->validateField('serviceArgumentId');
		$this->validateField('assignedValue');
	}
}
