<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;

/**
 * Validator for HostService objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class HostServiceInstanceValidator extends ModelValidator {

	/**
	 * Validates the host service id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function hostServiceIdValidator() {
		$this->referenceExists('hostServiceId', datamapper\HostServiceMapper::getInstance());
	}

	/**
	 * Validates the sla id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function slaIdValidator() {
		if ($this->model->slaId !== null) {
			$this->referenceExists('slaId', datamapper\SLAMapper::getInstance());
		}
	}

	/**
	 * Validates the name
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function nameValidator() {
		if ($this->model->name !== null) {
			$this->isNotEmpty('name');
			$this->isNagiosString('name');

			try {
				$entity = $this->model->getMapper()->getByName(
					$this->model->name,
					$this->model->getHostService()->hostId,
					$this->model->getHostService()->serviceId
				);

				$entity->allowRead();

				// Probably we found ourself :)
				if (!$entity->doesRecordMatch($this->model->getIdentifier())) {
					$this->setIsInvalid(
						'name',
						sprintf(
							tr('The name "%s" is already in use'),
							$this->model->name
						)
					);
				}
			}
			catch (\OutOfBoundsException $e) {
				// Name is free so don't do anything
			}
		}
	}

	/**
	 * Validates the isPassive flag
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function isPassiveValidator() {
		$this->isNotNull('isPassive');
	}

	/**
	 * Validates the isEnabled flag
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function isEnabledValidator() {
		$this->isNotNull('isEnabled');
	}

	/**
	 * Validates the hasTrouble flag
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function hasTroubleValidator() {
		$this->isNotNull('hasTrouble');
	}

	/**
	 * Validates the forAvailability flag
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function forAvailabilityValidator() {
		$this->isNotNull('forAvailability');
	}

	/**
	 * Validates the complete HostService object
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        David Vogt <david.vogt@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('hostServiceId');
		$this->validateField('slaId');
		$this->validateField('name');
		$this->validateField('isPassive');
		$this->validateField('isEnabled');
		$this->validateField('hasTrouble');
		$this->validateField('forAvailability');
	}
}
