<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;

/**
 * Validator for HostService objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class HostServiceValidator extends ModelValidator {

	/**
	 * Validates the host id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function hostIdValidator() {
		$this->referenceExists('hostId', datamapper\HostMapper::getInstance());
	}

	/**
	 * Validates the service id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function serviceIdValidator() {
		if ($this->model->serviceId !== null) {
			$this->referenceExists('serviceId', datamapper\ServiceMapper::getInstance());
		}
	}

	/**
	 * Validates the complete HostService object
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        David Vogt <david.vogt@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('hostId');
		$this->validateField('serviceId');
	}
}
