<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;
use ch\monitoring\model;

/**
 * Validator for ImportCommand objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class ImportCommandValidator extends ModelValidator {

	/**
	 * Validates the file id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function fileIdValidator() {
		$this->referenceExists('fileId', datamapper\ImportFileMapper::getInstance());
	}

	/**
	 * Validates the hostgroup id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function commandIdValidator() {
		if ($this->model->commandId !== null) {
			$this->referenceExists('commandId', datamapper\CommandMapper::getInstance());
		}
	}

	/**
	 * Validates the command_name
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function command_nameValidator() {
		// Nothing
	}

	/**
	 * Validates the command_line
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function command_lineValidator() {
		// Nothing
	}

	/**
	 * Validates the register flag
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function registerValidator() {
		// Nothing
	}

	/**
	 * Validates the complete ImportCommand object
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        David Vogt <david.vogt@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('fileId');
		$this->validateField('commandId');
	}
}
