<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;
use ch\monitoring\model;

/**
 * Validator for ImportFile objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class ImportFileValidator extends ModelValidator {

	/**
	 * Validates the name
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function nameValidator() {
		$this->isNotEmpty('name');
	}

	/**
	 * Validates the hosts count
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function hostsValidator() {
		$this->isGreaterThanOrEqualZero('hosts');
	}

	/**
	 * Validates the services count
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function servicesValidator() {
		$this->isGreaterThanOrEqualZero('services');
	}

	/**
	 * Validates the commands count
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function commandsValidator() {
		$this->isGreaterThanOrEqualZero('commands');
	}

	/**
	 * Validates the hostgroups count
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function hostgroupsValidator() {
		$this->isGreaterThanOrEqualZero('hostgroups');
	}

	/**
	 * Validates the complete ImportFile object
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        David Vogt <david.vogt@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('name');
		$this->validateField('hosts');
		$this->validateField('services');
		$this->validateField('commands');
		$this->validateField('hostgroups');
	}
}
