<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;
use ch\monitoring\model;

/**
 * Validator for ImportHost objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class ImportHostValidator extends ModelValidator {

	/**
	 * Validates the file id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function fileIdValidator() {
		$this->referenceExists('fileId', datamapper\ImportFileMapper::getInstance());
	}

	/**
	 * Validates the host id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function hostIdValidator() {
		if ($this->model->hostId !== null) {
			$this->referenceExists('hostId', datamapper\HostMapper::getInstance());
		}
	}

	/**
	 * Validates the os id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function osIdValidator() {
		if ($this->model->osId !== null) {
			$this->referenceExists('osId', datamapper\HostOSMapper::getInstance());
		}
	}

	/**
	 * Validates the customer id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function customerIdValidator() {
		if ($this->model->customerId !== null) {
			$this->referenceExists('customerId', datamapper\CustomerMapper::getInstance());
		}
	}

	/**
	 * Validates the host_name
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function host_nameValidator() {
		// Nothing
	}

	/**
	 * Validates the alias
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function aliasValidator() {
		// Nothing
	}

	/**
	 * Validates the address
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function addressValidator() {
		// Nothing
	}

	/**
	 * Validates the parents
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function parentsValidator() {
		// Nothing
	}

	/**
	 * Validates the hostgroups
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function hostgroupsValidator() {
		// Nothing
	}

	/**
	 * Validates the register flag
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function registerValidator() {
		// Nothing
	}

	/**
	 * Validates the complete ImportHost object
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        David Vogt <david.vogt@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('fileId');
		$this->validateField('hostId');
	}
}
