<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;
use ch\monitoring\model;

/**
 * Validator for ImportService objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class ImportServiceValidator extends ModelValidator {

	/**
	 * Validates the file id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function fileIdValidator() {
		$this->referenceExists('fileId', datamapper\ImportFileMapper::getInstance());
	}

	/**
	 * Validates the service id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function serviceIdValidator() {
		if ($this->model->serviceId !== null) {
			$this->referenceExists('serviceId', datamapper\ServiceMapper::getInstance());
		}
	}

	/**
	 * Validates the host_name
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function host_nameValidator() {
		// Nothing
	}

	/**
	 * Validates the hostgroup_name
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function hostgroup_nameValidator() {
		// Nothing
	}

	/**
	 * Validates the service_description
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function service_descriptionValidator() {
		// Nothing
	}

	/**
	 * Validates the check_command
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function check_commandValidator() {
		// Nothing
	}

	/**
	 * Validates the max_check_attempts
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function max_check_attemptsValidator() {
		// Nothing
	}

	/**
	 * Validates the check_interval
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function check_intervalValidator() {
		// Nothing
	}

	/**
	 * Validates the retry_interval
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function retry_intervalValidator() {
		// Nothing
	}

	/**
	 * Validates the register flag
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function registerValidator() {
		// Nothing
	}

	/**
	 * Validates the complete ImportService object
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        David Vogt <david.vogt@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('fileId');
		$this->validateField('serviceId');
	}
}
