<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;
use ch\monitoring\model;

/**
 * Validator for Infofeed objects
 *
 * @copyright     Adfinis SyGroup AG 2014
 * @license       LGPLv3
 **/
class InfofeedValidator extends ModelValidator {

	/**
	 * Validates the user id
	 *
	 * @returns       void
	 */
	protected function userIdValidator() {
		$this->referenceExists('userId', datamapper\UserMapper::getInstance());
	}

	/**
	 * Validates the onAlert field
	 *
	 * @returns       void
	 */
	protected function onAlertValidator() {
		$this->isNotNull('onAlert');
	}

	/**
	 * Validates the onWarning field
	 *
	 * @returns       void
	 */
	protected function onWarningValidator() {
		$this->isNotNull('onWarning');
	}

	/**
	 * Validates the onAcknowledge field
	 *
	 * @returns       void
	 */
	protected function onAcknowledgeValidator() {
		$this->isNotNull('onAcknowledge');
	}

	/**
	 * Validates the complete Infofeed object
	 *
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('userId');
		$this->validateField('onAlert');
		$this->validateField('onWarning');
		$this->validateField('onAcknowledge');
	}
}
