<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;

/**
 * Validator for MaintenanceComment objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class  MaintenanceCommentValidator extends ModelValidator {

	/**
	 * Validates the maintenance id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function ticketHostIdValidator() {
		$this->referenceExists('ticketHostId', datamapper\MaintenanceTicketHostMapper::getInstance());
	}

	/**
	 * Validates the user id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function userIdValidator() {
		$this->referenceExists('userId', datamapper\UserMapper::getInstance());
	}

	/**
	 * Validates the old state id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function oldStateIdValidator() {
		if ($this->model->oldStateId !== null) {
			$this->referenceExists('oldStateId', datamapper\MaintenanceStateMapper::getInstance());
		}
	}

	/**
	 * Validates the new state id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function newStateIdValidator() {
		if ($this->model->newStateId !== null) {
			$this->referenceExists('newStateId', datamapper\MaintenanceStateMapper::getInstance());
		}
	}

	/**
	 * Validates the old OS version
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function oldOsVersionIdValidator() {
		if ($this->model->oldOsVersionId !== null) {
			$this->referenceExists('oldOsVersionId', datamapper\HostOSVersionMapper::getInstance());
		}
	}

	/**
	 * Validates the new OS version
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function newOsVersionIdValidator() {
		if ($this->model->newOsVersionId !== null) {
			$this->referenceExists('newOsVersionId', datamapper\HostOSVersionMapper::getInstance());
		}
	}

	/**
	 * Validates the timestamp
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function timestampValidator() {
		$this->isNotNull('timestamp');
	}

	/**
	 * Validates the comment
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function commentValidator() {
		// Nothing
	}

	/**
	 * Validates the complete MaintenanceComment object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('ticketHostId');
		$this->validateField('userId');
		$this->validateField('oldStateId');
		$this->validateField('newStateId');
		$this->validateField('oldOsVersionId');
		$this->validateField('newOsVersionId');
		$this->validateField('timestamp');
	}
}
