<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;
use ch\monitoring\model;

/**
 * Validator for MaintenanceGroup objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class MaintenanceGroupValidator extends ModelValidator {

	/**
	 * Validates the maintenance cycle id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function maintenanceCycleIdValidator() {
		if ($this->model->maintenanceCycleId !== null) {
			$this->referenceExists('maintenanceCycleId', datamapper\MaintenanceCycleMapper::getInstance());
		}
	}

	/**
	 * Validates the name
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function nameValidator() {
		$this->isNotEmpty('name');
		$this->nameIsFree('name');
	}

	/**
	 * Validates the description
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function descriptionValidator() {
		$this->isNotEmpty('description');
	}

	/**
	 * Validates the dateStart
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function dateStartValidator() {
		// Nothing.
	}

	/**
	 * Validates the complete MaintenanceGroup object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('maintenanceCycleId');
		$this->validateField('name');
		$this->validateField('description');
	}
}
