<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;
use ch\monitoring\model;

/**
 * Validator for MaintenanceTicketHost objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class  MaintenanceTicketHostValidator extends ModelValidator {

	/**
	 * Validates the ticket id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function ticketIdValidator() {
		$this->referenceExists('ticketId', datamapper\MaintenanceTicketMapper::getInstance());
	}

	/**
	 * Validates the host id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function hostIdValidator() {
		$this->referenceExists('hostId', datamapper\HostMapper::getInstance());
	}

	/**
	 * Validates the state id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function stateIdValidator() {
		$this->referenceExists('stateId', datamapper\MaintenanceStateMapper::getInstance());
	}

	/**
	 * Validates the changed datetime
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function datetimeChangedValidator() {
		// Nothing
	}

	/**
	 * Validates the complete MaintenanceTicketHost object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('ticketId');
		$this->validateField('hostId');
		$this->validateField('stateId');
	}
}
