<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;
use ch\monitoring\model;

/**
 * Validator for MaintenanceTicket objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class  MaintenanceTicketValidator extends ModelValidator {

	/**
	 * Validates the group id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function groupIdValidator() {
		if ($this->model->groupId !== null) {
			$this->referenceExists('groupId', datamapper\MaintenanceGroupMapper::getInstance());
		}
	}

	/**
	 * Validates the customer id
	 *
	 * @returns       void
	 */
	protected function customerIdValidator() {
		$this->referenceExists('customerId', datamapper\CustomerMapper::getInstance());
	}

	/**
	 * Validates the user id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function userIdValidator() {
		if ($this->model->userId !== null) {
			$this->referenceExists('userId', datamapper\UserMapper::getInstance());
		}
	}

	/**
	 * Validates the creation date
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function dateCreatedValidator() {
		$this->isNotNull('dateCreated');
	}

	/**
	 * Validates the due date
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function dateDueValidator() {
		// Nothing
	}

	/**
	 * Validates the dateArchived flag
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function dateArchivedValidator() {
		// Nothing
	}

	/**
	 * Validates the complete MaintenanceTicket object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('groupId');
		$this->validateField('customerId');
		$this->validateField('userId');
		$this->validateField('dateCreated');
	}
}
