<?php

namespace ch\monitoring\validate;

/**
 * Validator for NagiosLog objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class  NagiosLogValidator extends ModelValidator {

	/**
	 * Validates the timestamp
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function timestampValidator() {
		// Nothing
	}

	/**
	 * Validates the objectType
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function objectTypeValidator() {
		$list = array(
			'HOST',
			'SERVICE'
		);
		$this->isInList('objectType', $list);
	}

	/**
	 * Validates the stateType
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function stateTypeValidator() {
		$list = array(
			'SOFT',
			'HARD'
		);
		$this->isInList('stateType', $list);
	}

	/**
	 * Validates the state
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function stateValidator() {
		$list = array(
			'UP',
			'DOWN',
			'UNREACHABLE',
			'OK',
			'WARNING',
			'UNKNOWN',
			'CRITICAL'
		);
		$this->isInList('state', $list);
	}

	/**
	 * Validates the timestamp
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function nameValidator() {
		$this->isNotEmpty('name');
	}

	/**
	 * Validates the hostname
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function hostnameValidator() {
		$this->isNotEmpty('hostname');
	}

	/**
	 * Validates the check command
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function checkCommandValidator() {
		$this->isNotEmpty('checkCommand');
	}

	/**
	 * Validates the address
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function addressValidator() {
		$this->isNotEmpty('address');
	}

	/**
	 * Validates the performance data
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function perfdataValidator() {
		// Nothing
	}

	/**
	 * Validates the duration
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function durationValidator() {
		$this->isNotEmpty('duration');
	}

	/**
	 * Validates the datetime
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function datetimeValidator() {
		$this->isNotNull('datetime');
	}

	/**
	 * Validates the attempt
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function datetimeValidator() {
		$this->isGreaterThanZero('attempt');
	}

	/**
	 * Validates the processing status
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function processedValidator() {
		$list = array(0, 1, 2, 3, 4, 5, 6, 7, 8, 9);
		$this->isInList('processed', $list);
	}

	/**
	 * Validates the complete NagiosLog object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('objectType');
		$this->validateField('stateType');
		$this->validateField('state');
		$this->validateField('name');
		$this->validateField('hostname');
		$this->validateField('checkCommand');
		$this->validateField('address');
		$this->validateField('output');
		$this->validateField('duration');
		$this->validateField('datetime');
		$this->validateField('attempt');
		$this->validateField('processed');
	}
}
