<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;
use ch\monitoring\Application;
use ch\monitoring\model;

/**
 * Validator for Report objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class ReportValidator extends ModelValidator {

	/**
	 * Validates the timestamp
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function timestampValidator() {
		$this->isNotNull('timestamp');
	}

	/**
	 * Validates the user id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function userIdValidator() {
		$this->referenceExists('userId', datamapper\UserMapper::getInstance());
	}

	/**
	 * Validates the customer id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function customerIdValidator() {
		$this->referenceExists('customerId', datamapper\CustomerMapper::getInstance());
	}

	/**
	 * Validates the date from
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function dateFromValidator() {
		$this->isNotNull('dateFrom');
	}

	/**
	 * Validates the date to
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function dateToValidator() {
		$this->isNotNull('dateTo');
	}

	/**
	 * Validates the isTemplate flag
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function isTemplateValidator() {
		$this->isNotNull('isTemplate');
	}

	/**
	 * Validates the complete Report object
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        David Vogt <david.vogt@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('timestamp');
		$this->validateField('userId');
		$this->validateField('customerId');
		$this->validateField('dateFrom');
		$this->validateField('dateTo');
		$this->validateField('isTemplate');
	}
}
