<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;
use ch\monitoring\model;

/**
 * Validator for SLA objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class SLAValidator extends ModelValidator {

	/**
	 * Validates the customer id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function customerIdValidator() {
		if ($this->model->customerId !== null) {
			$this->referenceExists('customerId', datamapper\CustomerMapper::getInstance());
		}
	}

	/**
	 * Validates the name
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function nameValidator() {
		$this->isNotEmpty('name');
		$this->nameIsFree('name');
	}

	/**
	 * Validates the description
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function descriptionValidator() {
		$this->isNotEmpty('description');
	}

	/**
	 * Validates the cycle delay
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function delayCycleValidator() {
		$this->isGreaterThanOrEqualZero('delayCycle');
		$this->isLessThanOrEqual('delayCycle', 10080);
	}

	/**
	 * Validates the restart delay
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function delayRestartValidator() {
		$this->isGreaterThanOrEqualZero('delayRestart');
		$this->isLessThanOrEqual('delayRestart', 10080);
	}

	/**
	 * Validates the timeout
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function timeoutValidator() {
		$this->isGreaterThanOrEqualZero('timeout');
		$this->isLessThanOrEqual('timeout', 10080);
	}

	/**
	 * Validates the min availability
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function minAvailabilityValidator() {
		$this->isGreaterThanOrEqual('minAvailability', 0);
		$this->isLessThanOrEqual('minAvailability', 100);
	}

	/**
	 * Validates the isDeleted flag
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function isDeletedValidator() {
		// Nothing
	}

	/**
	 * Validates the complete SLA object
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        David Vogt <david.vogt@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('customerId');
		$this->validateField('name');
		$this->validateField('description');
		$this->validateField('delayCycle');
		$this->validateField('delayRestart');
		$this->validateField('timeout');
		$this->validateField('minAvailability');
	}
}
