<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;

/**
 * Validator for HostServiceArgument objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class ServiceArgumentValidator extends ModelValidator {

	/**
	 * Validates the service id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function serviceIdValidator() {
		$this->referenceExists('serviceId', datamapper\ServiceMapper::getInstance());
	}

	/**
	 * Validates the position
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function positionValidator() {
		$this->isGreaterThanOrEqualZero('position');
	}

	/**
	 * Validates the option
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function optionValidator() {
		// Nothing
	}

	/**
	 * Validates the value
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function valueValidator() {
		$this->containsNot('value', "'");
	}

	/**
	 * Validates the description
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function descriptionValidator() {
		// Nothing
	}

	/**
	 * Validates the type
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function typeValidator() {
		$list = array(
			'Fixed',
			'Variable'
		);
		$this->isInList('type', $list);
	}

	/**
	 * Validates the complete HostServiceArgument object
	 *
	 * @author        Adrian Wittwer <aw@adfinis.com>
	 * @author        David Vogt <david.vogt@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('serviceId');
		$this->validateField('position');
		$this->validateField('type');
		$this->validateField('value');
	}
}
