<?php

namespace ch\monitoring\validate;

use ch\monitoring\datamapper;

/**
 * Validator for TimeframeRule objects
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2012
 * @license       LGPLv3
 **/
class TimeframeRuleValidator extends ModelValidator {

	/**
	 * Validates the timeframe id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function timeframeIdValidator() {
		$this->referenceExists('timeframeId', datamapper\TimeframeMapper::getInstance());
	}

	/**
	 * Validates the action id
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function actionIdValidator() {
		$this->referenceExists('actionId', datamapper\SLAActionMapper::getInstance());
	}

	/**
	 * Validates the delay
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	protected function delayValidator() {
		$this->isGreaterThanOrEqualZero('delay');
		$this->isLessThanOrEqual('delay', 10080);
	}

	/**
	 * Validates the complete TimeframeRule object
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @returns       void
	 */
	public function validateEntity() {
		$this->validateField('timeframeId');
		$this->validateField('actionId');
		$this->validateField('delay');
	}
}
