<?php

namespace ch\monitoring\view;

use org\adfinis\framework\template\Skittle;

/**
 * Abstract definition of an View class
 *
 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2014
 * @license       LGPLv3
 **/
abstract class View {

	/**
	 * Template renderer
	 *
	 * @var           Smarty $tpl
	 */
	protected $tpl;

	/**
	 * Associated model to render
	 *
	 * @var           \org\adfinis\framework\model\Entity $model
	 */
	protected $model;

	/**
	 * Create a new view handler class
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @param         \org\adfinis\framework\model\Entity $model
	 * @param         \org\adfinis\framework\template\Skittle $tpl
	 */
	public function __construct($model = null, $tpl = null) {
		$this->tpl   = !$tpl ? (!$tpl instanceof Skittle ? new Skittle() : $tpl) : $tpl;
		$this->model = $model;
		$this->assignDefaultVariables();
	}

	/**
	 * Initialize default template variables
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @return        void
	 */
	public function assignDefaultVariables() {
		$this->tpl->registerClass("Permission", "\ch\monitoring\model\Permission");

		$this->tpl->assign('model', $this->model);
		$this->tpl->assign('view',  $this);
	}

	/**
	 * Assign additional values to the template
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @param         string|array<mixed> $var
	 * @param         mixed               $value [optional]
	 * @return        View
	 */
	public function assign($var, $value = null) {
		$this->tpl->assign($var, $value);

		return $this;
	}

	/**
	 * Render this view to string when casted to string
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @return        string
	 */
	public function __toString() {
		return $this->render();
	}

	/**
	 * Used to parse this view to string
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @param         string $tpl
	 * @return        string
	 */
	abstract function render($tpl);
}