<?php

namespace ch\monitoring\view\datatable;

use \ch\monitoring\model;

/**
 * View for DataTable for Hosts
 *
 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2014
 * @license       LGPLv3
 **/
class Downtime extends View  {

	/**
	 * The customer field
	 */
	const CUSTOMER = 'customer';

	/**
	 * The hostname field
	 */
	const HOST = 'hostname';

	/**
	 * The service field
	 */
	const SERVICES = 'service';

	/**
	 * The from field
	 */
	const FROM = 'from';

	/**
	 * The to field
	 */
	const TO = 'to';

	/**
	 * The recurring field
	 */
	const RECURRING = 'recurring';

	/**
	 * The button field
	 */
	const ACTIONS = 'actions';

	/**
	 * Initialize default template variables
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @return        void
	 */
	public function assignDefaultVariables() {
		parent::assignDefaultVariables();

		$this->assign('user', model\User::getOrCreateActive());
	}

	/**
	 * Used to parse this Host view to string
	 *
	 * You only need to specify the field template, path is automatically prepended
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @param         string $tpl
	 * @return        string
	 */
	public function render($tpl) {
		$tpl = sprintf('maintenance/datatable/downtime/%s', $tpl);
		return $this->tpl->fetch($tpl);
	}

	/**
	 * Get all relevant data in a compatible format for DataTables
	 * Get the DataTable mapping, if not initialized yet, initialize them
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @return        array
	 * @return        void
	 */
	public function getDataTableData() {
		$data = [];

		foreach ($this->getFieldTemplates() as $field => $tpl) {
			$this->tpl->assign('field', $field);
			$data[] = $this->render($tpl);
		}

		return $data;
	}

	/**
	 * Get the DataTable mapping, if not initialized yet, initialize them
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @return        void
	 */
	public static function getDataTableMapping() {
		if (!static::$dataTableMapping) {
			static::$dataTableMapping = [
				static::CUSTOMER  => ['customer.tpl',  static::FIELD_SEARCHABLE],
				static::HOST      => ['host.tpl',      static::FIELD_SEARCHABLE],
				static::SERVICES  => ['services.tpl',  static::FIELD_SEARCHABLE],
				static::FROM      => ['date.tpl'],
				static::TO        => ['date.tpl'],
				static::RECURRING => ['recurring.tpl'],
				static::ACTIONS   => ['actions.tpl']
			];
		}

		return static::$dataTableMapping;
	}
}
