<?php

namespace ch\monitoring\view\datatable;

use \ch\monitoring\model;

/**
 * View for DataTable for Hosts
 *
 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2014
 * @license       LGPLv3
 **/
class Host extends View  {

	/**
	 * The IP field
	 */
	const IP = 'ip';

	/**
	 * The customer field
	 */
	const CUSTOMER = 'customer';

	/**
	 * The hostname field
	 */
	const HOSTNAME = 'hostname';

	/**
	 * The hostname sort field
	 */
	const HOSTNAME_SORT = 'hostname_sort';

	/**
	 * The description field
	 */
	const DESCRIPTION = 'description';

	/**
	 * The wiki field
	 */
	const WIKI = 'wiki';

	/**
	 * The button field
	 */
	const ACTIONS = 'actions';

	/**
	 * Initialize default template variables
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @return        void
	 */
	public function assignDefaultVariables() {
		parent::assignDefaultVariables();

		$this->assign('user', model\User::getOrCreateActive());
	}

	/**
	 * Used to parse this Host view to string
	 *
	 * You only need to specify the field template, path is automatically prepended
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @param         string $tpl
	 * @return        string
	 */
	public function render($tpl) {
		$tpl = sprintf('hosts/datatable/%s', $tpl);
		return $this->tpl->fetch($tpl);
	}

	/**
	 * Get the DataTable mapping, if not initialized yet, initialize them
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @return        void
	 */
	public static function getDataTableMapping() {
		if (!static::$dataTableMapping) {
			static::$dataTableMapping = [
				static::IP            => ['ip.tpl',           static::FIELD_SEARCHABLE],
				static::CUSTOMER      => ['customer.tpl',     static::FIELD_SEARCHABLE],
				static::HOSTNAME_SORT => ['hostnameSort.tpl', static::FIELD_SEARCHABLE],
				static::HOSTNAME      => ['hostname.tpl'],
				static::DESCRIPTION   => ['description.tpl',  static::FIELD_SEARCHABLE],
				static::WIKI          => ['wiki.tpl'],
				static::ACTIONS       => ['actions.tpl']
			];
		}

		return static::$dataTableMapping;
	}
}
