<?php

namespace ch\monitoring\view\datatable;

use \ch\monitoring\model;

/**
 * View for DataTable for Hosts
 *
 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2014
 * @license       LGPLv3
 **/
class MaintenanceHost extends Host  {

	/**
	 * The customer field
	 */
	const HOST_ID = 'host_id';

	/**
	 * The customer field
	 */
	const CUSTOMER = 'customer';

	/**
	 * The customer field
	 */
	const HOST_OS = 'host_os';

	/**
	 * The customer field
	 */
	const HOST_SERVICES = 'host_services';

	/**
	 * The button field
	 */
	const ACTIONS = 'actions';

	/**
	 * Used to parse this Host view to string
	 *
	 * You only need to specify the field template, path is automatically prepended
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @param         string $tpl
	 * @return        string
	 */
	public function render($tpl) {
		$tpl = sprintf('maintenance/datatable/host/%s', $tpl);
		return $this->tpl->fetch($tpl);
	}

	/**
	 * Get the DataTable mapping, if not initialized yet, initialize them
	 *
	 * structure:
	 * 	array [
	 * 		model::FIELD => [ "template.tpl", self::FIELD_FLAGS | ... ],
	 * 		(string)          (string)        (int, bitoperator compatible)
	 * 		...
	 * 	]
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @return        void
	 */
	public static function getDataTableMapping() {
		if (!static::$dataTableMapping) {
			static::$dataTableMapping = [
				static::HOST_ID       => ['hostID.tpl'],
				static::CUSTOMER      => ['customer.tpl',     static::FIELD_SEARCHABLE],
				static::HOSTNAME_SORT => ['hostnameSort.tpl', static::FIELD_SEARCHABLE],
				static::HOSTNAME      => ['hostname.tpl'],
				static::HOST_OS       => ['hostOS.tpl',       static::FIELD_SEARCHABLE],
				//static::HOST_SERVICES => ['hostServices.tpl', static::FIELD_SEARCHABLE],
				static::ACTIONS       => ['actions.tpl']
			];
		}

		return static::$dataTableMapping;
	}
}
