<?php

namespace ch\monitoring\view\datatable;

use \ch\monitoring\model;
use \ch\monitoring\controller\NotificationController;

/**
 * View for DataTable for NagiosLog
 *
 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
 * @copyright     Adfinis SyGroup AG 2014
 * @license       LGPLv3
 **/
class NagiosLog extends View  {

	/**
	 * The state field
	 */
	const STATE = 'state';

	/**
	 * The id field
	 */
	const ID = 'id';

	/**
	 * The timestamp field
	 */
	const TIMESTAMP = 'timestamp';

	/**
	 * The stateDescription field
	 */
	const STATE_DESCRIPTION = 'stateDescription';

	/**
	 * The type sort field
	 */
	const TYPE = 'type';

	/**
	 * The output field
	 */
	const OUTPUT = 'output';

	/**
	 * The status field
	 */
	const STATUS = 'status';

	/**
	 * Initialize default template variables
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @return        void
	 */
	public function assignDefaultVariables() {
		parent::assignDefaultVariables();

		$this->assign('user',        model\User::getOrCreateActive());
		$this->assign('statusCodes', NotificationController::getStatusCodes());
	}

	/**
	 * Used to parse this NagiosLog view to string
	 *
	 * You only need to specify the field template, path is automatically prepended
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @param         string $tpl
	 * @return        string
	 */
	public function render($tpl) {
		$tpl = sprintf('maintenance/datatable/notification/%s', $tpl);
		return $this->tpl->fetch($tpl);
	}

	/**
	 * Get the DataTable mapping, if not initialized yet, initialize them
	 *
	 * structure:
	 * 	array [
	 * 		model::FIELD => [ "template.tpl", self::FIELD_FLAGS | ... ],
	 * 		(string)          (string)        (int, bitoperator compatible)
	 * 		...
	 * 	]
	 *
	 * @author        Philipp Schärer <philipp.schaerer@adfinis-sygroup.ch>
	 * @return        void
	 */
	public static function getDataTableMapping() {
		if (!static::$dataTableMapping) {
			static::$dataTableMapping = [
				static::STATE             => ['state.tpl'           , static::FIELD_SEARCHABLE],
				static::ID                => ['id.tpl'              , static::FIELD_SEARCHABLE],
				static::TIMESTAMP         => ['timestamp.tpl'],
				static::STATE_DESCRIPTION => ['stateDescription.tpl', static::FIELD_SEARCHABLE],
				static::TYPE              => ['type.tpl'            , static::FIELD_SEARCHABLE],
				static::OUTPUT            => ['output.tpl'          , static::FIELD_SEARCHABLE],
				static::STATUS            => ['status.tpl'          , static::FIELD_SEARCHABLE],
			];
		}

		return static::$dataTableMapping;
	}
}
