<h2>Alert Templates</h2>

<p>In the current stage of SyMonitoring the same templates can be reused for multiple notification types. It is recommanded to use a descriptive name that no-html mails and html mails can be keep apart.</p>

<p>Only the notification types <b>eMail</b>, <b>SMS</b> and <b>Jabber</b> can have a template!</p>

<h2>The Template Syntax</h2>

<p>The alerting template system uses the same markup language as django (<a target="blank" href="https://docs.djangoproject.com/en/dev/topics/templates/">Django Template</a>). The content can be plain text or html - it won't be validated. The placeholder of the django markup language are written with curly brackets. As example:</p>

<pre class="well">
	{literal}
	{{printsYourVariable}}
	
	{% if 1 < 5 %} {% endif %}
	{/literal}
</pre>

<h2>Formatting Variables</h2>

<p>Variables of the type "String" can be printed directly. The type "Boolean" behaves itself like a number. If you want it to turn into a string ("yes", "no") you need to use an if-clause. The type "Datetime", "Date" and "Time" can be formatted with the methods described on the <a target="blank" href="https://docs.python.org/2/library/datetime.html">datetime documentation</a>. Often you can use the method <b>isoformat(' ')</b></p>

<h2>Available Variables</h2>

<h3>Occurred Alert</h3>
<table class="table">
	<tr>
		<th>Name</th>
		<th>Type</th>
		<th>Description</th>
	</tr>
	<tr>
		<td>logdata.alert.state</td>
		<td>String</td>
		<td>Textual representation of the state of the alert</td>
	</tr>
	<tr>
		<td>logdata.alert.datetimeoccured</td>
		<td>Datetime</td>
		<td>Datetime describing when the alert occurred</td>
	</tr>
	<tr>
		<td>logdata.alert.acknowledgedby.name</td>
		<td>String</td>
		<td>Username of the user who acknowledged the alert</td>
	</tr>
	<tr>
		<td>logdata.alert.acknowledgedby.fullname</td>
		<td>String</td>
		<td>Name of the user who acknowledged the alert</td>
	</tr>
	<tr>
		<td>logdata.alert.comment</td>
		<td>String</td>
		<td>Attached comment</td>
	</tr>
	<tr>
		<td>logdata.alert.output</td>
		<td>String</td>
		<td>The nagios output</td>
	</tr>
</table>

<h3>Host which failed</h3>
<table class="table">
	<tr>
		<th>Name</th>
		<th>Type</th>
		<th>Description</th>
	</tr>
	<tr>
		<td>logdata.host.hostname</td>
		<td>String</td>
		<td>Name of the host that has created the alert</td>
	</tr>
	<tr>
		<td>logdata.host.description</td>
		<td>String</td>
		<td>Description of the host</td>
	</tr>
	<tr>
		<td>logdata.host.customer.name</td>
		<td>String</td>
		<td>Name of the customer which is in charge of this host</td>
	</tr>
	<tr>
		<td>logdata.host.ipv4</td>
		<td>String</td>
		<td>The ipv4 address</td>
	</tr>
	<tr>
		<td>logdata.host.ipv6</td>
		<td>String</td>
		<td>The ipv6 address</td>
	</tr>
	<tr>
		<td>logdata.host.osid.name</td>
		<td>String</td>
		<td>Name of the operating system</td>
	</tr>
	<tr>
		<td>logdata.host.osversionid.name</td>
		<td>String</td>
		<td>Version of the operating system</td>
	</tr>
</table>

<h3>Command which failed</h3>
<table class="table">
	<tr>
		<th>Name</th>
		<th>Type</th>
		<th>Description</th>
	</tr>
	<tr>
		<td>logdata.command.name</td>
		<td>String</td>
		<td>Name of the command</td>
	</tr>
	<tr>
		<td>logdata.command.description</td>
		<td>String</td>
		<td>Description of the command</td>
	</tr>
	<tr>
		<td>logdata.command.commandline</td>
		<td>String</td>
		<td>The nagios command which has been executed</td>
	</tr>
	<tr>
		<td>logdata.command.v6capable</td>
		<td>Boolean</td>
		<td>Indicates if the command shall use IPv6</td>
	</tr>
</table>

<h3>Corresponding timeframe</h3>

<table class="table">
	<tr>
		<th>Name</th>
		<th>Type</th>
		<th>Description</th>
	</tr>
	<tr>
		<td>timeframe.timefrom</td>
		<td>Time</td>
		<td>Starttime of the alert scheduler</td>
	</tr>
	<tr>
		<td>timeframe.timeto</td>
		<td>Time</td>
		<td>Endtime of the alert scheduler</td>
	</tr>
	<tr>
		<td>timeframe.customerid.name</td>
		<td>String</td>
		<td>Name of the corresponding customer</td>
	</tr>
</table>


<h3>Active user</h3>

<table class="table">
	<tr>
		<th>Name</th>
		<th>Type</th>
		<th>Description</th>
	</tr>
	<tr>
		<td>user.name</td>
		<td>String</td>
		<td>The username of the user who receive the message</td>
	</tr>
	<tr>
		<td>user.fullname</td>
		<td>String</td>
		<td>The forename and lastname</td>
	</tr>
	<tr>
		<td>user.customerid.name</td>
		<td>String</td>
		<td>Customer name of the user</td>
	</tr>
</table>

<p>There are even more variables available. But the list of variables is that huge that it cannot be added here.</p>


<h3>Special Variables</h3>

<p>The variables <b>part</b>, <b>syntax</b> and <b>type</b> are set by the daemon.</p>

<p>The first variables can be used to divide the template into multiple parts. The variable <b>part</b> can be one of the following values: <b>subject</b>, <b>html</b> and <b>plain</b>. The variable will be <b>none</b> for all other types then EMail and Jabber!</p>

<p>The variable <b>syntax</b> will be set to <b>true</b> if there was an syntax error in the template.</p>

<p>The variable <b>type</b> can be either "alert" or "infofeed". This helps to clean the output for the infofeed.</p>

<h2>Example</h2>

<pre class="well">
	{literal}
	{% if part == 'subject'  %}
	A new alert has occured
	{% endif %}

	{if part == 'html'}
	&lt;h1&gt;Dear Customer&lt;/h1&gt;
	
	&lt;p&gt;A new alert ({{logdata.alert.state}}) has been created for host
	"{{logdata.host.hostname}}", which {% if logdata.command.v6capable %} uses IPv6
	{% else %} doesn't use IPv6{% endif %}! The failure occurred on {{logdata.alert.
	datetimeoccured}} for the command "{{logdata.command.commandline}}".&lt;/p&gt;
	
	&lt;p&gt;Best Regards, Your SyMonitoring System&lt;/p&gt;
	{% endif %}

	{% if part == 'plain' %}
	Dear Customer
	
	
	A new alert ({{logdata.alert.state}}) has been created for host
	"{{logdata.host.hostname}}", which {% if logdata.command.v6capable %}
	uses IPv6 {% else %} doesn't use IPv6{% endif %}! The failure occurred on
	{{logdata.alert.datetimeoccured}} for the command "{{logdata.command.
	commandline}}".
	
	
	Best Regards, Your SyMonitoring System
	{% endif %}
	{/literal}
</pre>