#!/bin/bash

# Adfinis SyGroup AG, Switzerland
# Version: 0.4

if ! which curl > /dev/null 2>&1
then
  echo "Curl not found using wget"
  curl="wget --no-check-certificate -q -O "
else
  curl="curl -s -k -o "
fi

function debian {
  echo "Running on a debian system"
  os=debian
  apt-get update
  aptcheckinstall curl
  aptcheckinstall wget
  aptcheckinstall nagios-nrpe-server
  aptcheckinstall nagios-plugins
  aptcheckinstall nagios-plugins-basic
  aptcheckinstall nagios-plugins-standard
  aptcheckinstall libnagios-plugin-perl
}

function rhel {
  echo "Running on a RHEL System"
  os=rhel
  majorVersion=$(lsb_release -sr | cut -d '.' -f 1)
  link=''

  yum update

  # Fix for different versions of redhat based distros
  if [ $majorVersion -eq 5 ]
  then
    link='http://mirror.switch.ch/ftp/mirror/epel/5/i386/epel-release-5-4.noarch.rpm'
  elif [ $majorVersion -eq 6 ]
  then
    link='http://mirror.switch.ch/ftp/mirror/epel/6/i386/epel-release-6-8.noarch.rpm'
  elif [ $majorVersion -eq 7 ]
  then
    echo "No stable version of epel for version $majorVersion"
    exit 2
  else
    echo 'Unknown major release'
    exit 2
  fi

  cd /tmp

  if ! rpm -q epel-release > /dev/null 2>&1
  then
    echo 'Installing epel-release'
    rpm -Uvh $link
  fi

  yumckinstall nrpe.x86_64
  yumckinstall nagios-plugins-all.x86_64
  chkconfig nrpe on
  /etc/init.d/nrpe start
}

function ucs {
  echo "Running on a UCS system"
  echo "WARNING! This may lead to problems due to nagios-config."
  while true; do
    read -p "Do you wish to install NRPE nevertheless? " yn
    case $yn in
      [Yy]* ) install_ucs; break;;
      [Nn]* ) echo "Canceling.. please configure manually.."; exit;;
      * ) echo "Please answer yes (y, Y or yes) or no (n, N or no).";;
    esac
  done
}

function install_ucs {
  echo "Installing on UCS"
  tempfile=$(mktemp)
  cat <<AWK_SCRIPT > "$tempfile"
  BEGIN {
      line_1 = 0
      line_2 = 0
      line_3 = 0
  }

  /^# Adfinis SyGroup AG; \\\$DATE; symonitoring; start #/ { line_1 = NR }
  /^include_dir=\/etc\/nagios\/nrpe.d/                     { line_2 = NR }
  /^# Adfinis SyGroup AG; \\\$DATE; symonitoring; end #/   { line_3 = NR }
  /.*/                                                     { print \$0; }

  END {
    if (line_1 == 0 && line_2 == 0 && line_3 == 0) {
          print "# Adfinis SyGroup AG; \$DATE; symonitoring; start #"
          print "include_dir=/etc/nagios/nrpe.d"
          print "# Adfinis SyGroup AG; \$DATE; symonitoring; end #"
          exit 0
      }
      else if (!(line_1 + 1 == line_2 && line_2 +1 == line_3)) {
          exit 1
      }
  }
AWK_SCRIPT

  if awk -f "$tempfile" < "/etc/univention/templates/files/etc/nagios/nrpe.cfg" > /dev/null; then
      cp "/etc/univention/templates/files/etc/nagios/nrpe.cfg" "univention_nrpe.tmp"
      awk -f "$tempfile" < "univention_nrpe.tmp" > "/etc/univention/templates/files/etc/nagios/nrpe.cfg"
      unlink "univention_nrpe.tmp"
      unlink "$tempfile"
  else
      echo "Error! NRPE-configuration partially in '/etc/univention/templates/files/etc/nagios/nrpe.cfg' found, aborting.."
      unlink "$tempfile"
      exit 1
  fi

  current_allowedhosts=`ucr get nagios/client/allowedhosts`
  if [ -z $current_allowedhosts ]; then
    ucr set nagios/client/allowedhosts={$domain}
  else
    if [[ $current_allowedhosts != *"{$domain}"* ]]
    then
      ucr set nagios/client/allowedhosts=$current_allowedhosts,{$domain}
    fi
  fi

  ucr commit
}


function aptcheckinstall {
  echo "Checking for $1"
  if ! dpkg -s $1 > /dev/null 2>&1
  then
    if ! DEBIAN_FRONTEND=noninteractive apt-get -yq install $1 > /dev/null 2>&1
    then
      echo "Installation of $1 failed"
    fi
  fi
}

function yumckinstall {
  echo "Checking for $1"
  if ! rpm -q $1 > /dev/null 2>&1
  then
    if ! yum --enablerepo=epel -y install $1 > /dev/null 2>&1
    then
      echo "Installation of $1 failed"
    fi
  fi
}

echo "Detecting OS..."

if [ -e /usr/sbin/ucr ]
then
    ucs
elif [ -e /etc/debian_version -o -e /usr/bin/apt-get ]
then
  debian
elif [ -e /etc/redhat-release -o -e /usr/bin/yum ]
then
  rhel
fi

echo "Using $curl to download files"

echo -n "Cronjob script URL: "
read scripturl

scriptdir=$(dirname $scripturl)

if ! $curl /usr/local/bin/updateNrpeConfig.sh $scriptdir/updateNrpeConfig.sh
then
  echo 'Unable to download updateNrpeConfig.sh script'
  exit 2
fi

$curl /etc/nagios/nrpeVariables.sh $scriptdir/nrpeVariables.sh
chmod 750 /etc/nagios/nrpeVariables.sh

chmod +x /usr/local/bin/updateNrpeConfig.sh

if [ ! -d /etc/nagios/nrpe.d/ ]
then
  mkdir -p /etc/nagios/nrpe.d/
fi

if [ ! -d /var/log/nagios3/ ]
then
  mkdir /var/log/nagios3/
fi

echo "Writing logrotate config"
cat > /etc/logrotate.d/symonitoring << EOF
/var/log/nagios3/cronjob.log {
	daily
	rotate 7
	compress
	missingok
	notifempty
	create 644 root root
}
/var/log/nagios3/nagios.log {
	daily
	rotate 7
	compress
	missingok
	notifempty
	create 644 root root
}
/var/log/nagios3/send_nsca.log {
	weekly
	rotate 7
	compress
	missingok
	notifempty
	create 644 root root
}
EOF

. /etc/nagios/nrpeVariables.sh

if  [ -d /etc/nagios/nrpe.local.d ]
then
   if [ ! -f /etc/nagios/nrpe.local.d/symonitoring.cfg ]
   then
     touch /etc/nagios/nrpe.local.d/symonitoring.cfg
   fi
   if ! grep -q "include_dir=/etc/nagios/nrpe.d/" /etc/nagios/nrpe.local.d/symonitoring.cfg
   then
      echo "Adding include line to /etc/nagios/nrpe.local.d/symonitoring.cfg"
      echo "include_dir=/etc/nagios/nrpe.d/" >> /etc/nagios/nrpe.local.d/symonitoring.cfg
   fi
else
  if ! grep -q "include_dir=/etc/nagios/nrpe.d/" /etc/nagios/nrpe.cfg
  then
    echo "Adding include line to /etc/nagios/nrpe.cfg"
    echo "include_dir=/etc/nagios/nrpe.d/" >> /etc/nagios/nrpe.cfg
  fi
fi

if [ -d /etc/nagios/nrpe.local.d ]
then
  echo "allowed_hosts=10.2.4.5,95.128.32.188,95.128.32.189,$host" > /etc/nagios/nrpe.local.d/0001allowed_hosts.cfg
else
  echo "allowed_hosts=10.2.4.5,95.128.32.188,95.128.32.189,$host" > /etc/nagios/nrpe.d/0001allowed_hosts.cfg
fi
echo "* * * * * root /usr/local/bin/updateNrpeConfig.sh" > /etc/cron.d/updateNrpeConfig
chmod 644 /etc/cron.d/updateNrpeConfig

sed -ie 's/^curl=.*/curl=\"wget --no-check-certificate -q -O\"/' /usr/local/bin/updateNrpeConfig.sh

if [ -d /etc/nagios/nrpe.local.d -o -f /etc/redhat-release ]
then
  sed -ie 's/^dpkg/#dpkg/' /usr/local/bin/updateNrpeConfig.sh
  sed -ie 's/apt-get/#apt-get/' /usr/local/bin/updateNrpeConfig.sh
fi

if [ -f /etc/redhat-release ]
then
  chkconfig nrpe on
  ln -s /usr/lib64/nagios /usr/lib/nagios
  sed -ie s/\\/usr\\/sbin\\/service.*/\\/sbin\\/service\ nrpe\ restart/ /usr/local/bin/updateNrpeConfig.sh
  /etc/init.d/nrpe start
fi

if [ -f /etc/nagios/nrpe_local.cfg ]
then
  mv /etc/nagios/nrpe_local.cfg /etc/nagios/nrpe_local.cfg.before_nrpe_install
  touch /etc/nagios/nrpe_local.cfg
fi
echo "Running cronjob"

/usr/local/bin/updateNrpeConfig.sh

echo "Success. Host prepared for NRPE."
