"""Test the (PHP) RPC server behaviour when writing exports after a db restart"""


# System imports
try:
    import unittest2 as unittest
except ImportError:  # pragma: no cover
    import unittest

import ConfigParser
import os
from subprocess import call
from syrpc import client

class ExportConfigTest(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(ExportConfigTest, self).__init__(*args, **kwargs)
        config = ConfigParser.ConfigParser()
        filepath = os.path.dirname(__file__)
        config.read('%s%srpc-test.ini'%(filepath, os.sep))
        appname = config.get('RABBITMQ','APP_NAME')
        host = config.get('RABBITMQ', 'HOST')
        pwd = config.get('RABBITMQ', 'PASSWORD')
        user = config.get('RABBITMQ', 'USER')
        num_queues = config.get('RABBITMQ', 'QUEUES')
        settings = {
            'app_name': appname,
            'amq_host': host,
            'amq_password': pwd,
            'amq_user': user,
            'amq_num_queues': int(num_queues),
        }
        self.client = client.Client(settings)

    def test_export_after_dbrestart(self):
        resultcode = self.client.put_request('writeIcingaConfig', None)
        result = self.client.get_result(resultcode, 2)
        self.assertFalse(result['data']['hasInvalidConfiguration'])
        call('sudo /etc/init.d/mysql restart', shell=True)
        resultcode = self.client.put_request('writeIcingaConfig', None)
        result = self.client.get_result(resultcode, 2)
        self.assertFalse(result['data']['hasInvalidConfiguration'])
