# -*- coding: UTF-8 -*-

"""
Login base class

This class provides central methods to login and logout to/from the given
application. This class acts as singleton.
"""

# pylint: disable=bad-whitespace,too-few-public-methods,invalid-name

# System imports
import atexit
from   pyvirtualdisplay               import Display
from   selenium                       import webdriver
from   selenium.webdriver.common.keys import Keys

# Project imports


class LoginBase(object):
    """Base class providing central login/logout methods"""
    instance = None

    def __init__(self, url='https://symonitoring.vm'):
        self.url = url
        self._cookie = None
        self.display = Display(visible=0, size=(1024, 768))
        self.display.start()
        assert self.display.is_alive()
        assert self.display.is_started
        self.driver = webdriver.Firefox()
        self.driver.set_window_size(1024, 786)
        self.driver.get(self.url)
        profile = webdriver.firefox.firefox_profile.FirefoxProfile()
        profile.accept_untrusted_certs = True
        self.driver = webdriver.Firefox(profile)

    @classmethod
    def get_instance(cls, url='https://symonitoring.vm'):
        """Returns an instance of LoginBase"""
        if cls.instance is None:
            cls.instance = cls(url)
        return cls.instance

    def login(self, username='admin', password='vagrant'):
        """Logs in to the set URL using provided credentials"""
        if self._cookie is None:
            elem_user = self.driver.find_element_by_name('username')
            elem_pass = self.driver.find_element_by_name('password')
            elem_user.send_keys(username)
            elem_pass.send_keys(password)
            elem_pass.send_keys(Keys.RETURN)
            self._cookie = self.driver.get_cookies()[0]

    def logout(self):
        """Logs out from the currently set URL"""
        if self._cookie is not None:
            self.driver.delete_all_cookies()
            self._cookie = None
        self.driver.get(self.url)

    @classmethod
    def release(cls):  # pragma: no cover
        """Releases the driver bound to instance"""
        base_instance = cls.get_instance()
        base_instance.driver.quit()
        base_instance.display.stop()

atexit.register(LoginBase.release)
