<?php
// Warning: This file is part of the development vagrant setup, on production
// it is managed by the symonitoring-server ansible playbook.
// For development use the frontend has been configured with rather insecure
// defaults. Please bbe aware of these and do change this file should it have
// been installed on you production.
// Developers, please make sure to add any changes you need to this file in the
// ansible template as well.

/**
 * Specific configuration options for frontend/public area
 *
 * @author      Nicolas Christener <nc@adfinis.ch>
 * @package     org.adfinis.config.templates
 */

/**
 * Static configuration directives
 *
 * for the frontend-code we define some very basic configuration directives as
 * constants for better performance
 */
define('_CONF_DOC_ROOT',                  '/vagrant/frontend');
define('_CONF_TMP',                       '/tmp');

define('_CONF_APP',      _CONF_DOC_ROOT . '/app');
define('_CONF_APP_INC',  _CONF_APP      . '/inc');

define('_CONF_LIB',      _CONF_DOC_ROOT . '/lib');
define('_CONF_FW',       _CONF_LIB .      '/adfinis');
define('_CONF_LIB_FW',   _CONF_FW .       '/inc');
define('_CONF_HTDOCS',   _CONF_DOC_ROOT . '/htdocs');

/**
 * Contains project configuration. Access only via ConfManager, please!
 *
 * @global array $_conf
 */
$_conf = array();

// Environment
$_conf['af']['env'] = 'dev'; // either 'dev', 'beta' or 'stable'

// disable TLS redirect on dev (optional config, do not use on prod unless you
// are sure what you are doing).
$_conf['af']['disableTLSRedirect'] = true;

// project
$_conf['af']['projectName'] = 'symonitoring';

// Additional include paths
$_conf['af']['include']['path'] = array();
$_conf['af']['include']['path'][] = sprintf('%s/vendor/smarty/smarty/libs', _CONF_LIB);
$_conf['af']['include']['path'][] = sprintf('%s/vendor/zendframework/zendframework1/library', _CONF_LIB);
$_conf['af']['include']['path'][] = sprintf('%s/fpdf', _CONF_LIB);
$_conf['af']['include']['path'][] = sprintf('%s/pear/inc', _CONF_LIB);

// Paths to translation files (.mo)
$_conf['af']['translate']['path'] = array();
$_conf['af']['translate']['path'][] = sprintf('%s/locale', _CONF_FW);
$_conf['af']['translate']['path'][] = sprintf('%s/locale', _CONF_APP);

// List of domains (without www) i.e. blubber.com
$_conf['af']['domain']['default']  = 'symonitoring.vm';
$_conf['af']['address']['default'] = '';

// List of URLs (should fit the list of domains)
$_conf['af']['URLNoSSL']['default'] = 'http://symonitoring.vm';
$_conf['af']['URLSSL']['default']   = 'https://symonitoring.vm';

// Domain alias (optional)
$_conf['af']['domain']['alias']   = '';
$_conf['af']['address']['alias']  = '';
$_conf['af']['URLNoSSL']['alias'] = '/cacti';
$_conf['af']['URLSSL']['alias']   = '/cacti';

$_conf['af']['URLSSL']['current']    = 'https://symonitoring.vm';
$_conf['af']['URLNoSSL']['current']  = 'http://symonitoring.vm';
$_conf['af']['URLSSL']['cacti']      = 'https://symonitoring.vm/cacti/';
$_conf['af']['URLSSL']['monitoring'] = 'https://symonitoring.vm/icinga/';
$_conf['af']['URLSSL']['status']     = 'https://symonitoring.vm/cgi-bin/icinga/status.cgi?limit=0&start=1';
// TODO: completely remove PNP from SyMonitoring
$_conf['af']['URLSSL']['pnp4nagios'] = '';
$_conf['af']['URLSSL']['nfsen']      = 'https://symonitoring.vm/nfsen/';
$_conf['af']['URLSSL']['smokeping']  = 'https://symonitoring.vm/cgi-bin/smokeping.cgi?target=Monitoring';
$_conf['af']['URLSSL']['weathermap'] = 'https://symonitoring.vm/weathermap/';

// Server specific settings
$_conf['af']['webserver']['user']    = 'www-data';
$_conf['af']['webserver']['group']   = 'www-data';

// Objects path (Icinga/Nagios object configuration is written there)
$_conf['af']['objectsRoot']['uri']     = '/var/lib/symonitoring/icinga/objects';
$_conf['af']['objectsTempRoot']['uri'] = '/var/lib/symonitoring/icinga/objects-temp';

// Web paths (path after the URL)
$_conf['af']['webRoot']['uri'] = '/var/lib/symonitoring/frontend';

$_conf['af']['webRoot']['pictures'        ]['uri'] = sprintf('%s/pictures',                $_conf['af']['webRoot']['uri']);
$_conf['af']['webRoot']['templatePictures']['uri'] = sprintf('%s/themes/default/pictures', $_conf['af']['webRoot']['uri']);

// Session
$_conf['af']['session']['namespace'] = 'Default'; // Namespace for session


// Error handlers (404 etc, used in oaf\presentation\PageHistory)
$_conf['af']['handler']['404'] = '/handler/404.php'; // path of $_SERVER['SCRIPT_NAME']

// Specify email address to send uncought exceptions
$_conf['af']['handler']['exception']['mailto'] = '';

// Timezone settings
// see php.net/manual/en/timezones.php and timezone_abbreviations_list() for possible values.
$_conf['af']['timezone'] = 'Europe/Zurich'; 

// Main database
$_conf['af']['DB']['default']['PDOType']    = 'Pdo_Mysql';
$_conf['af']['DB']['default']['host']       = 'localhost';
$_conf['af']['DB']['default']['DBName']     = 'symonitoring';
$_conf['af']['DB']['default']['user']       = 'symonitoring';
$_conf['af']['DB']['default']['pass']       = 'vagrant';
$envpw = getenv('MYSQL_PWD');
if($envpw !== false) {
  $_conf['af']['DB']['default']['pass']       = $envpw;
}
$_conf['af']['DB']['default']['charset']    = 'utf8';
$_conf['af']['DB']['default']['autocommit'] = true;
$_conf['af']['DB']['default']['fetchmode']  = PDO::FETCH_ASSOC;

// Cacti database
$_conf['af']['DB']['cacti']['PDOType']    = 'Pdo_Mysql';
$_conf['af']['DB']['cacti']['host']       = 'localhost';
$_conf['af']['DB']['cacti']['DBName']     = 'cacti';
$_conf['af']['DB']['cacti']['user']       = 'cacti';
$_conf['af']['DB']['cacti']['pass']       = 'vagrant';
$_conf['af']['DB']['cacti']['charset']    = 'utf8';
$_conf['af']['DB']['cacti']['autocommit'] = true;
$_conf['af']['DB']['cacti']['fetchmode']  = PDO::FETCH_ASSOC;

// Icinga ido database
$_conf['af']['DB']['icingaIdo']['PDOType']    = 'Pdo_Mysql';
$_conf['af']['DB']['icingaIdo']['host']       = 'localhost';
$_conf['af']['DB']['icingaIdo']['DBName']     = 'icinga';
$_conf['af']['DB']['icingaIdo']['user']       = 'icinga-idoutils';
$_conf['af']['DB']['icingaIdo']['pass']       = 'vagrant';
$_conf['af']['DB']['icingaIdo']['charset']    = 'utf8';
$_conf['af']['DB']['icingaIdo']['autocommit'] = true;
$_conf['af']['DB']['icingaIdo']['fetchmode']  = PDO::FETCH_ASSOC;

// Icinga web database
$_conf['af']['DB']['icingaWeb']['PDOType']    = 'Pdo_Mysql';
$_conf['af']['DB']['icingaWeb']['host']       = 'localhost';
$_conf['af']['DB']['icingaWeb']['DBName']     = 'icingaweb2';
$_conf['af']['DB']['icingaWeb']['user']       = 'icingaweb2';
$_conf['af']['DB']['icingaWeb']['pass']       = 'vagrant';
$_conf['af']['DB']['icingaWeb']['charset']    = 'utf8';
$_conf['af']['DB']['icingaWeb']['autocommit'] = true;
$_conf['af']['DB']['icingaWeb']['fetchmode']  = PDO::FETCH_ASSOC;

// Icinga web configuration
$_conf['af']['icingaWeb']['authSource']       = 'openldap-ldap1';
$_conf['af']['icingaWeb']['algorithm']        = 'sha256';
$_conf['af']['icingaWeb']['priviledgedGroup'] = 'appkit_admin';
$_conf['af']['icingaWeb']['restrictedGroup']  = 'appkit_user';

// Icinga global config
$_conf['af']['icinga']['config']['writeTimeout'] = '420';

// Ldap settings
$_conf['af']['ldap']['default']['server']   = 'ldap://127.0.0.1';
$_conf['af']['ldap']['default']['baseDN']   = 'dc=symon,dc=vm';
$_conf['af']['ldap']['default']['userDN']   = array('ou=users');
$_conf['af']['ldap']['default']['groupDN']  = array('ou=groups');
$_conf['af']['ldap']['default']['accessDN'] = '';
$_conf['af']['ldap']['default']['password'] = 'vagrant';
$_conf['af']['ldap']['default']['authMethod'] = 'all';
$_conf['af']['ldap']['default']['authGroup']  = '';

// Authentication settings
$_conf['af']['auth']['ldap']  = 'yes';
$_conf['af']['auth']['local'] = 'yes';

// Monitoring commands and paths
$_conf['af']['monitoring']['binary']     = '/usr/sbin/icinga';
$_conf['af']['monitoring']['config']     = '/etc/icinga/icinga.cfg';
$_conf['af']['monitoring']['tempConfig'] = '/etc/icinga/icinga-tmp.cfg';
$_conf['af']['monitoring']['start']      = '/etc/init.d/icinga start';
$_conf['af']['monitoring']['stop']       = '/etc/init.d/icinga stop';
$_conf['af']['monitoring']['status']     = '/etc/init.d/icinga status';
$_conf['af']['monitoring']['reload']     = '/etc/init.d/icinga reload';
$_conf['af']['monitoring']['cmd']        = '/var/lib/symonitoring/icinga/icinga.cmd';

// Font directory for captcha
$_conf['af']['captcha']['fonts']['path'] = sprintf('%s/data/fonts', _CONF_FW);

// Temporary pictures (CAPTCHA etc)
$_conf['af']['picturesTmp']['path'] = sprintf('%s/htdocs/pictures/tmp', _CONF_DOC_ROOT);
$_conf['af']['picturesTmp']['uri']  = sprintf('%s/pictures/tmp', $_conf['af']['webRoot']['uri']);

// Used languages
$_conf['af']['language']['default']['languageID'] = 1;

// Smarty Templates
$_conf['af']['smarty']['templates']['path'] = array(
	sprintf('%s/templates', _CONF_APP),
	sprintf('%s/framework/templates', _CONF_LIB),
);
$_conf['af']['smarty']['compiled']['path'] = sprintf('%s/templatesCompiled', _CONF_TMP);
$_conf['af']['smarty']['cached'  ]['path'] = sprintf('%s/templatesCache', _CONF_TMP);

// SMTP
$_conf['af']['SMTP']['default']['hostname'] = 'localhost';

// Mail
$_conf['af']['mail']['fromSystem']['fromMail'] = 'symonitoring@adfinis-sygroup.ch';
$_conf['af']['mail']['fromSystem']['fromName'] = 'SyMonitoring';
$_conf['af']['mail']['fromSystem']['fromMaintenanceMail'] = 'maintenance@adfinis-sygroup.ch';
$_conf['af']['mail']['fromSystem']['fromMaintenanceName'] = 'SyMonitoring Maintenance';

// DebugHelper mail receivers.
$_conf['af']['mail']['debug']['receivers']['deniss'] = array(
	'firstName' => 'Denis',
	'lastName'  => 'Simonet',
	'address'   => 'denis.simonet@adfinis-sygroup.ch'
);

// PNP4Nagios configuration
// TODO: completely remove PNP from SyMonitoring
$_conf['sm']['pnp4nagios']['user'] = '';
$_conf['sm']['pnp4nagios']['pass'] = '';

// Config for command path
$_conf['sm']['command']['path']['fs']  = sprintf('%s/commandfiles', _CONF_HTDOCS);
$_conf['sm']['command']['path']['uri'] = sprintf('%s/commandfiles', $_conf['af']['URLSSL']['default']);

// Config for SyRPC
$_conf['sm']['RPC']['encoding']           = 'utf-8';
$_conf['sm']['RPC']['wqAppName']          = 'symonitoring_write_queue';
$_conf['sm']['RPC']['lcAppName']          = 'symonitoring_logic';
$_conf['sm']['RPC']['wqQueues']           = '16';
$_conf['sm']['RPC']['lcQueues']           = '32';
$_conf['sm']['RPC']['amq']['virtualhost'] = '/';
$_conf['sm']['RPC']['amq']['host']        = 'localhost';
$_conf['sm']['RPC']['amq']['user']        = 'symonitoring';
$_conf['sm']['RPC']['amq']['password']    = 'vagrant';

$_conf['sm']['RPC']['timeout']            = '10';
$_conf['sm']['RPC']['icinga_timeout']     = '60';

// Logging
$_conf['sm']['logging']['level'] = 7;
