<?php

use ch\monitoring\controller\PageNotFoundController;
use ch\monitoring\controller\ForbiddenController;
use org\adfinis\framework\lang\Language;
use org\adfinis\framework\request;
use org\adfinis\framework\controller\Dispatcher;
use org\adfinis\framework\exceptions;

/**
 * The central entry point. Loads the correct controller.
 *
 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
 */

// TODO Load from user profile, 'auto' if none found
$locale = new Zend_Locale('de_CH');
Zend_Registry::set('Zend_Locale', $locale);
Language::init('de_CH');

$dispatcher = new Dispatcher();
$dispatcher->setMapping(array(
	'#page=account(&|$)#'                        => 'ch\monitoring\controller\AccountController',
	'#page=setting(&|$)#'                        => 'ch\monitoring\controller\SettingController',
	'#page=alerttemplate(&|$)#'                  => 'ch\monitoring\controller\AlertTemplateController',

	'#page=applications(&|$)#'                   => 'ch\monitoring\controller\BREApplicationController',
	'#page=hosts(&|$)#'                          => 'ch\monitoring\controller\HostController',
	'#page=hostGroups(&|$)#'                     => 'ch\monitoring\controller\HostGroupController',
	'#page=hostTypes(&|$)#'                      => 'ch\monitoring\controller\HostTypeController',
	'#page=hostOS(&|$)#'                         => 'ch\monitoring\controller\HostOSController',
	'#page=hostsHierarchy(&|$)#'                 => 'ch\monitoring\controller\HostHierarchyController',
	'#page=hostsExport(&|$)#'                    => 'ch\monitoring\controller\HostExportController',
	'#page=architectures(&|$)#'                  => 'ch\monitoring\controller\ArchitectureController',
	'#page=services(&|$)#'                       => 'ch\monitoring\controller\ServiceController',
	'#page=infofeeds(&|$)#'                      => 'ch\monitoring\controller\InfofeedController',
	'#page=groups(&|$)#'                         => 'ch\monitoring\controller\ServiceGroupController',
	'#page=commands(&|$)#'                       => 'ch\monitoring\controller\CommandController',
	'#page=customers(&|$)#'                      => 'ch\monitoring\controller\CustomerController',
	'#page=slas(&|$)#'                           => 'ch\monitoring\controller\SlaController',
	'#page=users(&|$)#'                          => 'ch\monitoring\controller\UserController',
	'#page=roles(&|$)#'                          => 'ch\monitoring\controller\RoleController',
	'#page=alerts[^&]*(&|$)#'                    => 'ch\monitoring\controller\AlertController',
	'#page=notifications(&|$)#'                  => 'ch\monitoring\controller\NotificationController',
	'#page=userlog(&|$)#'                        => 'ch\monitoring\controller\UserlogController',
	'#page=calendar(&|$)#'                       => 'ch\monitoring\controller\CalendarController',
	'#page=maintenanceOverview(&|$)#'            => 'ch\monitoring\controller\MaintenanceController',
	'#page=maintenanceProcess(&|$)#'             => 'ch\monitoring\controller\MaintenanceController',
	'#page=maintenanceHistory(&|$)#'             => 'ch\monitoring\controller\MaintenanceController',
	'#page=maintenanceHosts(&|$)#'               => 'ch\monitoring\controller\MaintenanceHostController',
	'#page=maintenanceChecklists(&|$)#'          => 'ch\monitoring\controller\MaintenanceChecklistController',
	'#page=downtimes(&|$)#'                      => 'ch\monitoring\controller\DowntimeController',
	'#page=downtimesAPI(&|$)#'                   => 'ch\monitoring\controller\DowntimeAPIController',
	'#page=(monitoring|monitoringCommand)(&|$)#' => 'ch\monitoring\controller\MonitoringController',
	'#page=export(&|$)#'                         => 'ch\monitoring\controller\ExportController',
	'#page=home(&|$)#'                           => 'ch\monitoring\controller\HomeController',
	'#page=login(&|$)#'                          => 'ch\monitoring\controller\LoginController',
	'#page=logout(&|$)#'                         => 'ch\monitoring\controller\LogoutController',
	'#page=graph(&|$)#'                          => 'ch\monitoring\controller\GraphController',
	'#page=reports(&|$)#'                        => 'ch\monitoring\controller\ReportController',
	'#page=pnp4nagios(&|$)#'                     => 'ch\monitoring\controller\PNP4NagiosController',
	'#page=maintenanceGroups(&|$)#'              => 'ch\monitoring\controller\MaintenanceGroupController',
	'#page=auditLog(&|$)#'                       => 'ch\monitoring\controller\AuditLogController',
	'#page=import(&|$)#'                         => 'ch\monitoring\controller\ImportController',
	'#page=[^&]*#'                               => 'ch\monitoring\controller\PageNotFoundController',
	'#.*#'                                       => 'ch\monitoring\controller\LoginController'
));

try {
	$request = request\ForgivingRequest::fromCurrentGPC();
	$controller = $dispatcher->getController($request);
}
catch(exceptions\NotFoundException $e) {
	$controller = new PageNotFoundController($request, array());
}
catch(\Exception $e) {
	die(sprintf("FATAL ERROR: %s", $e->getMessage()));
}

try {
	$controller->handle();
}
catch (exceptions\ForbiddenException $e) {
	$controller = new ForbiddenController($request, array());
	$controller->handle();
}
