define([
  'jquery',
  'jquery-jgrowl',
  'bootstrap',
  '/js/app/event/initializeElements.js',
  '/js/app/callbackregistry.js',
  'domReady!'
], function($, jgrowl, bootstrap, initializeElements, callbackRegistry) {

'use strict'

function handleErrors(e, errors, preservePrevious) {
  var errorContainer
    , errorBody
    , errorList
    , modalBody

  // Remove error container if it exists (new error messages override old ones)
  if (!preservePrevious) {
    clearErrors()
  }

  if (!$('#error-container').length || !preservePrevious) {
    errorContainer = $('<div>', {
      id: 'error-container'
    , class: 'alert alert-danger break-word'
    })
    $('<strong>', { 'id': 'error-header', 'text': 'An error occured' }).appendTo(errorContainer)
  }
  else {
    errorContainer = $('#error-container')
    $('#error-header').html('Multiple errors have occured')
  }
  errorBody = $('<div>', { id: 'error-body' }).appendTo(errorContainer)
  errorList = $('<ul>').appendTo(errorBody)

  if (errors.error && errors.error.errorMessages.length) {
    errors.error.errorMessages.forEach(function(msg) {
      msg.split('\n').forEach(function(msgItem) {
        errorList.append($('<li>').html(msgItem))
      })
    })
  }
  else {
    errorList.append($('<li>').html('An unknown error occured, please check the application log file(s)!'))
  }

  modalBody = $('.modal-body')
  if (modalBody.length && modalBody.is(':visible') && $('.modal').hasClass('in')) {
    modalBody.prepend(errorContainer)
    $('.modal').scrollTop(0)
  }
  else if (!$('#box_template').length) {
    $('#wide-content').prepend(errorContainer)
    $('html, body').scrollTop(0)
  }
  else {
    $('#box_template').prepend(errorContainer)
    $('html, body').scrollTop(0)
  }
}

function clearErrors() {
  var errorContainer = $('#error-container')
  if (errorContainer.length) {
    errorContainer.remove()
  }
}

function handleNotices(e, notices, preservePrevious) {
  var noticeContainer
    , noticeBody
    , noticeList

  if (!preservePrevious) {
    clearNotices()
  }

  if (!$('#error-container').length || !preservePrevious) {
    noticeContainer = $('<div>', {
      id: 'notice-container'
    , class: 'alert alert-info break-word'
    })
    $('<strong>', { 'id': 'notice-header', 'text': 'Notice' }).appendTo(noticeContainer)
  }
  else {
    noticeContainer = $('#notice-container')
    $('#notice-header').html('Multiple errors have occured')
  }
  noticeBody = $('<div>', { id: 'notice-body' }).appendTo(noticeContainer)
  noticeList = $('<ul>').appendTo(noticeBody)

  notices.notify.notifyMessages.forEach(function(msg) {
    msg.split('\n').forEach(function(msgItem) {
      noticeList.append($('<li>').html(msgItem))
    })
  })

  var modalBody = $('.modal-body')
  if (notices.notify.notifyMessages.length && modalBody.length && modalBody.is(':visible')) {
    modalBody.prepend(noticeContainer)
    $('.modal').scrollTop(0)
  }
  else if (!$('#box_template').length) {
    $('#wide-content').prepend(noticeContainer)
    $('html, body').scrollTop(0)
  }
  else {
    $('#box_template').prepend(noticeContainer)
    $('html, body').scrollTop(0)
  }
}

function clearNotices() {
  var noticeContainer = $('#notice-container')
  if (noticeContainer.length) {
    noticeContainer.remove()
  }
}

function displayGrowl(growl, target) {
  if (growl) {
    $(target || '#mainMessage').jGrowl(growl)
  }
}

function hideGrowl() {
  /*jshint validthis:true */

  $(this).parent().parent().trigger('jGrowl.close');
}

function serializeObject(data, object) {
  var $elements = $(object)

  if ($elements.length == 1 && $elements.is('form')) {
    var form = new FormData($elements[0])

    $.each(data, function(key, value) {
      form.append(key, value)
    })

    return form
  }

  // Handle non-standard forms with several sources of data
  $elements.each(function(i, el) {
    var a = $(el).serializeArray();

    $.each(a, function() {
      if (data[this.name]) {
        if (!data[this.name].push) {
          data[this.name] = [ data[this.name] ];
        }

        data[this.name].push(this.value || '')
      }
      else {
        data[this.name] = this.value || ''
      }
    })
  })

  return data
}

/**
 * jQuery.fn.DataTable() throws TypeError if the table
 * is not a datatable...
 */
function getDatatableAPI($el) {
  try {
    return $el.DataTable()
  }
  catch (e) {
    return false
  }
}

function handleRequestResult(e, res, callback, target, settings) {
  /*jshint validthis:true */

  var hide        = this.dataset.syHide
  var growl       = this.dataset.syGrowl
  var growlTarget = this.dataset.syGrowlTarget
  var action      = this.dataset.syAction || 'html'
  var $target     = $(target.map(function(t) { return $(t)[0] }))
  $target = $target.filter(function() {
    if (typeof this !== 'undefined') return this
  })

  if (res.notify && res.notify.hasNotifyMessages) {
    $target.unmask()
    handleNotices(e, res, settings.preserveNotices)
  }

  if (res.error.hasErrorMessages) {
    $target.unmask()
    return handleErrors(e, res, settings.preserveErrors)
  }

  displayGrowl(growl, growlTarget)

  if (hide) {
    hide.split(',').forEach(function(val, i) {
      var $el = $(val).hide()

      // Datatable rows will be removed instead of hidden
      // this will cause a redraw of the datatable for each
      // removed row. Be careful! :)
      if ($el.is('tr')) {
        var $table = $el.closest('table')

        if ($table.is('.dataTable, #list, .ajaxList')) {
          var datatable = getDatatableAPI($el.closest('table'))

          if (datatable) datatable.row(val).remove().draw()
        }
      }
    }, this)
  }

  // TODO: The #list thingy should probably have a dataTable class
  if ($target.is('.dataTable tbody, #list tbody, .ajaxList tbody, .ajaxList tbody tr')) {
    updateDatatable($target, res.html)
  }
  else {
    // I'm not sure why, but the jQuery#each() method seems broken, as
    // the index callback parameter is an element too?!
    $target.toArray().forEach(function(el, i) {
      var $target = $(el)
      // We call initializeElements on the response elements, in case we
      // use replaceWith
      var $response

      if (Array.isArray(res.html)) {
        $response = $(res.html[i].html)

        // Populate target with result
        $target[action]($response).unmask()
      }
      else {
        if (i === 0) {
          $response = $(res.html)
          // Populate target with result
          $target[action]($response).unmask()
        }
        else {
          // For some reason, we set an element value instead of actual
          // DOM manipulation, initializeElements.process has to be called on elements
          // so we use the $target here...
          $response = $target
          $target.val(res.parameters[$target.attr('name')] || '').unmask()
        }
      }

      if (action === 'replaceWith') {
        $response.each(initializeElements.process)
      }
      else {
        $target.each(initializeElements.process)
      }

      if ($target.is('.ui-sortable')) {
        $target.trigger('sortupdate')
      }
    })
  }

  if (this.dataset.syGrowlHide) {
    hideGrowl.call(this)
  }

  if (callback) {
    return callback(e, res)
  }

  return res
}

function makeRequest(e, url, callback, target, settings, resCallback) {
  /*jshint validthis:true */

  var data   = this.dataset.syData ? $.parseJSON(this.dataset.syData) : {}
  var source = this.dataset.syFrom
  var method = this.method || this.dataset.syMethod
  var handlers = settings.handlers

  if (!settings.preserveNotices) {
    clearNotices()
  }
  if (!settings.preserveErrors) {
    clearErrors()
  }

  if (source) {
    data = serializeObject(data, source)
  }

  var options = { 'type':     method
                , 'url':      url
                , 'dataType': 'json'
                , 'context':  this
                , 'data':     data
                }

  options.success = function success(res) {
    // Only call the ajax success handlers if the result has no error Messages
    if (handlers && handlers.success && !res.error.hasErrorMessages) {
      handlers.success.call(this, e)
    }
    return handleRequestResult.call(this, e, res, callback, target, settings)
  }

  options.error = function error(res) {
    if (handlers && handlers.failure) handlers.failure.call(this, e)
    var errors = {}

    if (res.status == 200 && !res.responseText) {
      handleRequestResult.call(this, e, res, callback, target, settings)
    }
    else if (res.responseText == 'error') {
      return
    }
    else {
      if (target) {
        target.forEach(function(val, i) {
          $(val).unmask()
        }, this)
      }

      if (window.isUnloading) {
        return
      }

      if (res.responseText) {
        errors = {
          'error': {
            'hasErrorMessages': true
          , 'errorMessages': [
              res.responseText
            ]
          }
        }
      }

      return handleErrors(e, errors, settings.preserveErrors)
    }
  }

  options.complete = function complete(res) {
    if (resCallback !== null) {
      try {
        // TODO:
        // change this to something cleaner with out catching exceptions?
        callbackRegistry.getCallback(resCallback)(res.responseJSON)
      } catch (e) {
        /* handle error */
        // TODO:
        // resCallback could not be registered, deal with the error
      }
    }
  }

  if (data instanceof FormData) {
    options.processData = false
    options.contentType = false
  }

  $.ajax(options)
}

function process(e, callback, settings) {
  /*jshint validthis:true */
  var target
    , resCallback
    , hide
    , targets
    , urls

  if (e.preventDefault) e.preventDefault()

  target  = this.dataset.syFor
  resCallback = this.dataset.syCallback || null

  hide        = this.dataset.syHide || ''
  targets     = target ? target.split(',') : []
  urls        = this.dataset.syUrl && this.dataset.syUrl.split(',')
  settings    = settings || {}

  if (this.dataset.syPreserveNotices) {
    settings.preserveNotices = true
  }

  if (this.dataset.syPreserveErrors) {
    settings.preserveErrors = true
  }

  targets.forEach(function(val) {
    var elem = $(val)
    if (elem.is(':hidden')) {
      elem.show()
    }
    elem.mask(this.dataset.syMask)
  }, this)

  hide.split(',').forEach(function(val) {
    $(val).mask(this.dataset.syMask)
  }, this)

  if (urls.length > 1) {
    urls.forEach(function(url, i) {
      var tars = targets[i] ? [ targets[i] ] : []
      makeRequest.call(this, e, url, callback, tars, settings, resCallback)
    }, this)
  }
  else {
    makeRequest.call(this, e, urls[0], callback, targets, settings, resCallback)
  }
}

function updateDatatable($table, html) {
  var $datatable = $table.closest('table')
    , dataTable  = $datatable.dataTable()
      // Append to table, raw data might end up in creating textnodes
      // which would fail in dataTable.fnAddTr()
    , $dummy     = $('<table>').append(html)

  $dummy.find('tr').each(function(i, el) {
    if (!$(el).find('th').length) {
      dataTable.fnAddTr(el)
    }
  })
}

return {
  process:         process
, handleErrors:    handleErrors
, clearErrors:     clearErrors
, handleNotices:   handleNotices
, clearNotices:    clearNotices
, serializeObject: serializeObject
}

})
