/* globals Application define */

define([
  'jquery',
  '/js/app/event/initializeElements.js',
  '/js/app/dialog/confirm.js',
  '/js/app/event/reloadPage.js',
  'domReady!'
], function($, initElements, confirmDialog, reloadPageEvent) {
  'use strict'

  function handleNotifications(e) {
    /*jshint validthis:true */

    // Handle notifications
    if (this && this.dataset.syNotify) {
      this.dataset.syNotify.split(',').forEach(function(el) {
        Application.loadModule(el, function(module) {
          if ($.isFunction(module)) {
            module.call(this, e)
          }
          else {
            module.process.call(this, e)
          }
        }, this)
      }, this)
    }
  }

  function requireModule(e, callback) {
    /*jshint validthis:true */
    var settings = { 'handlers': { 'success': handleNotifications } }

    if (this.dataset.syPreserveNotices) {
      settings.preserveNotices = true
    }

    if (this.dataset.syPreserveErrors) {
      settings.preserveErrors = true
    }

    if (!this.dataset.syRequire) {
      Application.loadModule('ajax', function(module) {
        module.process.call(this, e, callback, settings)
      }, this)
      return
    }

    Application.loadModule(this.dataset.syRequire, function(module) {
      if ($.isFunction(module)) {
        module.call(this, e, callback, settings)
      }
      else {
        module.process.call(this, e, callback, settings)
      }
    }, this)

    return this
  }

  function process(e, callback, disableElement) {
    /*jshint validthis:true */

    // Disable the element, the actions coming from
    if (disableElement) {
      $(this).prop('disabled', true)
    }

    if (e !== undefined) {
      e.preventDefault()
    }

    if (this.dataset.syConfirm) {
      return confirmDialog.call(this, e, requireModule.bind(this, e, callback))
    }

    return requireModule.call(this, e, callback)
  }

  function postProcess(e, callback) {
    /*jshint validthis:true */

    // Re-enable the clicked element
    $(this).prop('disabled', false)
  }

  // Initialize elements if needed
  $('.ajax-init').each(function(i, el) {
    initElements.process.call(el)
  })

  $('.ajax-require').each(function(i, el) {
    this.dataset.syRequire.split(',').forEach(function(requirement) {
      Application.loadModule(requirement)
    })
  })

  // Event callbacks
  $(document)
    .on('click',  '[data-sy-event-click]',  function(e, callback) {
      process.call(this, e, postProcess.bind(this))
    })
    .on('change', '[data-sy-change]',       function(e, callback) {
      process.call(this, e) // TODO: Why is the callback ommited here?
    })
    .on('change', '[data-sy-event-change]', function(e, callback) {
      process.call(this, e) // TODO: Why is the callback ommited here?
    })

  return { process: process, postProcess: postProcess }
})
