define([
  'jquery',
  'moment',
  'jquery-bsmselect',
  'jquery-bsmselect-sortable',
  'jquery-loadmask',
  'jquery-validate',
  'jquery-cookie',
  'jquery-treeview',
  'datatables',
  'datatables/plugins/fnAddTr',
  'datatables/plugins/date-ch',
  'datatables/plugins/date-de',
  'jquery-ui',
  'chosen',
  'fuelux-wizard',
  'fuelux-scheduler',
  'bootstrap-daterangepicker',
  'bootstrap-timepicker',
  'domReady!'
], function ($, moment) { 'use strict';
  function process(e, callback) {
    /*jshint validthis:true */

    var context
    var target = this.dataset ? this.dataset.syTarget : undefined
    var dataTableSettings = {
      'order'       : [[ document.sort_column, document.sort_by ]],
      'orderClasses': false,
      'paging'      : true,
      'columns'     : document.aoColumns,
      'columnDefs'  : document.columnDefs
    }
    var ajaxDataTableSettings = {
      'serverSide': true,
      'paging'    : true,
      'processing': true,
    }
    $.extend(dataTableSettings, document.datatableSettings)

    $.fn.dataTableExt.sErrMode = 'throw'

    if (target) {
      context = $(this.dataset.syTarget)[0]
    }
    else {
      context = this.jquery ? this[0] : this
    }

    var plugins = function(){
      // Treeview>
      $('.hierarchy', context).treeview({
        collapsed: true
      })

      // Bootstrap popover
      $('.add-popover', context).popover({
          container: 'body',
          placement: 'right',
          trigger  : 'hover',
          html     : true
      })

      $('.hover-popover', context).popover({
        container: 'body',
        html     : true,
        animation: true,
        placement: 'bottom',
        trigger  : 'click'
      })
    }

    // jQuery datatable
    try {
      $('.dataTable.list', context).DataTable(
        dataTableSettings
      )

      $('.dataTable.ajaxList', context).each(function () {
        ajaxDataTableSettings.ajax = {
          'url' : '?' + $.param({
              'action': 'dataTable',
              'page'  : document.target_page,
            }),
          'data': function(data) {
            $('form.dataTableFilter').serializeArray().reduce(function(result, object) {
              result[object.name] = object.value

              return result
            }, data)
          }
        }

        $(this).on('xhr.dt', function ( e, settings, json ) {
          if (json.error || json.notify) {
            window.Application.loadModule('ajax', function(ajax) {
              if (json.error.hasErrorMessages) {
                ajax.handleErrors(null, json)
              }
              if (json.notify.hasNotifyMessages) {
                ajax.handleNotices(null, json)
              }
            });
          }
        }).on('draw.dt', plugins)
        .DataTable($.extend({}, dataTableSettings, ajaxDataTableSettings))
      })

      $('.dataTableNoSort', context).DataTable({
        'ordering' : false,
        'paging'   : false,
        'searching': true
      })
    }
    catch (e) {
      console.error('An error occured while initializing Datatable', e)
    }

    $('.dataTableFilter').on('click', '.reload', function() {
      $('.dataTable.ajaxList').DataTable().draw()
    })

    $('.sydatatable', context).each(function() {
      var $this = $(this)
      if($this.data('datatable-initialized')) {
        return;
      }

      var opts = {
        'bPaginate'   : false,
        'bSortClasses': false,
      }

      var mapping = {
        'sySorting'   : 'aaSorting',
        'syColumns'   : 'aoColumns',
        'syColumnDefs': 'columnDefs',
      };

      for(var key in mapping) {
        opts[mapping[key]] = $this.data(key)
      }

      $this.data('datatable-initialized', true)
      try {
        $this.dataTable(opts)
      }
      catch (e) {
        console.error('An error occured while initializing Datatable', e)
      }
    })

    plugins();

    var datePickerOptions = {
      showWeekNumbers: true,
      locale: { firstDay: 1 },
      showDropdowns   : true,
      timePicker12Hour: false,
      startDate       : moment(),
      endDate         : moment(),
    }

    // Bootstrap date time picker
    $('.datePicker', context).daterangepicker($.extend({}, datePickerOptions, {
      singleDatePicker: true,
      timePicker      : false,
      format          : 'YYYY-MM-DD',
    }))

    $('.daterangePicker', context).daterangepicker($.extend({}, datePickerOptions, {
      timePicker      : false,
      format          : 'YYYY-MM-DD',
      opens           : 'left',
      ranges          : {
        'Last 30 days': [moment().subtract(29, 'days'), moment()],
        'This Month'  : [moment().startOf('month'),     moment().endOf('month')],
        'Last Month'  : [
          moment().subtract(1, 'month').startOf('month'),
          moment().subtract(1, 'month').endOf('month'),
        ],
        'Last 3 Months': [
          moment().subtract(3, 'month').startOf('month'),
          moment().subtract(1, 'month').endOf('month'),
        ],
        'Last 6 Months': [
          moment().subtract(6, 'month').startOf('month'),
          moment().subtract(1, 'month').endOf('month'),
        ],
        'Last Year': [
          moment().subtract(12, 'month').startOf('month'),
          moment().subtract(1,  'month').endOf('month'),
        ]

      },
      startDate       : moment().subtract(1, 'month'),
      endDate         : moment(),
    }))

    $('.dateTimePicker', context).daterangepicker($.extend({}, datePickerOptions, {
      singleDatePicker   : true,
      timePicker         : true,
      timePickerIncrement: 5,
      format             : 'YYYY-MM-DD HH:mm:ss',
    }))

    // Bootstrap timepicker
    $('.timePicker', context).timepicker({
      showMeridian: false, // Enables 24h format
      minuteStep  : 1,
      defaultTime : false,
    })

    $('.dateTimePicker', context).each(function() {
      $(this).on('hide.daterangepicker', function (e, picker) {
        picker.updateInputText()
      })
    })

    tabRedraw.call(context)

    // BSM Select
    $('.multi', context).bsmSelect()

    $('.multiSort', context).bsmSelect({
      removeLabel: 'X',
      plugins: [
        $.bsmSelect.plugins.sortable(
          {
            axis   : 'y',
            opacity: 0.5
          },
          {
            listSortableClass: 'bsmListSortableCustom'
          }
        )
      ]
    })

    // Form validation
    $('.validateForm', context).each(function(){
      $(this).validate({
        errorElement: 'em',
        highlight: function(element, errorClass) {
          $(element).parent().addClass('bg-danger text-danger')
        },
        unhighlight: function(element, errorClass) {
          $(element).parent().removeClass('bg-danger text-danger')
        }
      })
    })

    // Sortable elements
    $('.sortable', context).sortable()

    // FuelUX wizard
    $('.wizard'   , context).wizard()
    $('.scheduler', context).scheduler()
    $('.radio'    , context).radio()

    // Now initialize remaining registered actions
    if (Array.isArray(document.initialize)) {
      var init = document.initialize
      init     = init.filter(function(n){ return n != undefined });

      $.each(init, function() { this(context) });
    }
  }

  function tabRedraw() {
    /*jshint validthis:true */

    $(this).find('select.combobox, select.comboboxMulti').each(function(){
      var $this = $(this)
      $this.show()
      if($this.data('chosen')) {
        $this.data('chosen').destroy()
      }
      $this.chosen({
        'search_contains': true,
        'enable_split_word_search': false,
        'include_group_label_in_selected': true,
      })
    })
  }

  $(document)
    .on('shown.bs.tab',       tabRedraw)
    .on('shown.bs.collapse',  tabRedraw)
    .on('changed', '.wizard', tabRedraw)

  return { process: process }
})
