/* globals define document */

define([
  'jquery',
  '/js/app/ajax.js',
  'domReady!'
], function($, ajax) {
  'use strict'

  var settings = Object.freeze({
    'preserveNotices': true,
    'preserveErrors': true
  })
  var wasExportNotificationDisplayed              = false
  var wasExportAllSatellitesNotificationDisplayed = false
  var displayedExportNotificationForSatellites    = []

  initialize()

  function initialize() {
    var e = {}

    // TODO: Why are we pretending that `e` is a DOM element?
    e.dataset = {}

    e.dataset.syUrl = 'index.php?page=setting&action=getNotificationStates'
    e.dataset.dontClearMessages = true

    // TODO: Why is almost every exported module function called process?
    //       And why do we have to call them by Function#call()?
    ajax.process.call(e, e, function(e, res) {
      var hostChanged          = res.parameters.hostChanged
      var satelliteChanged     = res.parameters.satelliteChanged
      var allSatellitesChanged = res.parameters.allSatellitesChanged

      if (hostChanged) {
        nagiosExportNotification()
      }

      if (satelliteChanged) {
        Object.keys(satelliteChanged).forEach(function(key) {
          nagiosSatelliteNotification(key, satelliteChanged[key])
        })
      }

      if (allSatellitesChanged) {
        nagiosAllSatellitesNotification()
      }
    }, settings)
  }

  function nagiosExportNotification() {
    /*jshint multistr:true */

    if (!wasExportNotificationDisplayed) {
      // TODO: Try to avoid multiline strings
      var link = '<a \
                   href="#" \
                   data-sy-event-click="require" \
                   data-sy-url="index.php?page=export&action=hideMessage,index.php?page=export&action=build" \
                   data-sy-growl-hide="hide" \
                  >Write master configs</a>'
      var text = 'Don\'t forget to export the monitoring configuration. ' + link

      $('#mainMessage').jGrowl(text, {
        sticky: true,
        close: function(e, m) {
          var context = {}
          context.dataset = {}
          context.dataset.syUrl = 'index.php?page=export&action=hideMessage'
          context.dataset.syMethod = 'post'
          ajax.process.call(context, context, null, settings)
          wasExportNotificationDisplayed = false
        }
      })
      wasExportNotificationDisplayed = true
    }
  }

  function nagiosSatelliteNotification(satelliteId, satelliteName) {
    /*jshint multistr:true */

    if (!displayedExportNotificationForSatellites[satelliteId]) {
      // TODO: Try to avoid multiline strings
      var link = '<a \
                   href="#" \
                   data-sy-event-click="require" \
                   data-sy-url="index.php?page=export&action=buildSatellite" \
                   data-sy-data=\'{ "satelliteId": ' + satelliteId + '}\' \
                   data-sy-method="post" \
                   data-sy-growl-hide="hide" \
                  >Write satellite configurations</a>'
      var text = 'Don\'t forget to export the satellite configuration for \
                  host <b> ' + satelliteName + '</b>. ' + link

      $('#mainMessage').jGrowl(text, {
        sticky: true,
        close: function(e, m) {
          var context = {}
          context.dataset = {}
          context.dataset.syUrl = 'index.php?page=export&action=hideSatellite'
          context.dataset.syMethod = 'post'
          ajax.process.call(context, context, null, settings)
          displayedExportNotificationForSatellites[satelliteId] = false;
        }
      })

      displayedExportNotificationForSatellites[satelliteId] = true;
    }
  }

  function nagiosAllSatellitesNotification() {
    /*jshint multistr:true */

    if (!wasExportAllSatellitesNotificationDisplayed) {
      // TODO: Try to avoid multiline strings
      var link = '<a \
                   href="#" \
                   data-sy-event-click="require" \
                   data-sy-url="index.php?page=export&action=buildAllSatellites" \
                   data-sy-method="post" \
                   data-sy-growl-hide="hide" \
                  >Write all satellite configurations</a>'
      var text = 'One or more services/commands have changed. Probably you want to ' + link

      $('#mainMessage').jGrowl(text, {
        sticky: true,
        close: function(e, m) {
          var context = {}
          context.dataset = {}
          context.dataset.syUrl = 'index.php?page=export&action=hideAllSatellites'
          context.dataset.syMethod = 'post'
          ajax.process.call(context, context, null, settings)
          wasExportAllSatellitesNotificationDisplayed = false;
        }
      });
      wasExportAllSatellitesNotificationDisplayed = true;
    }
  }

  // TODO: This function name tells us nothing!
  function process(e) {
    /*jshint validthis:true */

    nagiosExportNotification()

    if ($('#isSatellite', this).val() == '1') {
      nagiosSatelliteNotification($('#hostId', this).val(), $('#hostname', this).val())
    }

    if ($('#satelliteId', this).val() > 0) {
      nagiosSatelliteNotification($('#satelliteId', this).val(), $('#satelliteId', this).find('option:selected').val())
    }

    if (this.dataset.syNotifyAll) {
      nagiosAllSatellitesNotification()
    }
  }

  return process
})
