define([
  'jquery',
  'upload',
  'datatables',
  'jquery-validate',
  'domReady!'
], function($, Upload) {
  /**
   * Delete an object and its row in a table
   */
  function deleteAndRemove(id, action, tr) {
    if (!window.confirm('Are you sure you want to delete this object?')) {
      return
    }

    $.ajax({
      dataType : 'json',
      type     : 'POST',
      url      : 'index.php?page=import&action=' + action,
      data     : { id: id },
      success  : function() {
        tr.remove()
      },
    })
  }

  /**
   * Handle the settings action response
   */
  function settingsHandler(data) {
    $('#buttonImportNext').prop('disabled', false)
    if (data.error.hasErrorMessages) {
      window.alert(data.error.errorMessages.join('\n'))
      $('#step2').unmask()
      return
    }

    $('#step2').unmask()
    $('#importWizard').wizard('next')
  }

  function conflictsHandler(data) {
    $('#buttonImportNext').prop('disabled', false)
    if (data.error.hasErrorMessages) {
      window.alert(data.error.errorMessages.join('\n'))
      $('#step3').unmask()
      return
    }

    $('#step3').unmask()

    var hosts      = data.parameters.hosts
      , services   = data.parameters.services
      , commands   = data.parameters.commands
      , hostgroups = data.parameters.hostgroups

    // Cancel the change event if there are still objects in conflict.
    if (hosts.length + services.length + commands.length + hostgroups.length) {
      window.alert('There are still objects in conflict.')

      // There are probably less conflicts than before so load again
      loadConflicts()

      return
    }

    $('#importWizard').wizard('next')
  }

  /**
   * Finish import on success, inform otherwise.
   */
  function finishHandler(data) {
    $('#buttonImportNext').prop('disabled', false)

    if (data.error.hasErrorMessages) {
      window.alert(data.error.errorMessages.join('\n'))
      $('#step4').unmask()
      return
    }

    window.alert('Done. The objects are now imported as specified.')
    location.reload()
  }

  /**
   * Show all objects with conflicts.
   */
  function loadConflicts() {
    $('#step3').html('')
    $('#step3').css('min-height', '100px')
    $('#step3').mask('Loading conflicts...')

    $.ajax({
      dataType : 'json',
      type     : 'GET',
      url      : 'index.php?page=import&action=getConflicts',
      success  : function(data) {
        if (data.error.hasErrorMessages) {
          window.alert(data.error.errorMessages.join('\n'))
          $('#step3').unmask()
          return
        }

        $('#step3').unmask()
        $('#step3 *').off()
        $('#step3').html(data.html)

        $('.add-popover').popover({ trigger: 'hover', html: true, container: 'body', placement: 'left', })

        $('#conflictsForm').submit(function() {
          $.ajax({
            dataType : 'json',
            type     : 'POST',
            url      : $(this).attr('action'),
            data     : $(this).serialize(),
            success  : conflictsHandler,
          })

          return false
        })

        // If 'use existing' is checked, the corresponding text input field must be disabled
        $('.existingService').on('click', function() {
          var id = $(this).attr('name').match(/\[(.*?)\]/)[1]
          var input = $('input[name=\'serviceName[' + id + ']\']')

          input.prop('disabled', $(this).is(':checked'))
        })

        $('.existingCommand').on('click', function() {
          var id = $(this).attr('name').match(/\[(.*?)\]/)[1]
          var input = $('input[name=\'commandName[' + id + ']\']')

          input.prop('disabled', $(this).is(':checked'))
        })

        $('.existingHostgroup').on('click', function() {
          var id = $(this).attr('name').match(/\[(.*?)\]/)[1]
          var input = $('input[name=\'hostgroupName[' + id + ']\']')

          input.prop('disabled', $(this).is(':checked'))
        })
      },
    })
  }

  /**
   * Load the overview (step 4) only if there are no more conflicts.
   */
  function loadOverview() {
    $('#step4').html('')
    $('#step4').css('min-height', '100px')
    $('#step4').mask('Loading overview...')

    $.ajax({
      dataType : 'json',
      type     : 'GET',
      url      : 'index.php?page=import&action=getOverview',
      success  : function(data) {
        if (data.error.hasErrorMessages) {
          window.alert(data.error.errorMessages.join('\n'))
          $('#step4').unmask()
          return
        }

        $('#step4').unmask()
        $('#step4 *').off()
        $('#step4').html(data.html)

        $('.add-popover').popover({ trigger: 'hover', html: true, container: 'body', placement: 'left', })

        $('#overviewForm').submit(function() {
          if ($('#overviewForm').valid()) {
            $('#buttonImportNext').prop('disabled', true)
            $('#step4').mask('Importing objects...')
            $.ajax({
              dataType : 'json',
              type     : 'POST',
              url      : $(this).attr('action'),
              data     : $(this).serialize(),
              success  : finishHandler,
            })
          }
          else {
            window.alert('Some values you entered are invalid.')
          }

          return false
        })

/*        $('select.combobox').chosen({
          search_contains : true,
        })
*/

        $('#step4 a[data-toggle="tab"]').on('shown.bs.tab', function (e) {
          $($.fn.dataTable.tables(true)).DataTable().columns.adjust()
        })

        try {
          $('.datatables').DataTable({
            'bSortClasses' : false,
            'paging'       : false,
            'scrollY'      : '400px',
          })
        }
        catch (e) {
          console.error('An error occured while initializing Datatable', e)
        }

        $.validator.addClassRules({
          serviceNumber: {
            required: true,
            min: 1,
            max: 10080,
            digits: true
          },
        });

        $('.validateForm').validate({
          errorElement: 'em',
          highlight: function(element, errorClass) {
            $(element).parent().addClass('has-error')
          },
          unhighlight: function(element, errorClass) {
            $(element).parent().removeClass('has-error')
          }
        });
      },
    })
  }

  $('body').addClass('big-popover')

  /**
   * Highlight the drop zone on drag.
   */
  $('body')
    .on('dragenter', function() {
      $('#file-drop').addClass('glowing-border')
    }) 
    .on('mouseenter', function() {
      $('#file-drop').removeClass('glowing-border')
    }) 

  $('#settingsForm').submit(function() {
    $.ajax({
      dataType : 'json',
      type     : 'POST',
      url      : $(this).attr('action'),
      data     : $(this).serialize(),
      success  : settingsHandler,
    })

    return false
  })

  /**
   * Cancel the whole import, i.e. delete all uploaded files and its objects.
   */
  $('#buttonImportCancel').on('click', function() {
    if (!window.confirm('Are you sure you want to cancel this import?')) {
      return
    }

    $.ajax({
      dataType : 'json',
      type     : 'POST',
      url      : 'index.php?page=import&action=cancel',
      success  : function() {
        location.reload()
      },
    })

    return false
  })


  $('#buttonImportNext').on('click', function() {
    var item = $('#importWizard').wizard('selectedItem')

    switch (item.step) {
      case 2:
        $('#step2').mask('Resolving dependencies...')
        $('#buttonImportNext').prop('disabled', true)
        $('#settingsForm').trigger('submit')
        break
      case 3:
        $('#step3').mask('Resolving conflicts...')
        $('#buttonImportNext').prop('disabled', true)
        $('#conflictsForm').trigger('submit')
        break
      default:
        $('#importWizard').wizard('next')
    }
  })

  /**
   * The change event is not trigered on stepclick.
   */
  $('#importWizard').on('stepclick', function(e, data) {
    if (data.step == 3) {
      loadConflicts()
    }
  })

  /**
   * Some steps require dynamic loading of content.
   */
  $('#importWizard').on('change', function(e, data) {
    // Conflicts
    if (data.step == 2) {
      loadConflicts()
    }

    // Overview
    if (data.step == 3) {
      loadOverview()
    }
  })

  /**
   * If a scrollable datatable is loaded in a wizard step, the table header
   * must be redrawn when visible
   */
  $('#importWizard').on('changed', function(e, data) {
    $($.fn.dataTable.tables(true)).DataTable().columns.adjust()
  })

  $('#importWizard').on('finished', function(e, data) {
    $('#overviewForm').submit()
  })

  var clickEvents = [ 'deleteFile'
                    , 'deleteHost'
                    , 'deleteService'
                    , 'deleteCommand'
                    , 'deleteHostGroup'
                    ]

  clickEvents.forEach(function(elem) {
    $(document).on('click', '.'+ elem, function(evt) {
      evt.preventDefault()

      var id = $(this).attr('id').split('-')[1]
        , tr = $(this).closest('tr')

      deleteAndRemove(id, elem, tr)
    })
  })

  $('#file-drop').on('drop dragenter dragover', false)

  $('#file-drop').on('drop', function(e) {
    $('#file-drop').css({ outline: '' })

    var overallProgress = null
    if (!$('#overallProgress').length) {
      overallProgress = $('<progress>').val('0').appendTo('#progressDiv')
    }

    var event = e.originalEvent
    Upload.upload(event.dataTransfer.files, '?page=import&action=upload', {
      overallProgress: overallProgress,
      start: function() {
        $('#buttonImportNext').prop('disabled', true)

        var tr           = $('<tr>')
          , tdName       = $('<td>')
          , tdHosts      = $('<td>', { class: 'text-right' })
          , tdServices   = $('<td>', { class: 'text-right' })
          , tdCommands   = $('<td>', { class: 'text-right' })
          , tdHostgroups = $('<td>', { class: 'text-right' })
          , tdDelete     = $('<td>')
          , tdInfo       = $('<td>', { colspan: 5 })
          , progress     = $('<progress>')
          , span         = $('<span>')
          , deleteButton = $('<button>', { class: 'deleteFile btn btn-link btn-xs' })
          , deleteSpan   = $('<span>', { class: 'glyphicon glyphicon-trash' })

        span.html(this.file.name)

        tr.append(tdName)
        tr.append(tdInfo)

        tdName.append(span)
        tdInfo.append(progress)

        tdDelete.append(deleteButton)
        deleteButton.append(deleteSpan)

        $('#uploads tbody').append(tr)

        this.on('progress', function(e) {
          if (event.lengthComputable) {
            progress.max         = event.total
            progress.value       = event.loaded
            progress.textContent = event.percent
          }
        })

        this.on('done', function() {
          var response = JSON.parse(this.xhr.responseText)

        $('#buttonImportNext').prop('disabled', false)

          progress.remove()
          span.remove()
          tdName.html(this.file.name)

          if (response.error.hasErrorMessages) {
            tr.addClass('danger');

            var errorMessages = response.error.errorMessages.join('\n')
              .replace(/\n/g,'<br />')

            tdInfo.html(errorMessages)
          }
          else {
            tdInfo.remove()

            tr.addClass('success');

            tdHosts.html(response.parameters.file.hosts).appendTo(tr)
            tdServices.html(response.parameters.file.services).appendTo(tr)
            tdCommands.html(response.parameters.file.commands).appendTo(tr)
            tdHostgroups.html(response.parameters.file.hostgroups).appendTo(tr)
            deleteButton.attr('id', 'delete-' + response.parameters.file.id)
            tr.append(tdDelete)
          }
        })
      }
    })

    return false
  })
})
