<?php
// +----------------------------------------------------------------------+
// | adfinis framework                                                    |
// +----------------------------------------------------------------------+

/**
 * Add all languages to the `language` table
 *
 * @author      Damian Senn
 * @package     org.adfinis.bin.dataCreator
 */

// SAPI check
CliChecker::sapiCheck();

// sanity check
$query = '
	SELECT
		COUNT(*) AS `count`
	FROM
		`language`
';
$result = DbManager::fetchRow($query);
if(!is_array($result) || $result['count'] > 0){
	die("Data exists, execution stopped\n");
}

$languages = array();
$languages[] = array(
	'language' => array(
		'languageID' => BaseI18n::LANG_DE_ID,
		'i18nNameID' => null,
		'code2' => 'de'
	),
	'i18nKey' => array(
		'keyword' => 'generic.language.name.de'
	),
	'i18nText' => array(
		array(
			'languageID' => BaseI18n::LANG_DE_ID,
			'value' => 'Deutsch'
		),
		array(
			'languageID' => BaseI18n::LANG_EN_ID,
			'value' => 'German'
		),
		array(
			'languageID' => BaseI18n::LANG_FR_ID,
			'value' => 'Allemand'
		)
	)
);
$languages[] = array(
	'language' => array(
		'languageID' => BaseI18n::LANG_EN_ID,
		'i18nNameID' => null,
		'code2' => 'en'
	),
	'i18nKey' => array(
		'keyword' => 'generic.language.name.en'
	),
	'i18nText' => array(
		array(
			'languageID' => BaseI18n::LANG_DE_ID,
			'value' => 'Englisch'
		),
		array(
			'languageID' => BaseI18n::LANG_EN_ID,
			'value' => 'English'
		),
		array(
			'languageID' => BaseI18n::LANG_FR_ID,
			'value' => 'Anglais'
		)
	)
);
$languages[] = array(
	'language' => array(
		'languageID' => BaseI18n::LANG_FR_ID,
		'i18nNameID' => null,
		'code2' => 'fr'
	),
	'i18nKey' => array(
		'keyword' => 'generic.language.name.fr'
	),
	'i18nText' => array(
		array(
			'languageID' => BaseI18n::LANG_DE_ID,
			'value' => 'Fransösisch'
		),
		array(
			'languageID' => BaseI18n::LANG_EN_ID,
			'value' => 'French'
		),
		array(
			'languageID' => BaseI18n::LANG_FR_ID,
			'value' => 'Français'
		)
	)
);

try{
	DbManager::beginTransaction();

	foreach($languages as $key => $language){
		$query = '
			INSERT INTO
				`language` (
					`languageID`,
					`i18nNameID`,
					`code2`
			) VALUES (
				:languageID,
				:i18nNameID,
				:code2
			)
		';

		DbManager::prepare($query)->execute($language['language']);

		$query = '
			INSERT INTO
				`i18nKey` (
					`keyword`
				) VALUES (
					:keyword
				)
		';
		DbManager::prepare($query)->execute($language['i18nKey']);
		$i18nKeyID = DbManager::lastInsertID();
		$i18nKeyText = array();
		foreach($language['i18nText'] as $i18nText){
			$i18nText['i18nKeyID'] = $i18nKeyID;
			$i18nKeyText[] = $i18nText;
		}
		$languages[$key]['i18nText'] = $i18nKeyText;

		$query = '
			UPDATE
				`language`
			SET
				`i18nNameID` = :i18nNameID
			WHERE
				`languageID` = :languageID
		';
		DbManager::prepare($query)->execute(array(
			'i18nNameID' => $i18nKeyID,
			'languageID' => $language['language']['languageID']
		));
	}

	foreach($languages as $language){
		$query = '
			INSERT INTO
				`i18nText` (
					`i18nKeyID`,
					`languageID`,
					`value`
				) VALUES (
					:i18nKeyID,
					:languageID,
					:value
				)
		';
		foreach($language['i18nText'] as $i18nText){
			DbManager::prepare($query)->execute($i18nText);
		}
	}
	DbManager::commit();
	echo "all done\n";
}catch(Exception $e){
	DbManager::rollBack();
	printf("oops error: %s \n", $e->getMessage());
}
