<?php
// +----------------------------------------------------------------------+
// | adfinis framework                                                    |
// +----------------------------------------------------------------------+

/**
 * Add all countries to the `country` table
 *
 * @author      Damian Senn
 * @package     org.adfinis.bin.dataCreator
 */

// SAPI check
CliChecker::sapiCheck();

// sanity check
$query = '
	SELECT
		COUNT(*) AS `count`
	FROM
		`country`
';
$result = DbManager::fetchRow($query);
if(!is_array($result) || $result['count'] > 0){
	die("Data exists, execution stopped\n");
}

try {
	$countries = array();
	$countriesCSV = new CsvIterator('dataCreator/002_countries.csv', ';', true);
	foreach($countriesCSV as $country){
		$newCountry = array(
			'country' => array(
				'code2'      => $country['country.code2'],
				'code3'      => $country['country.code3'],
				'phoneCode'  => $country['country.phoneCode'],
				'capital'    => $country['country.capital'],
				'priority'   => $country['country.priority'],
				'isEU'       => $country['country.isEU'],
				'isDeleted'  => $country['country.isDeleted']
			),
			'i18nKey' => array(
				'keyword'    => $country['i18nKey.keyword']
			),
			'i18nText' => array(
				array(
					'languageID' => BaseI18n::LANG_DE_ID,
					'value'      => $country['i18nText.1']
				),
				array(
					'languageID' => BaseI18n::LANG_EN_ID,
					'value'      => $country['i18nText.2']
				),
				array(
					'languageID' => BaseI18n::LANG_FR_ID,
					'value'      => $country['i18nText.3']
				)
			)
		);

		$countries[] = $newCountry;
	}

	DbManager::beginTransaction();

	$query = '
		INSERT INTO
			`i18nKey` (
				`keyword`
			) VALUES (
				:keyword
			)
	';
	$insertI18nKey = DbManager::prepare($query);

	$query = '
		INSERT INTO
			`country` (
				`i18nNameID`,
				`code2`,
				`code3`,
				`phoneCode`,
				`capital`,
				`priority`,
				`isEU`,
				`isDeleted`
			) VALUES (
				:i18nNameID,
				:code2,
				:code3,
				:phoneCode,
				:capital,
				:priority,
				:isEU,
				:isDeleted
			)
	';
	$insertCountry = DbManager::prepare($query);

	$query = '
		INSERT INTO
			`i18nText` (
				`i18nKeyID`,
				`languageID`,
				`value`
			) VALUES (
				:i18nKeyID,
				:languageID,
				:value
			)
	';
	$insertI18nText = DbManager::prepare($query);

	foreach($countries as $country){
		$insertI18nKey->execute($country['i18nKey']);
		$i18nKeyID = DbManager::lastInsertID();
		$country['country']['i18nNameID'] = $i18nKeyID;
		$i18nKeyText = array();
		foreach($country['i18nText'] as $i18nText){
			$i18nText['i18nKeyID'] = $i18nKeyID;
			$insertI18nText->execute($i18nText);
		}
		$insertCountry->execute($country['country']);
	}
	DbManager::commit();
	echo "all done\n";
}catch(Exception $e){
	DbManager::rollBack();
	printf("oops error: %s \n", $e->getMessage());
}
