<?php
// +----------------------------------------------------------------------+
// | adfinis framework                                                    |
// +----------------------------------------------------------------------+

/**
 * Add all cantons to the `canton` table
 *
 * @author      Damian Senn
 * @package     org.adfinis.bin.dataCreator
 */

// SAPI check
CliChecker::sapiCheck();

// sanity check
$query = '
	SELECT
		COUNT(*) AS `count`
	FROM
		`canton`
';
$result = DbManager::fetchRow($query);
if(!is_array($result) || $result['count'] > 0){
	die("Data exists, execution stopped\n");
}

try {
	$cantons = array();
	$cantonCSV = new CsvIterator('dataCreator/003_cantons.csv', ';', true);
	foreach($cantonCSV as $canton){
		$newCanton = array(
			'canton' => array(
				'code2'      => $canton['canton.code2']
			),
			'i18nKey' => array(
				'keyword'    => $canton['i18nKey.keyword']
			),
			'i18nText' => array(
				array(
					'languageID' => BaseI18n::LANG_DE_ID,
					'value'      => $canton['i18nText.1']
				),
				array(
					'languageID' => BaseI18n::LANG_EN_ID,
					'value'      => $canton['i18nText.2']
				)
			)
		);

		$cantons[] = $newCanton;
	}

	DbManager::beginTransaction();

	$query = '
		INSERT INTO
			`i18nKey` (
				`keyword`
			) VALUES (
				:keyword
			)
	';
	$insertI18nKey = DbManager::prepare($query);

	$query = '
		INSERT INTO
			`canton` (
				`i18nNameID`,
				`code2`
			) VALUES (
				:i18nNameID,
				:code2
			)
	';
	$insertCanton = DbManager::prepare($query);

	$query = '
		INSERT INTO
			`i18nText` (
				`i18nKeyID`,
				`languageID`,
				`value`
			) VALUES (
				:i18nKeyID,
				:languageID,
				:value
			)
	';
	$insertI18nText = DbManager::prepare($query);

	foreach($cantons as $canton){
		$insertI18nKey->execute($canton['i18nKey']);
		$i18nKeyID = DbManager::lastInsertID();
		$canton['canton']['i18nNameID'] = $i18nKeyID;
		$i18nKeyText = array();
		foreach($canton['i18nText'] as $i18nText){
			$i18nText['i18nKeyID'] = $i18nKeyID;
			$insertI18nText->execute($i18nText);
		}
		$insertCanton->execute($canton['canton']);
	}
	DbManager::commit();
	echo "all done\n";
}catch(Exception $e){
	DbManager::rollBack();
	printf("oops error: %s \n", $e->getMessage());
}
