<?php
// +----------------------------------------------------------------------+
// | adfinis framework                                                    |
// +----------------------------------------------------------------------+

/**
 * Add all cities to the `city` table
 *
 * @author        Damian Senn <ds@adfinis.ch>
 * @author        David Vogt <dv@adfinis.ch>
 * @todo by dv:   Import i18n stuff again.. somehow. We're not using 
 *                DB-oriented i18n anymore.
 */

use org\adfinis\framework\utils\CLIChecker;
use org\adfinis\framework\utils\fileformats\CSVIterator;
use org\adfinis\framework\utils\i18n\Translator;
use org\adfinis\framework\db\DbManager;

// SAPI check
CliChecker::sapiCheck();

// sanity check
$query = '
	SELECT
		COUNT(*) AS `count`
	FROM
		`city`
';
$result = DbManager::fetchRow($query);
if(!is_array($result) || $result['count'] > 0){
	die("Data exists, execution stopped\n");
}

$cities = array();
$cityCSV = new CsvIterator('dataCreator/004_cities.csv', ';', true);
foreach($cityCSV as $city){
	$newCity = array(
		'city' => array(
			'cantonID' => $city['city.cantonID'],
			'onrp'     => $city['city.onrp'],
			'zip'      => $city['city.zip']
		),
		'i18nKey' => array(
			'keyword'    => 'generic.city.name.'.$city['city.onrp']
		),
		'i18nText' => array(
			array(
				'languageID' => Translator::LANG_DE_ID,
				'value'      => $city['i18nText.1']
			)
		)
	);

	$cities[] = $newCity;
}

try {
	DbManager::beginTransaction();

	#$query = '
	#	INSERT INTO
	#		`i18nKey` (
	#			`keyword`
	#		) VALUES (
	#			:keyword
	#		)
	#';
	#$insertI18nKey = DbManager::prepare($query);

	$query = '
		INSERT INTO
			`city` (
				`cantonID`,
				`onrp`,
				`zip`
			) VALUES (
				:cantonID,
				:onrp,
				:zip
			)
	';
	$insertCity = DbManager::prepare($query);

	#$query = '
	#	INSERT INTO
	#		`i18nText` (
	#			`i18nKeyID`,
	#			`languageID`,
	#			`value`
	#		) VALUES (
	#			:i18nKeyID,
	#			:languageID,
	#			:value
	#		)
	#';
	#$insertI18nText = DbManager::prepare($query);

	foreach($cities as $city){
		#$insertI18nKey->execute($city['i18nKey']);
		#$i18nKeyID = DbManager::lastInsertID();
		#$city['city']['i18nNameID'] = $i18nKeyID;
		#$i18nKeyText = array();
		#foreach($city['i18nText'] as $i18nText){
		#	$i18nText['i18nKeyID'] = $i18nKeyID;
		#	$insertI18nText->execute($i18nText);
		#}
		$insertCity->execute($city['city']);
	}
	DbManager::commit();
	echo "all done\n";
}catch(\PDOException $e){
	DbManager::rollBack();
	printf("oops error: %s \n", $e->getMessage());
}
