#!/usr/bin/env php
<?php
$stdin  = fopen('php://stdin',  'r');
$stdout = fopen('php://stdout', 'w');

# Detect script paths..
$mydir = dirname(__FILE__);
chdir($mydir);     // now at lib/adfinis/bin
chdir('../../..'); // now at app root
$rootdir = getcwd();

// Set source & target paths
$TEMPLATES = sprintf("%s/lib/adfinis/data/app-template", $rootdir);
$APPDIR    = sprintf("%s/app",                           $rootdir);
$HTDOCS    = sprintf("%s/htdocs",                        $rootdir);
$FWDIR     = sprintf("%s/lib/adfinis",                   $rootdir);
$JSDIR     = sprintf("%s/lib/javascript",                $rootdir);

// Notify user about what's gonna happen
printf("Welcome to the app preparator.\n");
printf("\n");
printf("Installing Templates into the following directories:\n");
printf("    application classes: %s\n", $APPDIR);
printf("    web content:         %s\n", $HTDOCS);
printf("\n");
dialog("Hit <Ctrl-C> if this is not what you want. Or <Enter> if you agree.\n");


# Application name
$appname = dialog('Application name: ');

# Namespace and app directory
$namespace = dialog('Application namespace: ');
$classdir  = str_replace('\\', '/', $namespace);

echo "\n";
############################# Begin install code ######################

// Directories
status('Creating required directories');
cmd('install', '-d', $HTDOCS.'/framework-utils');
cmd('install', '-d', $HTDOCS.'/jslib');
cmd('install', '-d', $APPDIR.'/inc');
cmd('install', '-d', $APPDIR.'/bin');
cmd('install', '-d', $APPDIR.'/templates');
cmd('install', '-d', $APPDIR.'/auto');
cmd('install', '-d', $APPDIR.'/inc/'.$classdir);
cmd('install', '-d', $APPDIR.'/config');

// htdocs symlinks
status('Symlinking framework utilities and lib/javascript into htdocs.');
cmd('ln', '-sf', glob($FWDIR.'/htdocs/*'), $HTDOCS.'/framework-utils');
cmd('ln', '-sf', glob($JSDIR.'/*'),        $HTDOCS.'/jslib');

// Prepend / Append files
status('Copying prepend / append files');
cmd('install', glob($TEMPLATES.'/app/auto/*.php'), $APPDIR.'/auto');


status('Copying and adjusting app files');
cmd('cp', '-r', glob($TEMPLATES.'/inc/NAMESPACE/*'), $APPDIR.'/inc/'.$classdir);
fixNamespaces($APPDIR.'/inc/'.$classdir, $namespace);
cmd('cp', '-r', glob($TEMPLATES.'/htdocs/*'), $HTDOCS);
fixNamespaces($HTDOCS, $namespace);
cmd('cp', '-r', glob($TEMPLATES.'/templates/*'), $APPDIR.'/templates/');

cmd('cp', '-r', glob($TEMPLATES.'/config.defs'    ), $rootdir);
cmd('cp', '-r', glob($TEMPLATES.'/config.template'), $rootdir);


############################# End install code ########################

function fixNamespaces($path, $namespace) {
	// TODO: is this really, really the right way to do it?
	$directoryIterator = new RecursiveDirectoryIterator($path);
	$recursiveIterator = new RecursiveIteratorIterator($directoryIterator);
	$regexIterator     = new RegexIterator($recursiveIterator, '/^.+\.php$/i', RecursiveRegexIterator::GET_MATCH);

	foreach($regexIterator as $file) {
		$path = $file[0];
		$content = file_get_contents($path);
		$content = preg_replace('/#NAMESPACE#/', $namespace, $content);
		file_put_contents($path, $content);
	}
}

function status($message) {
	printf("=== %s\n", $message);
}

function cmd($cmd) {
	$args = func_get_args();

	// $args[0] == $cmd. We don't need that.
	array_shift($args);

	$argsEscaped = array();
	foreach($args as $arg) {
		if(is_array($arg)) {
			foreach($arg as $subarg) {
				$argsEscaped[] = escapeshellarg($subarg);
			}
		}
		else {
			$argsEscaped[] = escapeshellarg($arg);
		}
	}

	$line = sprintf(
		'%s %s',
		$cmd,
		join(' ', $argsEscaped)
	);

	return system($line);
}

function dialog($message, $multiline = false) {
	global $stdin;
	global $stdout;

	fprintf($stdout, $message);
	fflush($stdout);

	if($multiline) {
		$content = '';
		while(($data = fread($stdin, 1024)) !== false) {
			$content .= $data;
		}
		return $data;
	}
	else {
		$line = fgets($stdin);
		$line = trim($line);

		return $line;
	}
}
