#!/usr/bin/env php
<?php

$params = array(
	'config' => 'default.conf'
);

// Parse parameters
//
// Optional parameter for providing a configuration file:
//     -c [FILENAME] or --config [FILENAME]
// Optional parameter for providing an absolute path:
//     -d [PATHNAME] or --defs [PATHNAME]
$shortopts  = "";
$shortopts .= "c:";
$shortopts .= "d:";
$shortopts .= "o:";
$shortopts .= "t:";
$longopts   = array(
	"config:",
	"defs:",
	"dest:",
	"tpls:"
);
$options = getopt($shortopts, $longopts);

foreach($options as $opt => $param) {
	switch($opt) {
		case 'c':
		case 'config':
			$params['config'] = $param;
			break;
		case 'd':
		case 'defs':
			$params['defs'] = $param;
			break;
		case 'o':
		case 'dest':
			$params['dest'] = $param;
			break;
		case 't':
		case 'tpls':
			$params['tpls'] = $param;
			break;
	}
}

// We're expected to be in <appdir>/lib/adfinis/bin/
$appdir  = dirname(dirname(dirname(dirname(__FILE__))));
$defsDir = sprintf('%s/config.defs',     $appdir);
$tplsDir = sprintf('%s/config.template', $appdir);


if (isset($params['defs'])) {
	if (is_dir($params['defs'])) {
		$defsDir = $params['defs'];
		echo(sprintf("### NOTICE: Using absolute directory %s for reading config.defs\n", $params['defs']));
	}
	else {
		die(sprintf("ERROR: Given absolute directory %s for reading config.defs not found!\n", $params['defs']));
	}
}

if (isset($params['tpls'])) {
	if (is_dir($params['tpls'])) {
		$tplsDir = $params['tpls'];
		echo(sprintf("### NOTICE: Using absolute directory %s for reading config.template\n", $params['tpls']));
	}
	else {
		die(sprintf("ERROR: Given absolute directory %s for reading config.template not found!\n", $params['tpls']));
	}
}

if (isset($params['dest'])) {
	$destDir = $params['dest'];
}
else {
	$destDir = sprintf('%s/config',     dirname($tplsDir));
}


// If destDir does not exist, create it
if (!is_dir($destDir)) {
	mkdir($destDir);
}
echo(sprintf("### NOTICE: Using directory %s for writing configs\n", $destDir));

$dirs = array(
	'checkout'        => $appdir,
	'config.defs'     => $defsDir,
	'config.template' => $tplsDir,
	'config'          => $destDir,
	'framework.inc'   => sprintf('%s/lib/adfinis/inc', $appdir),
	'libs'            => sprintf('%s/lib/',            $appdir)
);
define('INC_PATH', $dirs['libs']);

// manually set timezone (to remove a warning while executing)
ini_set('date.timezone', 'Europe/Zurich');


// We can't assume a properly configured env here, so
// we load our stuff by hand..
include_once(sprintf('%s/org/adfinis/framework/deploy/ConfigHelper.class.php', $dirs['framework.inc']));
use org\adfinis\framework\deploy\ConfigHelper;

$configFile = sprintf(
	'%s/%s',
	$dirs['config.defs'],
	$params['config']
);
$ch = new ConfigHelper($dirs['checkout'], $configFile);
$ch->generateSiteConfig($dirs['config.template'], $dirs['config']);
