#!/bin/bash
DIR=`dirname $0`  # $DIR should be <fw-location>/data/bin
cd "$DIR/../../../"
DIR=`pwd` # $DIR should now be <fw-location>

. config/shellConfig.sh

# Only run tests if the environment is set to "test". We don't 
# want to break existing dev or production data.
if [ "$environment" != "test" ]; then
	echo "--- WARNING: ENV is not set to 'test', aborting unit tests."
	echo "--- Please run tests with an appropriate configuration"
	exit 2
fi

DIRS=""

if [ "$1" = "framework" ]; then
	TESTDIR="$DIR/lib/adfinis/tests/"
elif [ "$1" = "app" ]; then
	TESTDIR="$DIR/app/tests/"
else
	echo "--- Unknown mode. Use one of the following commands:"
	echo "--- $0 framework"
	echo "--- $0 app"
	exit 1
fi

echo "=== Running PHPUnit for $1. Tests in $TESTDIR"

if [ ! -d $TESTDIR ]; then
	echo "--- No tests for $1, skipping"
	exit 0
fi

TESTSUITE_XML=/tmp/selenium.$$.xml

# build test suite xml
echo "<phpunit><testsuites><testsuite name=\"$1\">" > $TESTSUITE_XML

shift
if [[ "$#" == 0 ]]; then
	# put all the files in the $TESTDIR to the XML
	find $TESTDIR -name "*.php" | xargs -I% echo '    <file>%</file>' >> $TESTSUITE_XML
else
	# only use the given files in the arguments
	while (( "$#" )); do
		echo "<file>$TESTDIR$1</file>" >> $TESTSUITE_XML
		shift
	done
fi

echo "</testsuite></testsuites></phpunit>" >> $TESTSUITE_XML

./lib/adfinis/bin/cliExec.sh \
	./lib/pear/bin/phpunit \
	--colors       \
	--verbose      \
	--no-configuration \
	--strict \
	--syntax-check \
	--configuration $TESTSUITE_XML

#rm -f $TESTSUITE_XML
