<?php

namespace #NAMESPACE#\presentation;

use \org\adfinis\framework\config\ConfManager;

/**
 * Protected page. Requires the user to be logged in to function.
 *
 * @author        David Vogt <dv@adfinis.ch>
 * @copyright     adfinis GmbH 2011
 * @license       BSD 3-Clause
 **/
class ProtectedPage extends BasePage {

	/**
	 * Constructor
	 *
	 * Passes all parameters to parent's constructor, then checks whether
	 * there's a user logged in. If user is not logged in, a redirect to
	 * the login page is done, then the program exits.
	 *
	 * @author        David Vogt <dv@adfinis.ch>
	 * @throws        UnexpectedValueException
	 * @param         bool   $allowSecure      (optional, defaults to false)
	 * @param         bool   $needSecure       (optional, defaults to false)
	 * @param         string $domainIdentifier (optional, defaults to 'default')
	 */
	public function __construct($allowSecure = false, $needSecure = false, $domainIdentifier = 'default') {
		parent::__construct($allowSecure, $needSecure, $domainIdentifier);

		// Assign userinfo stuff
		$this->tpl->assign(
			'userinfoData',
			array(
				'logoutURL'   => URLGenerator::getStaticPageURL(URLGenerator::STATIC_PAGE_LOGOUT),
				'profileURL'  => URLGenerator::getStaticPageURL(URLGenerator::STATIC_PAGE_USERPROFILE),
				'currentUser' => $this->login->getCurrentUser()
			)
		);
		$this->checkLoggedIn();
	}

	/**
	 * Checks whether the user is logged in. Redirects to login page if he's not.
	 *
	 * @author        David Vogt <dv@adfinis.ch>
	 * @returns       void
	 */
	private function checkLoggedIn() {
		throw new Exception('This method is a dummy from the framework. YOU need to implement it!');
	}
}
