<?php

namespace org\adfinis\framework\config;

/**
 * class dealing with config values
 *
 * @author      Matthias Blaser <mb@adfinis.ch>
 * @copyright   adfinis GmbH 2005-2010
 * @license     BSD 3-Clause
 */
class ConfManager {

	/**
	 * Get configuration variable identified by the given key sequence.
	 *
	 * To get the config Key foo::bar::baz, call this:
	 * @code
	 * ConfManager::getVar('af', 'foo', 'bar', 'baz');
	 * @endcode
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @todo by dv: Throw another exception if config is not present
	 * @throws      \OutOfRangeException
	 * @return      mixed
	 */
	public static function getVar(){
		global $_conf;

		$value = $_conf;
		$args = func_get_args();

		foreach($args as $arg){
			if(is_array($value) && key_exists($arg, $value)){
				$value = $value[$arg];
			}
			else {
				throw new \OutOfRangeException(
					sprintf(tr('Key "%s" not found in config'), join(':', $args))
				);
			}
		}

		return $value;
	}

	/**
	 * Checks wether a configuration var is set or not
	 *
	 * To check the config Key foo::bar::baz, call this:
	 * @code
	 * ConfManager::keyExists('af', 'foo', 'bar', 'baz');
	 * @endcode
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @return      bool
	 */
	public static function keyExists(){
		global $_conf;

		$value = $_conf;
		$args = func_get_args();

		foreach($args as $arg){
			if(is_array($value) && key_exists($arg, $value)){
				$value = $value[$arg];
			} else {
				return false;
			}
		}

		return true;
	}
}
