<?php

namespace org\adfinis\framework\controller;

/**
 * Interface definition for a controller class
 *
 * Defines methods that are required to act properly when using a object-oriented controller approach.
 *
 * @author        David Vogt <dv@adfinis.ch>
 * @copyright     adfinis GmbH 2011
 * @license       BSD 3-Clause
 **/
interface ControllerInterface {

	/**
	 * Constructor.
	 *
	 * @author        David Vogt <dv@adfinis.ch>
	 * @param         org\adfinis\framework\request\RequestInterface $request
	 * @param         array                                          $urlMatch
	 */
	public function __construct($request, $urlMatch);

	/**
	 * Returns a request object, representing the current request.
	 *
	 * @author        David Vogt <dv@adfinis.ch>
	 * @returns       org\adfinis\framework\request\RequestInterface
	 */
	public function getRequest();

	/**
	 * Handles the request.
	 *
	 * You need to implement full request handling in this method.
	 *
	 * @author        David Vogt <dv@adfinis.ch>
	 * @returns       void
	 */
	public function handle();
}
