<?php

namespace org\adfinis\framework\datamapper;

use \org\adfinis\framework as oaf;

/**
 * Abstract Mapper class
 *
 * @author        Damian Senn <ds@adfinis.com>
 * @copyright     adfinis GmbH 2011
 * @license       BSD 3-Clause
 */
abstract class Mapper {

	/**
	 * The class for which this mapper is used
	 *
	 * @var           string $targetClass
	 */
	protected $targetClass;

	/**
	 * Constructor of Mapper
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @param         string $targetClass
	 */
	public function __construct($targetClass) {
		$this->targetClass = $targetClass;
	}

	/**
	 * Saves the given oaf\model\Entity
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @param         oaf\model\Entity $obj
	 * @returns       array $identifier
	 */
	abstract public function save(oaf\model\Entity $obj);

	/**
	 * Deletes the entity with this identifier from the database
	 *
	 * @author        Denis Simonet <denis.simonet@adfinis-sygroup.ch>
	 * @param         array $identifier
	 * @returns       void
	 */
	abstract public function delete($identifier);

	/**
	 * Return the dataset by the given ID
	 *
	 * This method must throw an exception when the dataset
	 * is not found.
	 * @author        Stefan Heinemann <stefan.heinemann@adfinis-sygroup.ch>
	 * @param         int $id
	 * @throws        \OutOfBoundException
	 * @returns       
	 */
	abstract public function getByID($id);

	/**
	 * Return whether a dataset exist with given ID
	 *
	 * @author        Stefan Heinemann <stefan.heinemann@adfinis-sygroup.ch>
	 * @param         int $id (probably mixed?)
	 * @returns       bool
	 */
	public function exists($id) {
		try {
			$this->getByID($id);
		} catch (\OutOfBoundsException $e) {
			return false;
		}

		return true;
	}
}
