<?php

namespace org\adfinis\framework\db;

use org\adfinis\framework\config\ConfManager;
use org\adfinis\framework\exceptions\DatabaseException;

/**
 * Class dealing with database connection and running queries (Debug verison)
 *
 * The database backend is using PDO (PHP data objects) and most
 * functions will return native PDO classes.
 *
 * @author      Matthias Blaser <mb@adfinis.ch>
 * @copyright   adfinis GmbH 2007-2010
 * @license     BSD 3-Clause
 * @see         http://ch2.php.net/pdo
 */
class DbManagerDebug extends DbManager {
	/**
	 * Executes a query and returns a result-statement object
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @throws      Zend_Db_Exception
	 * @param       string $SQL
	 * @param       array  $bind An array of data to bind to the placeholders.
	 * @param       string $instanceName
	 * @return      PDOStatement
	 * @see         http://ch2.php.net/manual/en/function.PDO-query.php
	 */
	public static function query($SQL, $bind = array(), $instanceName = 'default'){
		$time_start = microtime(true);
			$pdoStatement = self::getInstance($instanceName)->query($SQL, $bind);
			$pdoStatement->setFetchMode(PDO::FETCH_ASSOC);
		$time_end = microtime(true);
		$time = $time_end - $time_start;

		//sessionManager::getInstance()->tempQueries .= sprintf("A: %.4f || %.175s <br />", $time, $SQL);
		printf('<div style="font-size:15px;color:#ffffff;">A: %.4f || %.150s </div><br />', $time, $SQL);
		//file_put_contents('/tmp/blubber/queryExecuteTime',sprintf("%s¦%s\n", $time, $SQL), FILE_APPEND);

		return $pdoStatement;
	}

	/**
	 * Executes a query and returns only the first row
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @throws      Zend_Db_Exception
	 * @param       string $SQL
	 * @param       string $instanceName
	 * @return      array $row
	 * @see         http://ch2.php.net/manual/en/function.PDO-query.php
	 */
	public static function queryFirst($SQL, $instanceName = 'default'){
		$time_start = microtime(true);
			$pdoStatement = self::getInstance($instanceName)->query($SQL);
			$pdoStatement->setFetchMode(PDO::FETCH_ASSOC);
			$row = $pdoStatement->fetch();
			$pdoStatement->closeCursor();
		$time_end = microtime(true);
		$time = $time_end - $time_start;

		//sessionManager::getInstance()->tempQueries .= sprintf("B: %.4f || %.175s <br />", $time, $SQL);
		printf('<div style="font-size:15px;color:#ffffff;">B: %.4f || %.150s </div><br />', $time, $SQL);
		//file_put_contents('/tmp/blubber/queryExecuteTime',sprintf("%s¦%s\n", $time, $SQL), FILE_APPEND);

		return $row;
	}

	/**
	 * Executes a query and returns the number of affected rows
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @throws      Zend_Db_Exception
	 * @param       string $SQL
	 * @param       string $instanceName
	 * @return      int affected rows
	 * @see         http://ch2.php.net/manual/en/function.PDO-exec.php
	 */
	public static function executeQuery($SQL, $instanceName = 'default'){
		$time_start = microtime(true);
			$result = self::getInstance($instanceName)->exec($SQL);
		$time_end = microtime(true);
		$time = $time_end - $time_start;

		//sessionManager::getInstance()->tempQueries .= sprintf("B: %.4f || %.175s <br />", $time, $SQL);
		printf('<div style="font-size:15px;color:#ffffff;">B: %.4f || %.150s </div><br />', $time, $SQL);
		//file_put_contents('/tmp/blubber/queryExecuteTime',sprintf("%s¦%s\n", $time, $SQL), FILE_APPEND);

		return $result;
	}
}
