<?php

namespace org\adfinis\framework\form\fields;

/**
 * FormCheckboxField class which extends FormInputField for checkbox fields
 *
 * @author      Damian Senn <ds@adfinis.ch>
 * @copyright   adfinis GmbH 2009-2010
 * @license     BSD 3-Clause
 */
class FormCheckboxField extends FormInputField {
	/**
	 * @var bool $checked
	 */
	private $checked = false;

	/**
	 * @var bool $required
	 */
	private $required;

	/**
	 * Constructor
	 *
	 * @author      Damian Senn <ds@adfinis.ch>
	 * @param       string $name
	 * @param       string $title
	 * @param       string $value      (optional)
	 * @param       string $checked    (optional)
	 * @param       array  $attributes (optional)
	 * @param       bool   $required   (optional)
	 * @return      void
	 */
	public function __construct($name, $title, $value = '', $checked = false, $attributes = array(), $required = false){
		parent::__construct($name, $title, $value, 'checkbox', true, $attributes);
		$this->required = $required;
		$this->setValue($checked);
		/* if HTML5
		 * $this->attributes['required'] = null;
		 * <input type="checkbox" required>
		 */
	}

	/**
	 * Sets the input field checked state
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @param       bool $checked
	 * @param       bool $validate (optional)
	 * @return      void
	 */
	public function setValue($checked, $validate = true){
		if($checked){
			$this->checked = true;
			$this->attributes['checked'] = 'checked';
		} else {
			$this->checked = false;
			unset($this->attributes['checked']);
		}
		if($validate){
			$this->validateValue($this->checked);
		}
	}

	/**
	 * Validates the given value
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @param       mixed $value
	 * @return      bool
	 */
	public function validateValue($value){
		if($value !== null && $value !== false){
			$this->attributes['class'] = 'valid';
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Returns the value of the checkbox if checked, false if not
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      string|int|false
	 */
	public function getValue(){
		if($this->checked == true){
			return $this->attributes['value'];
		} else {
			return false;
		}
	}
}
