<?php

namespace org\adfinis\framework\form\fields;

/**
 * FormInputField class which extends FormField for input fields
 *
 * @author      Toni Rudolf <tr@adfinis.ch>
 * @author      Adrian Wittwer <aw@adfinis.ch>
 * @author      Damian Senn <ds@adfinis.ch>
 * @copyright   adfinis GmbH 2009-2010
 * @license     BSD 3-Clause
 */
class FormInputField extends FormField {
	/**
	 * Constructor
	 *
	 * @author      Toni Rudolf <tr@adfinis.ch>
	 * @author      Adrian Wittwer <aw@adfinis.ch>
	 * @author      Damian Senn <ds@adfinis.ch>
	 * @todo by dv: Document & describe the parameters here
	 * @param       string  $name
	 * @param       string  $title
	 * @param       string  $defaultValue     (optional)
	 * @param       string  $type             (optional)
	 * @param       string  $autoFill         (optional)
	 * @param       array   $attributes       (optional)
	 * @param       Closure $validateCallback (optional)
	 * @return      void
	 */
	public function __construct($name, $title, $defaultValue = '', $type = 'text', $autoFill = true, array $attributes = array(), Closure $validateCallback = null){
		parent::__construct($name, $title, $autoFill, $attributes, $validateCallback);

		$this->attributes['type'] = $type;
		$this->attributes['name'] = $name;
		$this->attributes['id'] = $name;
		$this->attributes['value'] = $defaultValue;
	}

	/**
	 * Returns the type of the FormField
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      string
	 */
	public function getType(){
		return $this->attributes['type'];
	}

	/**
	 * Returns the HTML element of this field
	 *
	 * @author      Damian Senn <ds@adfinis.ch>
	 * @return      string (HTML element)
	 */
	public function returnField(){
		$attributes = $this->attributes;
		if(!$this->getAutoFill()){
			$attributes['value'] = '';
		}

		// return input HTML element
		return sprintf('<input %s />', self::getAttributesString($attributes));
	}

	/**
	 * Calls the validateCallback function
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @param       string $value
	 * @return      bool
	 */
	public function validateValue($value){
		// we need to get the callback method before we can call it
		$callback = $this->validateCallback;
		// get callback message
		$message = $callback($value);
		if(!$message['error']){
			$this->attributes['class'] = 'valid';
			return true;
		} else {
			$this->attributes['class'] = 'invalid';
			$this->setErrorMessage($message['message']);
			return false;
		}
	}

	/**
	 * Returns the FormField value
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      string
	 */
	public function getValue(){
		return $this->attributes['value'];
	}
}
