<?php

namespace org\adfinis\framework\form\fields;

/**
 * FormRadioField class which extends FormInputField for radio groups
 *
 * @author      Damian Senn <ds@adfinis.ch>
 * @copyright   adfinis GmbH 2009-2010
 * @license     BSD 3-Clause
 */
class FormRadioField extends FormInputField {

	/**
	 * @var bool $checked
	 */
	private $checked = false;

	/**
	 * Constructor
	 *
	 * @author      Damian Senn <ds@adfinis.ch>
	 * @param       string $name
	 * @param       string $title
	 * @param       string $value      (optional)
	 * @param       array  $attributes (optional)
	 * @return      void
	 */
	public function __construct($name, $title, $value = '', array $attributes = array()){
		parent::__construct($name, $title, $value, 'radio', true, $attributes);
	}

	/**
	 * Sets the input field checked state
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @param       bool $checked
	 * @param       bool $validate (optional)
	 * @return      void
	 */
	public function setValue($checked, $validate = true){
		if($checked !== null && $checked !== false){
			$this->checked = true;
			$this->attributes['checked'] = 'checked';
		} else {
			$this->checked = false;
			unset($this->attributes['checked']);
		}
		if($validate){
			$this->validateValue($this->checked);
		}
	}

	/**
	 * Validates the given value
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @param       mixed $value
	 * @return      bool
	 */
	public function validateValue($value){
		if($value){
			$this->attributes['class'] = 'valid';
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Returns the value of the radiobutton if checked, false if not
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      string|int|false
	 */
	public function getValue(){
		if($this->checked == true){
			return $this->attributes['value'];
		} else {
			return false;
		}
	}
}
