<?php

namespace org\adfinis\framework\form\fields;

/**
 * FormRadioGroup class which handles radio boxes
 *
 * @author      Damian Senn <ds@adfinis.ch>
 * @copyright   adfinis GmbH 2009-2010
 * @license     BSD 3-Clause
 */
class FormRadioGroup extends FormField {
	private $formRadioFields = array();
	private $name;

	/**
	 * Constructor of FormRadioGroup
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @param       string $name
	 * @param       string $title
	 * @param       array  $values
	 * @param       string $selected   (optional)
	 * @param       array  $attributes (optional)
	 * @return      void
	 */
	public function __construct($name, $title, array $values, $selected = null, array $attributes = array()){
		$firstLoop = true;
		foreach($values as $key => $value){
			$formField = new FormRadioField($name, $key, $value, $attributes);
			$formField->setAttribute('id', $name.ucfirst($value));
			$this->formRadioFields[$value] = $formField;

			if($firstLoop){ // check first radiobutton
				$formField->setValue(true);
				$firstLoop = false;
			}
		}

		// selected preselected radiobutton
		if($selected !== null){
			$this->setValue($selected);
		}
		$this->name = $name;
		$this->attributes['title'] = $title;
	}

	/**
	 * Returns the RadioGroupLabel
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      string
	 */
	public function returnLabel(){
		return sprintf('<label for="%s">%s</label>',
			$this->name, $this->attributes['title']);
	}

	/**
	 * Selects the FormRadioField with the given value
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @param       string|int $value
	 * @param       bool $validate (optional)
	 * @return      void
	 */
	public function setValue($value, $validate = true){
		foreach($this->formRadioFields as $key => $formField){
			$formField->setValue($key == $value, $validate);
		}
	}

	/**
	 * Returns the value of the selected FormRadioField
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      string|int
	 */
	public function getValue(){
		foreach($this->formRadioFields as $key => $formField){
			$value = $formField->getValue();
			if($value !== false){
				return $value;
			}
		}
	}

	/**
	 * The validate function is called in the setter of each FormRadioField
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @param       string $value
	 * @return      void
	 */
	public function validateValue($value){
		// Abstract method which needs to be implemented
	}

	/**
	 * Returns the type of the FormRadioGroup
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      string
	 */
	public function getType(){
		return 'radiogroup';
	}

	/**
	 * Returns the name of this FormField
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      string
	 */
	public function getName(){
		return $this->name;
	}

	/**
	 * Returns the FormRadioGroup HTML element
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      string
	 */
	public function returnField(){
		$field = sprintf('<span id="%s">', $this->getName());
		foreach($this->formRadioFields as $formField){
			$field .= sprintf('<span class="radio">%s%s</span>',
				$formField->returnField(), $formField->returnLabel());
		}
		$field .= '</span>';
		return $field;
	}
}
