<?php

namespace org\adfinis\framework\form\fields;

/**
 * FormSelectField class which extends FormField for select fields
 *
 * @author      Damian Senn <ds@adfinis.ch>
 * @copyright   adfinis GmbH 2009-2010
 * @license     BSD 3-Clause
 */
class FormSelectField extends FormField {
	/**
	 * Holds the selected value
	 *
	 * @var string $value
	 */
	private $value;

	/**
	 * Holds the possible values
	 *
	 * @var array $values
	 */
	private $values = array();

	/**
	 * Constructor
	 *
	 * @author      Damian Senn <ds@adfinis.ch>
	 * @param       string $name
	 * @param       string $title
	 * @param       array  $values
	 * @param       string $selected   (optional)
	 * @param       array  $attributes (optional)
	 * @return      void
	 */
	public function __construct($name, $title, array $values, $selected = null, array $attributes = array()){
		parent::__construct($name, $title, true, $attributes);
		$this->attributes['name'] = $name;
		$this->attributes['id'] = $name;
		$this->values = $values;
		$this->setValue($selected);
	}

	/**
	 * Returns the type of this FormField
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      string
	 */
	public function getType(){
		return 'select';
	}

	/**
	 * Returns the current value
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      mixed
	 */
	public function getValue(){
		return $this->value;
	}

	/**
	 * Selects the option with the given value
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @param       string|int $value
	 * @param       bool       $validate (unused)
	 * @return      void
	 */
	public function setValue($value, $validate = true){
		if(in_array($value, $this->values)){
			$this->value = $value;
		}
	}

	/**
	 * The validate function
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @param       string $value
	 * @return      void
	 */
	protected function validateValue($value){
		// Not needed by now, maybe we should implement this if we got an "empty" option
	}

	/**
	 * Returns the HTML select field element
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      string
	 */
	public function returnField(){
		$select = sprintf('<select %s>',
			self::getAttributesString($this->attributes));

		foreach($this->values as $label => $value){
			if($this->getValue() != $value){
				$select .= sprintf('<option value="%s">%s</option>', $value, $label);
			} else {
				$select .= sprintf('<option value="%s" selected="selected">%s</option>',
					$value, $label);
			}
		}
		$select .= '</select>';
		return $select;
	}
}
