<?php

namespace org\adfinis\framework\form\fields;

/**
 * FormTextField class which extends FormField for textarea fields
 *
 * @author      Damian Senn <ds@adfinis.ch>
 * @copyright   adfinis GmbH 2009-2010
 * @license     BSD 3-Clause
 */
class FormTextField extends FormField {
	private $text;

	/**
	 * Constructor of FormTextField
	 *
	 * @author      Damian Senn <ds@adfinis.ch>
	 * @param       string  $name
	 * @param       string  $title
	 * @param       string  $defaultText      (optional, defaults to '')
	 * @param       bool    $autoFill         (optional, defaults to true)
	 * @param       array   $attributes       (optional)
	 * @param       Closure $validateCallback (optional)
	 * @return      void
	 */
	public function __construct($name, $title, $defaultText = '', $autoFill = true, array $attributes = array(), Closure $validateCallback = null){
		parent::__construct($name, $title, $autoFill, $attributes, $validateCallback);

		$this->text = $defaultText;
		$this->attributes['name'] = $name;
		$this->attributes['id'] = $name;
	}

	/**
	 * Returns the type of the FormField
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      string
	 */
	public function getType(){
		return 'textarea';
	}

	/**
	 * Returns the HTML element of this field
	 *
	 * @author      Damian Senn <ds@adfinis.ch>
	 * @return      string (HTML element)
	 */
	public function returnField(){
		$text = $this->text;
		if(!$this->getAutoFill()){
			$text = '';
		}

		// return textarea HTML element
		return sprintf('<textarea %s>%s</textarea>',
			self::getAttributesString($this->attributes), $text);
	}

	/**
	 * Calls the validateCallback function
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @param       string $value
	 * @return      bool
	 */
	public function validateValue($value){
		// we need to get the callback method before we can call it
		$callback = $this->validateCallback;
		// get callback message
		$message = $callback($value);
		if(!$message['error']){
			$this->attributes['class'] = 'valid';
			return true;
		} else {
			$this->attributes['class'] = 'invalid';
			$this->setErrorMessage($message['message']);
			return false;
		}
	}

	/**
	 * Returns the FormField value
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      string
	 */
	public function getValue(){
		return $this->text;
	}

	/**
	 * Sets the value of the field and call the validateValue method
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @param       string $value
	 * @param       bool   $validate (optional)
	 * @return      void
	 */
	public function setValue($value, $validate = true){
		$this->text = $value;
		if($validate){
			$this->validateValue($value);
		}
	}
}
