<?php

namespace org\adfinis\framework\geo;

/**
 * Class dealing with cities
 *
 * @author      Damian Senn <ds@adfinis.com>
 * @copyright   adfinis GmbH 2009-2010
 * @license     BSD 3-Clause
 */
class CityManager {
	/**
	 * method to return citynames from a zip code
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @todo by nc  check $languageCode2 for proper value
	 * @param       int $zip
	 * @param       string $languageCode2 (DE|FR)
	 * @return      array
	 */
	public static function ZIPToName($zip, $languageCode2){
		$fieldName = sprintf('name%s', strtoupper($languageCode2));

		$query = sprintf("
			SELECT
				`%s`
			FROM
				`city`
			WHERE
				`zip` = %d
			",
			$fieldName,
			$zip
		);

		$ZIPNames = array();
		foreach(DbManager::query($query) as $row){
			$ZIPNames[] = $row[$fieldName];
		}

		return $ZIPNames;
	}

	/**
	 * returns the ZIP(s) of a city name
	 *
	 * always returns an array as the City/ZIP relation is not unique in Switzerland
	 *
	 * @author      Nicolas Christener <nc@adfinis.com>
	 * @todo by nc  check $languageCode2 for proper value
	 * @param       string $name
	 * @param       string $languageCode2
	 * @return       array()
	 */
	public static function nameToZIP($name, $languageCode2){
		$fieldName = sprintf('name%s', strtoupper($languageCode2));

		$preparedStatement = DbManager::prepare(
			sprintf("
				SELECT
					`zip`
				FROM
					`city`
				WHERE
					`%s` = ?
				",
				$fieldName
			)
		);

		$preparedStatement->execute(array($name));

		$result = array();
		foreach($preparedStatement as $row){
			$result[] = $row['zip'];
		}

		return $result;
	}
}
