<?php

namespace org\adfinis\framework\geo;

/**
 * Class dealing with GeoIP related stuff
 *
 * @author      Nicolas Christener <nc@adfinis.ch>
 * @copyright   adfinis GmbH 2009-2010
 * @license     BSD 3-Clause
 */
class GeoIp {
	/**
	 * Returns an array with country info from am ip (array key ['country'] for the country name
	 * and the array key ['country_code'] for the 2-letter country code
	 *
	 * @author      Nicolas Christener <nc@adfinis.ch>
	 * @param       string $IP (use $_SERVER['REMOTE_ADDR'] for example)
	 * @return      array
	 */
	public static function getCountryByIp($IP){
		// Includes the geoIP file
		require_once(_CONF_INC . '/3rdparty/GeoIP/GeoIP.php');

		$geoIP = Net_GeoIP::getInstance(
			sprintf('%s/3rdparty/GeoIP/GeoIP.dat', _CONF_INC)
		);

		// get the country name
		$countryInfos['country'] = $geoIP->lookupCountryName($IP);

		// get the country code
		$countryInfos['countryCode'] = $geoIP->lookupCountryCode($IP);

		return $countryInfos;
	}

	/**
	 * Returns array with country informations by countryId
	 *
	 * @author      Toni Rudolf <tr@adfinis.ch>
	 * @param       int $countryId id from our countries table
	 * @return      array
	 */
	public static function getCountryInfosById($countryId){
		$countryId = intval($countryId);
		try {
			$preparedStatement = DbManager::prepare("
				SELECT
					`nameDE`,
					`nameEN`,
					`countryID`,
					`countryCode2`,
					`countryCode3`
				FROM
					`country`
				WHERE
					`countryID` = ?
				"
			);
			$preparedStatement->execute(array($countryId));
			$row = $preparedStatement->fetch();

			return $row;
		}catch(Exception $e){
			return false;
		}
	}
}
