<?php

/**
 * Helper for translation
 *
 * This file is a bit ... special. It sits in a namespaced location, 
 * but actually provides global functions. This is useful because
 * we want a simple notation for translation.
 *
 * Example translating some string:
 *
 * @code
 *     echo _('Some string');
 * @endcode
 *
 * @author        David Vogt <dv@adfinis.ch>
 * @copyright     adfinis GmbH 2011
 * @license       BSD 3-Clause
 **/

/**
 * Shorthand for Language::gettext()
 *
 * Translates plural / singular form depending of the given amount.
 *
 * @author        David Vogt <dv@adfinis.ch>
 * @param         string $text
 * @returns       string
 */
function tr($text) {
	return org\adfinis\framework\lang\Language::gettext($text);
}

/**
 * Shorthand for Language::ngettext().
 *
 * Translates plural / singular form depending of the given amount.
 *
 * @author        David Vogt <dv@adfinis.ch>
 * @param         string $text1  Singular form of the phrase
 * @param         string $textn  Plural form of the phrase
 * @param         int    $number Number to decide between singular/plural
 * @returns       string
 */
function trn($text1, $textn, $number) {
	return org\adfinis\framework\lang\Language::ngettext($text1, $textn, $number);
}

