<?php

namespace org\adfinis\framework\login;

use \org\adfinis\framework\entity\Entity;

/**
 * Class to deal with basic login
 *
 * @author      Damian Senn <ds@adfinis.com>
 * @copyright   adfinis GmbH 2010
 * @license     BSD 3-Clause
 */
abstract class Login {

	/**
	 * @var Entity
	 */
	private $user;

	/**
	 * Get the currently logged in user
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      Entity|null
	 */
	public function getUser(){
		return $this->user;
	}

	/**
	 * Set the user which is logged in
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @param       ggUser
	 * @return      this
	 */
	protected function setUser(Entity $user){
		$this->user = $user;

		return $this;
	}

	/**
	 * Is the user logged in?
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      bool
	 */
	public function isLoggedIn(){
		return isset($this->user)
			&& $this->user->isActive
			&& $this->user->isVerified;
	}
}
