<?php

namespace org\adfinis\framework\login;

use \org\adfinis\framework\entity\Entity;

/**
 * Interface to define Login classes
 *
 * @author      Damian Senn <ds@adfinis.com>
 * @copyright   adfinis GmbH 2010
 * @license     BSD 3-Clause
 */
interface LoginInterface {

	/**
	 * Get Login instance
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      Login
	 */
	public static function getInstance();

	/**
	 * Logs the given user in if the password is valid
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @throws      Exception
	 * @param       mixed  $login
	 * @param       string $password
	 * @param       bool   $checkPassword (optional)
	 * @return      bool
	 */
	public function login($login, $password, $checkPassword = false);

	/**
	 * Sets and sends the cookie
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @param       bool $cookie
	 * @return      void
	 */
	public function setCookie($cookie);

	/**
	 * Login by cookie
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @throws      Exception
	 * @return      bool
	 */
	public function cookieLogin();

	/**
	 * Returns the user which is currently logged in
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      Entity
	 */
	public function getUser();

	/**
	 * Is a user logged in?
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      bool
	 */
	public function isLoggedIn();

	/**
	 * Logout the current user
	 *
	 * @author      Damian Senn <ds@adfinis.com>
	 * @return      void
	 */
	public function logout();
}
