<?php

namespace org\adfinis\framework\request;

/**
 * Represents a HTTP request, wrapping the GET, POST, FILE and COOKIE superglobals.
 *
 * This provides an object-oriented way to access query data. By using
 * this class, we can unit test whole web requests without using a browser.
 *
 * The actual implementation sits in AbstractRequest, we just implement
 * initialisation here.
 *
 * @author      David Vogt <dv@adfinis.com>
 * @copyright   adfinis GmbH 2010-2010
 * @license     BSD 3-Clause
*/
class Request extends AbstractRequest {

	/**
	 * Creates a new Request object initialized from the $_POST, $_GET, $_COOKIE and $_FILES superglobals.
	 *
	 * You should consider using Request::fromCurrentGPC()
	 * instead of calling this constructor directly.
	 *
	 * @author        David Vogt <dv@adfinis.com>
	 * @param[in]     array &$postData
	 * @param[in]     array &$getData
	 * @param[in]     array &$cookieData
	 * @param[in]     array &$fileData
	 */
	public function __construct(&$postData, &$getData, &$cookieData, &$fileData) {
		$this->postData   = $postData;
		$this->getData    = $getData;
		$this->fileData   = $fileData;
		$this->cookieData = $cookieData;

		// Set isPOST if we have stuff in the POST data.
		if(sizeof($postData)) {
			$this->isPOST = true;
		}
	}

	/**
	 * Factory for creating a request object from the current HTTP request.
	 *
	 * This takes the current $_POST, $_GET etc and creates a Request object from them.
	 *
	 * @author      David Vogt <dv@adfinis.com>
	 * @return      org\adfinis\framework\request\Request
	 */
	public static function fromCurrentGPC() {
		$newMe = new self($_POST, $_GET, $_COOKIE, $_FILES);

		// isPOST is set, but we need to find out if isAJAX is to be set:
		if (isset($_SERVER['HTTP_X_REQUESTED_WITH']) &&
			strtolower($_SERVER['HTTP_X_REQUESTED_WITH']) == 'xmlhttprequest'
		) {
			$newMe->isAJAX = true;
		}
		return $newMe;
	}
}
