<?php

namespace org\adfinis\framework\session;

use org\adfinis\framework\config\ConfManager;

/**
 * Session handling methods
 *
 * @author      Matthias Blaser <mb@adfinis.ch>
 * @author      David Vogt <dv@adfinis.com>
 * @copyright   adfinis GmbH 2009-2010
 * @license     BSD 3-Clause
 */
class SessionManager {
	/**
	 * Holds currently registred namespace objects
	 *
	 * @var         array $zendSessionNamespaces
	 */
	private static $zendSessionNamespaces = array();

	/**
	 * Starts session and initializes a namespace object
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @param       string $namespace
	 */
	public static function init($namespace = null){
		if($namespace === null){
			$namespace = ConfManager::getVar('af', 'session', 'namespace');
		}
		// check if session is already started
		if(!\Zend_Session::isStarted()){
			\Zend_Session::start();
		}

		// initialize session namespace object
		if(!isset(self::$zendSessionNamespaces[$namespace])){
			self::$zendSessionNamespaces[$namespace] = new \Zend_Session_Namespace($namespace, true);
		}
	}

	/**
	 * Returns session namespace object
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @param       string $namespace
	 * @return      Zend_Session_Namespace
	 */
	public static function getInstance($namespace = 'Default'){
		if(isset(self::$zendSessionNamespaces[$namespace])){
			return self::$zendSessionNamespaces[$namespace];
		}

		throw new OutOfRangeException(
			sprintf(tr('Session namespace "%s" not found'), $namespace)
		);
	}


	/**
	 * Resets all session namespaces
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @return      void
	 */
	public static function reset(){
		foreach(self::$zendSessionNamespaces as $namespace){
			$namespace->unsetAll();
		}
	}

	/**
	 * Regenerate sessionID
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @return      void
	 */
	public static function regenerateID(){
		\Zend_Session::regenerateID();
	}

	/**
	 * Returns sessionID
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @return      string sessionID
	 */
	public static function getID(){
		return \Zend_Session::getId();
	}

	/**
	 * Convenience method to determine if the session is already started.
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @return      bool
	 */
	public static function isStarted(){
		return \Zend_Session::isStarted();
	}

	/**
	 * Shutsdown the sesssion
	 *
	 * Close writing and detach $_SESSION from the back-end storage mechanism.
	 * This will complete the internal data transformation on this request.
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @param       bool $readonly - OPTIONAL remove write access (i.e. throw error if Zend_Session's attempt writes)
	 * @return      void
	 */
	public static function writeClose($readonly = true){
		return \Zend_Session::writeClose($readonly);
	}

	/**
	 * Whether or not a session exists for the current request
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @return     bool
	 */
	public static function sessionExists(){
		return \Zend_Session::sessionExists();
	}
}
