<?php

namespace org\adfinis\framework\template\smorfy;

/**
 * Smorfy for processing M$ Word documents
 *
 * @author        Damian Senn <ds@adfinis.com>
 */
class SmorfyDOCX extends Smorfy {

	/**
	 * Replace simple placeholders
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @author        Stefan Heinemann <stefan.heinemann@adfinis-sygroup.ch>
	 * @param         DOMXPath $xpath
	 * @param         DOMNode  $body
	 * @returns       void
	 */
	protected function replaceTextPlaceholders($xpath, $body) {
		foreach ($xpath->query('.//w:t', $body) as $p) {
			if (preg_match_all('/\{\$(\w+)\}/', $p->textContent, $matches)) {
				foreach ($matches[1] as $match) {
					$text = new \DOMText(
						str_replace(sprintf('{$%s}', $match),
						$this->variables[$match], 
						$p->textContent)
					);

					$p->removeChild($p->firstChild);
					$p->appendChild($text);
				}
			}
		}
	}

	/**
	 * Replace placeholders in tables
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @param         DOMXPath $xpath
	 * @param         DOMNode  $body
	 * @returns       void
	 */
	protected function replaceTablePlaceholders($xpath, $body) {
		foreach ($xpath->query('.//w:tbl', $body) as $table) {
			foreach ($xpath->query('w:tr', $table) as $row) {
				if (preg_match('/\{\%(\w+)\.?(?:\w+)?\}/', $row->textContent, $rowMatches)) {
					$count = count($this->variables[$rowMatches[1]]);

					for ($i = 0; $i < $count; ++$i) {
						$clone = $row->cloneNode(true);
						$row->parentNode->insertBefore($clone, $row);

						foreach ($xpath->query('.//w:t', $clone) as $p) {
							if (preg_match('/\{\%(\w+)\.?(\w+)?\}/', $p->textContent, $matches)) {
								if (!isset($matches[2])) {
									$text = new \DOMText(str_replace(sprintf('{%%%s}', $matches[1]),
										$this->variables[$matches[1]], $p->textContent));
								}
								else {
									$text = new \DOMText(str_replace(sprintf('{%%%s.%s}', $matches[1], $matches[2]),
										$this->variables[$matches[1]][$i][$matches[2]], $p->textContent));
								}

								$p->removeChild($p->firstChild);
								$p->appendChild($text);
							}
						}
					}

					$row->parentNode->removeChild($row);
				}
			}
		}
	}

	/**
	 * Replace placeholders in list items
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @param         DOMXPath $xpath
	 * @param         DOMNode  $body
	 * @returns       void
	 */
	protected function replaceListPlaceholders($xpath, $body) {
		foreach ($xpath->query('.//w:numPr', $body) as $row) {
			$row = $row->parentNode->parentNode;

			if (preg_match('/\{\%(\w+)\.?(?:\w+)?\}/', $row->textContent, $rowMatches)) {
				$count = count($this->variables[$rowMatches[1]]);

				for ($i = 0; $i < $count; ++$i) {
					$clone = $row->cloneNode(true);
					$row->parentNode->insertBefore($clone, $row);

					foreach ($xpath->query('.//w:t/text()', $clone) as $p) {
						if (preg_match('/\{\%(\w+)\}/', $p->textContent, $matches)) {
							$text = new \DOMText(str_replace(sprintf('{%%%s}', $matches[1]),
								$this->variables[$matches[1]][$i], $p->textContent));

							$parent = $p->parentNode;
							$parent->removeChild($p);
							$parent->appendChild($text);
						}
					}
				}

				$row->parentNode->removeChild($row);
			}
		}
	}

	/**
	 * Get the document body
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @returns       DOMNode
	 */
	public function getDocumentBody($xpath) {
		return $xpath->query('/w:document/w:body')->item(0);
	}
}
