<?php

namespace org\adfinis\framework\template\smorfy;

/**
 * Smorfy for processing OOo documents
 *
 * @author        Damian Senn <ds@adfinis.com>
 */
class SmorfyODT extends Smorfy {

	/**
	 * Replace simple placeholders
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @author        Stefan Heinemann <stefan.heinemann@adfinis-sygroup.ch>
	 * @param         DOMXPath $xpath
	 * @param         DOMNode  $body
	 * @returns       void
	 */
	protected function replaceTextPlaceholders($xpath, $body) {
		foreach ($xpath->query('.//text:p//text()', $body) as $p) {
			if (preg_match_all('/\{\$(\w+)\}/', $p->textContent, $matches)) {
				$text = $p->textContent;

				foreach ($matches[1] as $match) {
					$text = str_replace(
						sprintf('{$%s}', $match),
						$this->variables[$match], 
						$text
					);
				}

				$dText = new \DOMText($text);
				$parent = $p->parentNode;
				$parent->removeChild($p);
				$parent->appendChild($dText);
			}
		}
	}

	/**
	 * Replace placeholders in tables
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @param         DOMXPath $xpath
	 * @param         DOMNode  $body
	 * @returns       void
	 */
	protected function replaceTablePlaceholders($xpath, $body) {
		foreach ($xpath->query('.//table:table', $body) as $table) {
			foreach ($xpath->query('table:table-row', $table) as $row) {
				if (preg_match('/\{\%(\w+)\.?(?:\w+)?\}/', $row->textContent, $rowMatches)) {
					$count = count($this->variables[$rowMatches[1]]);

					for ($i = 0; $i < $count; ++$i) {
						$clone = $row->cloneNode(true);
						$row->parentNode->insertBefore($clone, $row);

						foreach ($xpath->query('.//text:p//text()', $clone) as $p) {
							if (preg_match('/\{\%(\w+)\.?(\w+)?\}/', $p->textContent, $matches)) {
								if (!isset($matches[2])) {
									$text = new \DOMText(str_replace(sprintf('{%%%s}', $matches[1]),
										$this->variables[$matches[1]], $p->textContent));
								}
								else {
									$text = new \DOMText(str_replace(sprintf('{%%%s.%s}', $matches[1], $matches[2]),
										$this->variables[$matches[1]][$i][$matches[2]], $p->textContent));
								}

								$parent = $p->parentNode;
								$parent->removeChild($p);
								$parent->appendChild($text);
							}
						}
					}

					$row->parentNode->removeChild($row);
				}
			}
		}
	}

	/**
	 * Replace placeholders in list items
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @param         DOMXPath $xpath
	 * @param         DOMNode  $body
	 * @returns       void
	 */
	protected function replaceListPlaceholders($xpath, $body) {
		foreach ($xpath->query('.//text:list', $body) as $list) {
			foreach ($xpath->query('text:list-item', $list) as $row) {
				if (preg_match('/\{\%(\w+)\.?(?:\w+)?\}/', $row->textContent, $rowMatches)) {
					$count = count($this->variables[$rowMatches[1]]);

					for ($i = 0; $i < $count; ++$i) {
						$clone = $row->cloneNode(true);
						$row->parentNode->insertBefore($clone, $row);

						foreach ($xpath->query('.//text:p//text()', $clone) as $p) {
							if (preg_match('/\{\%(\w+)\}/', $p->textContent, $matches)) {
								$text = new \DOMText(str_replace(sprintf('{%%%s}', $matches[1]),
									$this->variables[$matches[1]][$i], $p->textContent));

								$parent = $p->parentNode;
								$parent->removeChild($p);
								$parent->appendChild($text);
							}
						}
					}

					$row->parentNode->removeChild($row);
				}
			}
		}
	}

	/**
	 * Get the document body
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @returns       DOMNode
	 */
	public function getDocumentBody($xpath) {
		return $xpath->query('/office:document-content/office:body')->item(0);
	}
}
