<?php

namespace org\adfinis\framework\utils;

/**
 * Class dealing with passwords
 *
 * @author      Adrian Wittwer <aw@adfinis.com>
 * @copyright   adfinis GmbH 2009-2010
 * @license     BSD 3-Clause
 */
class PasswordGenerator {
	/**
	 * generate a random password
	 *
	 * @author      Adrian Wittwer <aw@adfinis.com>
	 * @param       int $length
	 * @param       bool $withCapitalLetters
	 * @param       bool $withNumbers
	 * @param       bool $withSpecialChars
	 * @return      string
	 */
	public static function generatePassword(
		$length,
		$withCapitalLetters = true,
		$withNumbers = true,
		$withSpecialChars = false
	) {
		$possibleLettersSmall = array();
		$possibleLettersCapital = array();
		$possibleNumbers = array();
		$possibleSpecialChars = array();

		// add all possible characters to the arrays
		$possibleLettersSmall = range('a', 'z');
		if ($withCapitalLetters) {
			$possibleLettersCapital = range('A', 'Z');
		}
		if ($withNumbers) {
			$possibleNumbers = range(0, 9);
		}
		if ($withSpecialChars) {
			$possibleSpecialChars = array(
				'+', '"', '*', '', '%', '&', '/', '(', ')', '=', '?', '!', '\'',
				'@', '#', '$', ',', '.', '-', ';', ':', '_', '[', ']', '{', '}',
				'^', '<', '>', '\\'
			);
		}

		// merge all of the possible characters into one array
		$possibleCharacters = array_merge(
			$possibleLettersSmall,
			$possibleLettersCapital,
			$possibleNumbers,
			$possibleSpecialChars
		);

		// get count of all possible characters for the mt_rand() function
		$count = count($possibleCharacters)-1;

		$password = '';
		for ($i = 0; $i < $length; $i++) {
			$password .= $possibleCharacters[mt_rand(0, $count)];
		}

		return $password;
	}
}
