<?php

namespace org\adfinis\framework\utils;

/**
 * Registry. Stores "global" information during a request.
 *
 * @author        David Vogt <dv@adfinis.ch>
 * @copyright     adfinis GmbH 2011
 * @license       BSD 3-Clause
 **/
class Registry {

	/**
	 * Stores the singleton instance
	 *
	 * @var           Registry $singleton
	 */
	private static $singleton;

	/**
	 * Stores the registered values
	 *
	 * @var           array $data
	 */
	private $data = array();

	/**
	 * Private constructor, for singleton pattern
	 *
	 * @author        David Vogt <dv@adfinis.ch>
	 */
	private function __construct() {
	}

	/**
	 * Returns a registry instance
	 *
	 * @author        David Vogt <dv@adfinis.ch>
	 * @returns       Registry
	 */
	public static function getInstance() {
		if(is_null(self::$singleton)) {
			self::$singleton = new self;
		}
		return self::$singleton;
	}
	

	/**
	 * Stores a value in the registry.
	 *
	 * @author        David Vogt <dv@adfinis.ch>
	 * @param         string $key
	 * @param         mixed  $value
	 * @returns       void
	 */
	public function set($key, $value) {
		$this->data[$key] = $value;
	}

	/**
	 * Returns the given value from the registry.
	 *
	 * If the key is not known, an OutOfBoundsException is thrown.
	 *
	 * @author        David Vogt <dv@adfinis.ch>
	 * @throws        OutOfBoundsException
	 * @param         string $key
	 * @returns       mixed
	 */
	public function get($key) {
		if(!isset($this->data[$key])) {
			throw new \OutOfBoundsException(sprintf(tr("Registry: Key %s is not known."), $key));
		}
		return $this->data[$key];
	}

	/**
	 * Returns whether the key exists
	 *
	 * @author        Stefan Heinemann <sh@adfinis.com>
	 * @param         string $key
	 * @returns       bool
	 */
	public function keyExists($key) {
		return isset($this->data[$key]);
	}
	
}
