<?php

namespace org\adfinis\framework\utils;

/**
 * Helper methods to generate URLs to public webservices
 *
 * This currently provides access URLs for google maps routes and the SBB time table.
 *
 * @author      Nicolas Christener <nc@adfinis.ch>
 * @copyright   adfinis GmbH 2009-2010
 * @license     BSD 3-Clause
 */
class WebServiceURL {

	/**
	 * Creates a link to 'Google Maps' showing the route betweend two addresses
	 *
	 * @author      Nicolas Christener <nc@adfinis.ch>
	 * @param       string $fromZIP
	 * @param       string $fromCity
	 * @param       string $fromStreet
	 * @param       string $toZIP
	 * @param       string $toCity
	 * @param       string $toStreet
	 * @param       string $languageName2
	 * @return      string
	 */
	public static function getGoogleRouteURL($fromZIP, $fromCity, $fromStreet, $toZIP, $toCity, $toStreet, $languageName2){
		$startAddress = urlencode(sprintf('%s %s %s', $fromStreet, $fromZIP, $fromCity));
		$endAddress = urlencode(sprintf('%s %s %s', $toZIP, $toCity, $toStreet));

		$URL = sprintf(
			'http://maps.google.com/maps?saddr=%s&daddr=%s&hl=%s',
			$startAddress,
			$endAddress,
			strtolower($languageName2)
		);

		return $URL;
	}

	/**
	 * Creates a link to 'SBB Fahrplan' (timetable) and fills out the form
	 *
	 * @author      Nicolas Christener <nc@adfinis.ch>
	 * @param       string $fromZIP
	 * @param       string $fromCity
	 * @param       string $fromStreet
	 * @param       string $toZIP
	 * @param       string $toCity
	 * @param       string $toStreet
	 * @return      string
	 */
	public static function getSBBURL($fromZIP, $fromCity, $fromStreet, $toZIP, $toCity, $toStreet){
		if(!empty($fromStreet)){
			$startAddress = urlencode(utf8_decode(sprintf('%s %s, %s', $fromZIP, $fromCity, $fromStreet)));
		} else {
			$startAddress = urlencode(utf8_decode(sprintf('%s %s', $fromZIP, $fromCity)));
		}

		if(!empty($toStreet)){
			$endAddress = urlencode(utf8_decode(sprintf('%s %s, %s', $toZIP, $toCity, $toStreet)));
		} else {
			$endAddress = urlencode(utf8_decode(sprintf('%s %s', $toZIP, $toCity)));
		}

		// defines the type of the start/end address (Ort, Strasse, Nr.)
		$sadr = '1';
		$zadr = '1';

		$URL = sprintf(
			'http://fahrplan.sbb.ch/bin/query.exe/dn?s=%s&sadr=%d&z=%s&zadr=%d',
			$startAddress,
			$sadr,
			$endAddress,
			$zadr
		);

		return $URL;
	}
}
