<?php

namespace org\adfinis\framework\utils\string;

/**
 * Class contains functions for getting and cleaning GPC-Vars
 *
 * @author      Matthias Blaser <mb@adfinis.ch>
 * @copyright   adfinis GmbH 2007-2010
 * @license     BSD 3-Clause
 */
class StringCleaner {
	/**
	 * replaces linebreaks by a dash  ' - '
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @param       string $text
	 * @return      string
	 */
	public static function rogerizeText($text){
		$text = stripslashes(str_replace("\n", " - ", strip_tags($text)));
		return $text;
	}

	/**
	 * remove slashes in a text - wrapper for stripslashes()
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @param       string $text
	 * @return      string
	 */
	public static function cleanText($text){
		$text = stripslashes($text);
		return $text;
	}

	/**
	 * remove html tags in a text - wrapper for strip_tags()
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @param       string $text
	 * @return      string
	 */
	public static function stripTags($text){
		$text = strip_tags($text);
		return $text;
	}

	/**
	 * remove html tags and slashed in a text
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @param       string $text
	 * @return      string
	 */
	public static function reallyCleanText($text){
		$text = self::cleanText(self::stripTags($text));
		return $text;
	}

	/**
	 * @todo description
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @param       string $text
	 * @return      string
	 */
	public static function escapeSpecialChars($text){
		$text = str_replace('&amp;', '&', htmlspecialchars($text, ENT_QUOTES, 'utf-8'));
		return $text;
	}

	/**
	 * @todo description
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @param       string $text
	 * @return      string
	 */
	public static function escapeJavaScriptSpecialChars($text){
		$text = str_replace(
			"'",
			"\'",
			str_replace(
				array('&amp;', '&#039;'),
				array('&', "'"),
				htmlspecialchars($text, ENT_COMPAT, 'utf-8'))
			);

		return $text;
	}

	/**
	 * @todo description
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @param       string $string
	 * @return      string
	 */
	public static function basicXSSClean($string) {

		// @taken from popoon: http://svn.bitflux.ch/repos/public/popoon/trunk/classes/externalinput.php
		// this basic clean should clean html code from
		// lot of possible malicious code for Cross Site Scripting
		// use it whereever you get external input

		if (get_magic_quotes_gpc()) {
			$string = stripslashes($string);
		}
		$string = str_replace(array("&amp;","&lt;","&gt;"),array("&amp;amp;","&amp;lt;","&amp;gt;",),$string);
		// fix &entitiy\n;

		$string = preg_replace('#(&\#*\w+)[\x00-\x20]+;#u',"$1;",$string);
		$string = preg_replace('#(&\#x*)([0-9A-F]+);*#iu',"$1$2;",$string);
		$string = html_entity_decode($string, ENT_COMPAT, "UTF-8");

		// remove any attribute starting with "on" or xmlns
		$string = preg_replace('#(<[^>]+[\x00-\x20\"\'])(on|xmlns)[^>]*>#iUu',"$1>",$string);
		// remove javascript: and vbscript: protocol
		$string = preg_replace('#([a-z]*)[\x00-\x20]*=[\x00-\x20]*([\`\'\"]*)[\\x00-\x20]*j[\x00-\x20]*a[\x00-\x20]*v[\x00-\x20]*a[\x00-\x20]*s[\x00-\x20]*c[\x00-\x20]*r[\x00-\x20]*i[\x00-\x20]*p[\x00-\x20]*t[\x00-\x20]*:#iUu','$1=$2nojavascript...',$string);
		$string = preg_replace('#([a-z]*)[\x00-\x20]*=([\'\"]*)[\x00-\x20]*v[\x00-\x20]*b[\x00-\x20]*s[\x00-\x20]*c[\x00-\x20]*r[\x00-\x20]*i[\x00-\x20]*p[\x00-\x20]*t[\x00-\x20]*:#iUu','$1=$2novbscript...',$string);
		//<span style="width: expression(alert('Ping!'));"></span>
		// only works in ie...
		$string = preg_replace('#(<[^>]+)style[\x00-\x20]*=[\x00-\x20]*([\`\'\"]*).*expression[\x00-\x20]*\([^>]*>#iU',"$1>",$string);
		$string = preg_replace('#(<[^>]+)style[\x00-\x20]*=[\x00-\x20]*([\`\'\"]*).*behaviour[\x00-\x20]*\([^>]*>#iU',"$1>",$string);
		$string = preg_replace('#(<[^>]+)style[\x00-\x20]*=[\x00-\x20]*([\`\'\"]*).*s[\x00-\x20]*c[\x00-\x20]*r[\x00-\x20]*i[\x00-\x20]*p[\x00-\x20]*t[\x00-\x20]*:*[^>]*>#iUu',"$1>",$string);
		//remove namespaced elements (we do not need them...)
		$string = preg_replace('#</*\w+:\w[^>]*>#i',"",$string);
		//remove really unwanted tags

		do {
			$oldstring = $string;
			// removed embed
			$string = preg_replace('#</*(applet|meta|xml|blink|link|style|script|embed|object|iframe|frame|frameset|ilayer|layer|bgsound|title|base)[^>]*>#i',"",$string);
		} while ($oldstring != $string);

		return $string;
	}
}
