<?php

namespace org\adfinis\framework\utils\string;

/**
 * Class contains functions for getting and cleaning GPC-Vars
 *
 * @author      Matthias Blaser <mb@adfinis.ch>
 * @copyright   adfinis GmbH 2007-2010
 * @license     BSD 3-Clause
 */
class StringFormat {
	/**
	* Formats number of bytes to a human readable format
	*
	* @author      Matthias Blaser <mb@adfinis.ch>
	* @param       int $bytes
	* @param       int $switch_bytes at which byte/kb/mb count switch to the next upper level
	* @return      string
	*/
	public static function formatFilesize($bytes, $switch_bytes = 750){
		// print out human readable filesizes

		if($bytes >= ($switch_bytes * 1048576)){
			$gb = number_format($bytes / 1073741824, 2, ".", "'");
			return $gb . " GB";
		}

		if($bytes >= ($switch_bytes * 1024)){
			$mb = number_format($bytes / 1048576, 2, ".", "'");
			return $mb . " MB";
		}

		if($bytes >= $switch_bytes){
			$kb =  number_format($bytes / 1024, 2, ".", "'");
			return $kb . " KB";
		}

		return $bytes . " Bytes";
	}

	/**
	 * Truncate a string to a certain length if necessary,
	 * optionally splitting in the middle of a word, and
	 * appending the $etc string or inserting $etc into the middle.
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @param       string $string
	 * @param       integer $length
	 * @param       string $etc
	 * @param       boolean $breakWords
	 * @param       boolean $middle
	 * @return      string
	 */
	public static function truncate($string, $length, $etc = '...', $breakWords = false, $middle = false){
		if ($length == 0)
			return '';

		if (strlen($string) > $length) {
			$length -= strlen($etc);
			if (!$breakWords && !$middle) {
				$string = preg_replace('/\s+?(\S+)?$/', '', substr($string, 0, $length+1));
			}
			if(!$middle) {
				return substr($string, 0, $length).$etc;
			} else {
				return substr($string, 0, $length/2) . $etc . substr($string, -$length/2);
			}
		} else {
			return $string;
		}
	}
}
