<?php

namespace org\adfinis\framework\utils\string;

/**
 * Class contains functions for getting and cleaning GPC-Vars
 *
 * @author      Matthias Blaser <mb@adfinis.ch>
 * @copyright   adfinis GmbH 2007-2010
 * @license     BSD 3-Clause
 */
class StringFunctions {
	/**
	 * Returns the first x words of a string
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @param       string $string
	 * @param       int $num
	 * @return      string
	 */
	public static function firstWords($string, $num = 10){
		$words = preg_split("/[\s,]+/", $string);
		$out = '';

		for($i = 0; $i < min($num, count($words)); $i++){
			$out .= $words[$i] . ' ';
		}

		return rtrim($out);
	}

	/**
	 * Returns an url safe string
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @param       string $string
	 * @return      string
	 */
	public static function URLizeString($string){
		$string = str_replace(' ', '_', $string);
		$string = preg_replace('/[^a-zA-Z0-9-_\.,]/', '', $string);
		return $string;
	}

	/**
	 * Encodes an URL but don't touch /
	 *
	 * Usually, urlencode also encodes / to %2F. But this is not usable when encoding
	 * full URL's with a path. This function does the same as urlencode(), just
	 * leaving / untouched.
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @param       string $string
	 * @return      string
	 */
	public static function pathSafeURLEncode($string){
		return str_replace('%2F', '/', urlencode($string));
	}
}
