<?php

namespace org\adfinis\framework\utils\string;

/**
 * Class contains functions for getting and cleaning GPC-Vars
 *
 * @author      Matthias Blaser <mb@adfinis.ch>
 * @copyright   adfinis GmbH 2007-2010
 * @license     BSD 3-Clause
 */
class StringTokenizer {
	/**
	 * Split a string into tokens.
	 *
	 * Token seperator can be space, comma, multiple words can be grouped
	 * together using single or double quotes.
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @param       string $string string to be tokenized
	 * @return      array string parts
	 */
	public static function tokenizeString($string){
		$tokens = array();

		if(mb_substr_count($string, '"') % 2 != 0){
			// uneven count of double quotes, strip them now
			$string = str_replace('"', '', $string);
		} else {
			// get all strings enclosed with double quotes
			if(preg_match_all('/"([^"]+)"/', $string, $matches)){
				foreach($matches[1] as $match){
					$match = trim($match);

					if($match == ''){
						continue;
					}

					$tokens[] = $match;

					// ... and remove it from string
					$string = trim(
						str_replace(
							sprintf('"%s"', $match),
							'',
							$string
						), ' ,'
					);
				}
			}
		}

		if(mb_substr_count($string, "'") % 2 != 0){
			// uneven count of single quotes, strip them now
			$string = str_replace("'", '', $string);
		} else {
			// get all strings matched with single quotes
			if(preg_match_all("/'([^']+)'/", $string, $matches)){
				foreach($matches[1] as $match){
					$match = trim($match);

					if($match == ''){
						continue;
					}

					$tokens[] = $match;

					// ... and remove it from string
					$string = trim(str_replace(sprintf("'%s'", $match), '', $string), ' ,');
				}
			}
		}

		// get all the rest (space, comma delimited)
		if(trim($string) != ''){
			$tokens_rest = preg_split('/(\s|,)+/', trim($string, ' ,'));

			foreach($tokens_rest as $match){
				$tokens[] = trim($match);
			}
		}

		return $tokens;
	}
}
