<?php

namespace org\adfinis\framework\utils\string;

/**
 * Class contains functions for getting and cleaning GPC-Vars
 *
 * @author      Matthias Blaser <mb@adfinis.ch>
 * @copyright   adfinis GmbH 2007-2010
 * @license     BSD 3-Clause
 */
class StringTransliterator {
	/**
	 * Transliterates a string for an URL
	 *
	 * @author      Matthias Blaser <mb@adfinis.ch>
	 * @param       string $string utf8 encoded string
	 * @return      string ascii
	 */
	public static function transliterateURL($string){
		// transliterate to an ascii representation
		$string = self::transliterate($string, 'ascii', 'utf-8');

		// and check if it's url safe at last
		return StringFunctions::URLizeString($string);
	}

	/**
	* Transliterate a string
	*
	* @author      Matthias Blaser <mb@adfinis.ch>
	* @param       string $string
	* @param       string $toCharset
	* @param       string $fromCharset
	* @return      string
	*/
	public static function transliterate($string, $toCharset, $fromCharset = 'UTF-8'){
		if(function_exists('transliterate')){
			// we have the transliterate extension, so do some advanced
			// transliteration first
			$string = iconv('utf-8', 'ucs-2', $string);
			$string = transliterate($string,
				array(
					/*'cyrillic_transliterate',
					'cyrillic_transliterate_bulgarian',
					'greek_transliterate',
					'han_transliterate',
					'hebrew_transliterate',
					'jamo_transliterate',*/
					'normalize_ligature',
					'normalize_punctuation',
					'normalize_superscript_numbers',
					'normalize_subscript_numbers',
					'normalize_numbers',
					'normalize_superscript',
					'normalize_subscript',
					'decompose_special',
					'decompose_currency_signs',
					'decompose',
					/*'hangul_to_jamo',*/
					'compact_underscores',
					'diacritical_remove'
					)
				);

			return iconv('ucs-2', 'utf-8', $string);
		}

		return iconv($fromCharset, $toCharset . '//TRANSLIT', $string);
	}
}
