<?php

namespace org\adfinis\framework\test\datamapper;

use org\adfinis\framework\model\Entity;
use org\adfinis\framework\datamapper\IdentityMap;

/**
 * Test cases for IdentityMap
 *
 * @author        Damian Senn <ds@adfinis.com>
 * @copyright     adfinis GmbH 2011
 * @license       BSD 3-Clause
 */
class IdentityMapTest extends \PHPUnit_Framework_TestCase {

	/**
	 * IdentityMap to test
	 *
	 * @var           IdentityMap
	 */
	static $identityMap;

	/**
	 * Set up an IdentityMap instance
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @returns       void
	 */
	public function setUp() {
		self::$identityMap = new IdentityMap();
	}

	/**
	 * Removes the test table
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @returns       void
	 */
	public function tearDown() {
		self::$identityMap->clear();
	}

	/**
	 * Test identity map
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @returns       void
	 */
	public function testIdentityMap() {
		$im = self::$identityMap;

		$obj1 = new TestEntity(1);
		$obj2 = new TestEntity(2);
		$obj3 = new TestEntity(3);

		$im->set($obj1);
		$im->set($obj2);

		$this->assertSame($obj1, $im->get($obj1->getIdentifier()));

		$this->assertNotSame($obj1, $im->get($obj2->getIdentifier()));

		$this->assertTrue($im->exists($obj2->getIdentifier()));

		$this->assertFalse($im->exists($obj3->getIdentifier()));

		$this->assertNull($im->get($obj3->getIdentifier()));
	}
}

/**
 * Object to store in identity map
 *
 * @author        Damian Senn <ds@adfinis.com>
 */
class TestEntity extends Entity {
	var $id;

	function __construct($id) {
		$this->id = $id;
	}

	function getIdentifier() {
		return array('id' => $this->id);
	}

	function doesRecordMatch($data) { }
	function fillFromRowData($data) { }
	static function getMapper() { }
}
