<?php

namespace org\adfinis\framework\test\model;

use org\adfinis\framework\db\DbManager;
use org\adfinis\framework\model\Entity;

/**
 * Test cases for the Entity class.
 *
 * @author        David Vogt <dv@adfinis.ch>
 * @copyright     adfinis GmbH 2011
 * @license       BSD 3-Clause
 **/
class EntityTest extends \PHPUnit_Framework_TestCase {

	/**
	 * Tests the saving capability of Entity::save().
	 *
	 * @author        David Vogt <dv@adfinis.ch>
	 * @returns       void
	 */
	public function testSave() {
		$model = new TestModel();
		$model->save();

		$this->assertSame($model, TestModelMapper::$saved);
	}
	
}

/**
 * Helper class for checking the functionality of oaf\model\Entity.
 *
 * @author        David Vogt <dv@adfinis.ch>
 * @copyright     adfinis GmbH 2011
 * @license       BSD 3-Clause
 **/
class TestModel extends Entity {

	public $id;
	public $foo;
	public $bar;

	function getIdentifier() {
		return array('id' => $this->id);
	}

	static function getMapper() {
		return new TestModelMapper();
	}

	function fillFromRowData($data) {
		$this->id = $data['id'];
		$this->foo = $data['foo'];
		$this->bar = $data['bar'];
	}

	function doesRecordMatch($data) {
		return $this->id == $data['id'];
	}
}

class TestModelMapper {
	public static $saved;

	function save($object) {
		self::$saved = $object;
	}

}
