<?php

namespace org\adfinis\framework\test\template\smorfy;

use \org\adfinis\framework as oaf;
use \org\adfinis\framework\template\smorfy;

/**
 * Test Smorfy
 *
 * @author        Damian Senn <ds@adfinis.com>
 * @copyright     adfinis GmbH 2011
 * @license       BSD 3-Clause
 */
class SmorfyTest extends \PHPUnit_Framework_TestCase {

	/**
	 * File dir to the documents
	 *
	 * @var           string $fileDir
	 */
	private $fileDir;

	/**
	 * Set up fileDir path
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @returns       void
	 */
	public function setUp() {
		$this->fileDir = sprintf('%s/data/tests/%s/',
			_CONF_FW,
			dirname(str_replace('\\', '/', __CLASS__)));
	}

	/**
	 * Remove temporary files
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @returns       void
	 */
	public function tearDown() {
		`rm /tmp/smorfy-test-*`;
	}

	/**
	 * Test simple placeholder replacements for ODT documents
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @returns       void
	 */
	public function testSimpleODT() {
		$tmp = tempnam('/tmp', 'smorfy-test-');
		$doc = smorfy\Document::open($this->fileDir . 'simple.odt');

		$this->assertInstanceOf(
			// oh thank god for namespaces, class names are so short now <3
			'\org\adfinis\framework\template\smorfy\ODTDocument', $doc);

		copy($this->fileDir . 'simple.odt', $tmp);

		$smorfy = $doc::getSmorfy();

		$this->assertInstanceOf(
			'\org\adfinis\framework\template\smorfy\SmorfyODT', $smorfy);

		$smorfy->assign('to',   'foo');
		$smorfy->assign('from', 'bar');

		$dom    = $smorfy->process($doc);
		$newDoc = new smorfy\ODTDocument($tmp);
		// $newDoc->getContent(); does not work after setting
		// (probably have to close and reopen file first..? anyway,
		// there is usually no point in retrieving the content again
		// so i leave it alone for now...
		#$newDoc->setContent($dom->saveXML());

		$expected = smorfy\Document::open($this->fileDir . 'simple.result.odt');
		$this->assertEquals($expected->getContent(), $dom->saveXML());
	}

	/**
	 * Test simple placeholder replacements for DOCX documents
	 *
	 * @author        Damian Senn <ds@adfinis.com>
	 * @returns       void
	 */
	public function testSimpleDOCX() {
		$tmp = tempnam('/tmp', 'smorfy-test-');
		$doc = smorfy\Document::open($this->fileDir . 'simple.docx');

		$this->assertInstanceOf(
			// oh thank god for namespaces, class names are so short now <3
			'\org\adfinis\framework\template\smorfy\DOCXDocument', $doc);

		copy($this->fileDir . 'simple.docx', $tmp);

		$smorfy = $doc::getSmorfy();

		$this->assertInstanceOf(
			'\org\adfinis\framework\template\smorfy\SmorfyDOCX', $smorfy);

		$smorfy->assign('to',   'foo');
		$smorfy->assign('from', 'bar');

		$dom    = $smorfy->process($doc);
		$newDoc = new smorfy\DOCXDocument($tmp);
		// $newDoc->getContent(); does not work after setting
		// (probably have to close and reopen file first..? anyway,
		// there is usually no point in retrieving the content again
		// so i leave it alone for now...
		$newDoc->setContent($dom->saveXML());

		$expected = smorfy\Document::open($this->fileDir . 'simple.result.docx');
		$this->assertEquals($expected->getContent(), $dom->saveXML());
	}
}
