<?php

namespace org\adfinis\framework\tests\validate;

use org\adfinis\framework\db\DbManager;
use org\adfinis\framework\model\Entity;
use org\adfinis\framework\validate\ModelValidator;

/**
 * Tests the functionality of a simple validator.
 *
 * @author        David Vogt <dv@adfinis.ch>
 * @copyright     adfinis GmbH 2011
 * @license       BSD 3-Clause
 **/
class ModelValidatorTest extends \PHPUnit_Framework_TestCase {

	/**
	 * Tests the validator for it's functionality.
	 *
	 * @author        David Vogt <dv@adfinis.ch>
	 * @returns       void
	 */
	public function testValidator() {

		$model = new TestModel();
		$model->foo = 5;
		$model->bar = 'blub';

		$validator = $model->getValidator();
		$this->assertInternalType('object', $validator);

		$this->assertInstanceOf(
			'org\adfinis\framework\validate\ModelValidator',
			$validator
		);

		// Since this is the first call, there should be one
		// message after this validateField() call.
		$validator->validateField('foo');
		$this->assertEquals(1, sizeof($validator->getMessages()));

		// Messages list should be empty after reset
		$validator->reset();
		$this->assertEquals(0, sizeof($validator->getMessages()));

		// Now run a full validation and see it's results.
		$validator->reset();
		$validator->validateEntity();
		$this->assertEquals(2, sizeof($validator->getMessages()));

		$messages = $validator->getMessages();

		$fooMessage1 = 'Foo should be at least ten characters long.';
		$fooMessage2 = "Foo cannot be 5 if bar is set!";
		$fooMessage  = sprintf('%s %s', $fooMessage1, $fooMessage2);

		$barMessage  = 'Bar should be between 1 and 100.';

		$this->assertEquals($fooMessage, $messages['foo']);
		$this->assertEquals($barMessage, $messages['bar']);
	}
}

/**
 * Helper class for checking the functionality of oaf\model\Entity.
 *
 * @author        David Vogt <dv@adfinis.ch>
 * @copyright     adfinis GmbH 2011
 * @license       BSD 3-Clause
 **/
class TestModel extends Entity {

	public $id;
	public $foo;
	public $bar;

	static function getMapper()     { }
	function getIdentifier()        { }
	function fillFromRowData($data) { }
	function doesRecordMatch($data) { }

	public function getValidator() {
		return new TestModelValidator($this);
	}

}

class TestModelValidator extends ModelValidator {

	function validateField($fieldName) {
		switch($fieldName) {
			case 'foo':
				if(strlen($this->model->foo) < 10) {
					$this->setIsInvalid('foo', 'Foo should be at least ten characters long.');
				}
				break;
			case 'bar':
				if($this->model->bar < 1 or $this->model->bar > 100) {
					$this->setIsInvalid('bar', 'Bar should be between 1 and 100.');
				}
				break;
		}
	}

	function validateEntity() {
		$this->validateField('foo');
		$this->validateField('bar');

		// This is unholy magic, but used to trigger test cases
		if($this->model->foo === 5) {
			$this->setIsInvalid('foo', "Foo cannot be 5 if bar is set!");
		}
	}
}
