<?php
// +----------------------------------------------------------------------+
// | adfinis framework                                                    |
// +----------------------------------------------------------------------+

/**
 * Contains file utility class
 *
 * @author      David Vogt <dv@adfinis.ch>
 * @package     org.adfinis.tests.form
 * @copyright   adfinis GmbH 2007-2010
 * @license     LGPL 3.0
 */

namespace org\adfinis\framework\test\utils;

use \org\adfinis\framework\utils\Browser;

/**
 * Test cases for the FormValidator class
 *
 * @author      David Vogt <dv@adfinis.com>
 * @package     org.adfinis.tests.form
 * @todo by dv: Implement tests for checkURI(), hostname(), unique(), length(), email()
 **/
class BrowserTest extends \PHPUnit_Framework_TestCase {

	/**
	 * Tests BotDetector for detecting bots
	 *
	 * @author      David Vogt <dv@adfinis.com>
	 */
	public function  testBotNames() {
		$bots = array(
			'Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)', // Googlebot
			'msnbot-media/1.0 (+http://search.msn.com/msnbot.htm)', // msnbot-media
			'psbot/0.1 (+http://www.picsearch.com/bot.html)', // psbot
			'msnbot/1.1 (+http://search.msn.com/msnbot.htm)', // msnbot
			'WikioFeedBot 1.0', // WikioFeedBot
			'Mozilla/5.0 (compatible; Yahoo! Slurp; http://help.yahoo.com/help/us/ysearch/slurp)', // Slurp
			'Mozilla/5.0 (compatible; Ask Jeeves/Teoma; +http://about.ask.com/en/docs/about/webmasters.shtml)', // Jeeves
			'Mozilla/5.0 (compatible; Ask Jeeves/Teoma; +http://about.ask.com/en/docs/about/webmasters.shtml)', // Teoma
		);

		$nonbots = array(
			'Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en; rv:1.8.1.14) Gecko/20080409 Camino/1.6 (like Firefox/2.0.0.14)',
			'Mozilla/5.0 (Windows NT 6.0) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.60 Safari/534.24',
			'Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_2; en-US) AppleWebKit/532.9 (KHTML, like Gecko) Chrome/5.0.307.11 Safari/532.9',
			'ELinks/0.12~pre2.dfsg0-1ubuntu1-lite (textmode; Debian; Linux 2.6.32-4-jolicloud i686; 143x37-2)',
			'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.4) Gecko/2008102920 Firefox/3.0.4 (Splashtop-v1.0.5.0)',
			'Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16',
		);


		foreach ($bots as $botname) {
			$browser = Browser::getInstance($botname);
			$this->assertTrue($browser->bot, sprintf('False negative bot: %s', $botname));
		}


		foreach ($nonbots as $botname) {
			$browser = Browser::getInstance($botname);

			$this->assertFalse($browser->bot, sprintf('False positive bot: %s', $botname));
		}
	}
}

